Class: Aws::CleanRooms::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CleanRooms::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cleanrooms/client.rb,
sig/client.rbs
Overview
An API client for CleanRooms. To construct a client, you need to configure a :region and :credentials.
client = Aws::CleanRooms::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetCollaborationAnalysisTemplateResponseSuccess, _BatchGetSchemaAnalysisRuleResponseSuccess, _BatchGetSchemaResponseSuccess, _CreateAnalysisTemplateResponseSuccess, _CreateCollaborationChangeRequestResponseSuccess, _CreateCollaborationResponseSuccess, _CreateConfiguredAudienceModelAssociationResponseSuccess, _CreateConfiguredTableAnalysisRuleResponseSuccess, _CreateConfiguredTableAssociationAnalysisRuleResponseSuccess, _CreateConfiguredTableAssociationResponseSuccess, _CreateConfiguredTableResponseSuccess, _CreateIdMappingTableResponseSuccess, _CreateIdNamespaceAssociationResponseSuccess, _CreateIntermediateTableAnalysisRuleResponseSuccess, _CreateIntermediateTableResponseSuccess, _CreateMembershipResponseSuccess, _CreatePrivacyBudgetTemplateResponseSuccess, _DeleteAnalysisTemplateResponseSuccess, _DeleteCollaborationResponseSuccess, _DeleteConfiguredAudienceModelAssociationResponseSuccess, _DeleteConfiguredTableAnalysisRuleResponseSuccess, _DeleteConfiguredTableAssociationAnalysisRuleResponseSuccess, _DeleteConfiguredTableAssociationResponseSuccess, _DeleteConfiguredTableResponseSuccess, _DeleteIdMappingTableResponseSuccess, _DeleteIdNamespaceAssociationResponseSuccess, _DeleteIntermediateTableAnalysisRuleResponseSuccess, _DeleteIntermediateTableResponseSuccess, _DeleteMemberResponseSuccess, _DeleteMembershipResponseSuccess, _DeletePrivacyBudgetTemplateResponseSuccess, _DisallowIntermediateTableResponseSuccess, _GetAnalysisLogExportResponseSuccess, _GetAnalysisTemplateResponseSuccess, _GetCollaborationAnalysisTemplateResponseSuccess, _GetCollaborationChangeRequestResponseSuccess, _GetCollaborationConfiguredAudienceModelAssociationResponseSuccess, _GetCollaborationIdNamespaceAssociationResponseSuccess, _GetCollaborationPrivacyBudgetTemplateResponseSuccess, _GetCollaborationResponseSuccess, _GetConfiguredAudienceModelAssociationResponseSuccess, _GetConfiguredTableAnalysisRuleResponseSuccess, _GetConfiguredTableAssociationAnalysisRuleResponseSuccess, _GetConfiguredTableAssociationResponseSuccess, _GetConfiguredTableResponseSuccess, _GetIdMappingTableResponseSuccess, _GetIdNamespaceAssociationResponseSuccess, _GetIntermediateTableAnalysisRuleResponseSuccess, _GetIntermediateTableResponseSuccess, _GetMembershipResponseSuccess, _GetPrivacyBudgetTemplateResponseSuccess, _GetProtectedJobResponseSuccess, _GetProtectedQueryResponseSuccess, _GetSchemaAnalysisRuleResponseSuccess, _GetSchemaResponseSuccess, _ListAnalysisLogExportsResponseSuccess, _ListAnalysisTemplatesResponseSuccess, _ListCollaborationAnalysisTemplatesResponseSuccess, _ListCollaborationChangeRequestsResponseSuccess, _ListCollaborationConfiguredAudienceModelAssociationsResponseSuccess, _ListCollaborationIdNamespaceAssociationsResponseSuccess, _ListCollaborationPrivacyBudgetTemplatesResponseSuccess, _ListCollaborationPrivacyBudgetsResponseSuccess, _ListCollaborationsResponseSuccess, _ListConfiguredAudienceModelAssociationsResponseSuccess, _ListConfiguredTableAssociationsResponseSuccess, _ListConfiguredTablesResponseSuccess, _ListIdMappingTablesResponseSuccess, _ListIdNamespaceAssociationsResponseSuccess, _ListIntermediateTableVersionsResponseSuccess, _ListIntermediateTablesResponseSuccess, _ListMembersResponseSuccess, _ListMembershipsResponseSuccess, _ListPrivacyBudgetTemplatesResponseSuccess, _ListPrivacyBudgetsResponseSuccess, _ListProtectedJobsResponseSuccess, _ListProtectedQueriesResponseSuccess, _ListSchemasResponseSuccess, _ListTagsForResourceResponseSuccess, _PopulateIdMappingTableResponseSuccess, _PopulateIntermediateTableResponseSuccess, _PreviewPrivacyImpactResponseSuccess, _StartAnalysisLogExportResponseSuccess, _StartProtectedJobResponseSuccess, _StartProtectedQueryResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAnalysisTemplateResponseSuccess, _UpdateCollaborationChangeRequestResponseSuccess, _UpdateCollaborationResponseSuccess, _UpdateConfiguredAudienceModelAssociationResponseSuccess, _UpdateConfiguredTableAnalysisRuleResponseSuccess, _UpdateConfiguredTableAssociationAnalysisRuleResponseSuccess, _UpdateConfiguredTableAssociationResponseSuccess, _UpdateConfiguredTableResponseSuccess, _UpdateIdMappingTableResponseSuccess, _UpdateIdNamespaceAssociationResponseSuccess, _UpdateIntermediateTableAnalysisRuleResponseSuccess, _UpdateIntermediateTableResponseSuccess, _UpdateMembershipResponseSuccess, _UpdatePrivacyBudgetTemplateResponseSuccess, _UpdateProtectedJobResponseSuccess, _UpdateProtectedQueryResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_collaboration_analysis_template(params = {}) ⇒ Types::BatchGetCollaborationAnalysisTemplateOutput
Retrieves multiple analysis templates within a collaboration by their Amazon Resource Names (ARNs).
-
#batch_get_schema(params = {}) ⇒ Types::BatchGetSchemaOutput
Retrieves multiple schemas by their identifiers.
-
#batch_get_schema_analysis_rule(params = {}) ⇒ Types::BatchGetSchemaAnalysisRuleOutput
Retrieves multiple analysis rule schemas.
-
#create_analysis_template(params = {}) ⇒ Types::CreateAnalysisTemplateOutput
Creates a new analysis template.
-
#create_collaboration(params = {}) ⇒ Types::CreateCollaborationOutput
Creates a new collaboration.
-
#create_collaboration_change_request(params = {}) ⇒ Types::CreateCollaborationChangeRequestOutput
Creates a new change request to modify an existing collaboration.
-
#create_configured_audience_model_association(params = {}) ⇒ Types::CreateConfiguredAudienceModelAssociationOutput
Provides the details necessary to create a configured audience model association.
-
#create_configured_table(params = {}) ⇒ Types::CreateConfiguredTableOutput
Creates a new configured table resource.
-
#create_configured_table_analysis_rule(params = {}) ⇒ Types::CreateConfiguredTableAnalysisRuleOutput
Creates a new analysis rule for a configured table.
-
#create_configured_table_association(params = {}) ⇒ Types::CreateConfiguredTableAssociationOutput
Creates a configured table association.
-
#create_configured_table_association_analysis_rule(params = {}) ⇒ Types::CreateConfiguredTableAssociationAnalysisRuleOutput
Creates a new analysis rule for an associated configured table.
-
#create_id_mapping_table(params = {}) ⇒ Types::CreateIdMappingTableOutput
Creates an ID mapping table.
-
#create_id_namespace_association(params = {}) ⇒ Types::CreateIdNamespaceAssociationOutput
Creates an ID namespace association.
-
#create_intermediate_table(params = {}) ⇒ Types::CreateIntermediateTableOutput
Creates an intermediate table in a membership.
-
#create_intermediate_table_analysis_rule(params = {}) ⇒ Types::CreateIntermediateTableAnalysisRuleOutput
Creates an analysis rule for an intermediate table.
-
#create_membership(params = {}) ⇒ Types::CreateMembershipOutput
Creates a membership for a specific collaboration identifier and joins the collaboration.
-
#create_privacy_budget_template(params = {}) ⇒ Types::CreatePrivacyBudgetTemplateOutput
Creates a privacy budget template for a specified collaboration.
-
#delete_analysis_template(params = {}) ⇒ Struct
Deletes an analysis template.
-
#delete_collaboration(params = {}) ⇒ Struct
Deletes a collaboration.
-
#delete_configured_audience_model_association(params = {}) ⇒ Struct
Provides the information necessary to delete a configured audience model association.
-
#delete_configured_table(params = {}) ⇒ Struct
Deletes a configured table.
-
#delete_configured_table_analysis_rule(params = {}) ⇒ Struct
Deletes a configured table analysis rule.
-
#delete_configured_table_association(params = {}) ⇒ Struct
Deletes a configured table association.
-
#delete_configured_table_association_analysis_rule(params = {}) ⇒ Struct
Deletes an analysis rule for a configured table association.
-
#delete_id_mapping_table(params = {}) ⇒ Struct
Deletes an ID mapping table.
-
#delete_id_namespace_association(params = {}) ⇒ Struct
Deletes an ID namespace association.
-
#delete_intermediate_table(params = {}) ⇒ Struct
Deletes an intermediate table.
-
#delete_intermediate_table_analysis_rule(params = {}) ⇒ Struct
Deletes an analysis rule from an intermediate table.
-
#delete_member(params = {}) ⇒ Struct
Removes the specified member from a collaboration.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a specified membership.
-
#delete_privacy_budget_template(params = {}) ⇒ Struct
Deletes a privacy budget template for a specified collaboration.
-
#disallow_intermediate_table(params = {}) ⇒ Struct
Marks an intermediate table as invalid when it references the caller's base table.
-
#get_analysis_log_export(params = {}) ⇒ Types::GetAnalysisLogExportOutput
Returns information about an analysis log export, including its current status and, if the export failed, the reason for the failure.
-
#get_analysis_template(params = {}) ⇒ Types::GetAnalysisTemplateOutput
Retrieves an analysis template.
-
#get_collaboration(params = {}) ⇒ Types::GetCollaborationOutput
Returns metadata about a collaboration.
-
#get_collaboration_analysis_template(params = {}) ⇒ Types::GetCollaborationAnalysisTemplateOutput
Retrieves an analysis template within a collaboration.
-
#get_collaboration_change_request(params = {}) ⇒ Types::GetCollaborationChangeRequestOutput
Retrieves detailed information about a specific collaboration change request.
-
#get_collaboration_configured_audience_model_association(params = {}) ⇒ Types::GetCollaborationConfiguredAudienceModelAssociationOutput
Retrieves a configured audience model association within a collaboration.
-
#get_collaboration_id_namespace_association(params = {}) ⇒ Types::GetCollaborationIdNamespaceAssociationOutput
Retrieves an ID namespace association from a specific collaboration.
-
#get_collaboration_privacy_budget_template(params = {}) ⇒ Types::GetCollaborationPrivacyBudgetTemplateOutput
Returns details about a specified privacy budget template.
-
#get_configured_audience_model_association(params = {}) ⇒ Types::GetConfiguredAudienceModelAssociationOutput
Returns information about a configured audience model association.
-
#get_configured_table(params = {}) ⇒ Types::GetConfiguredTableOutput
Retrieves a configured table.
-
#get_configured_table_analysis_rule(params = {}) ⇒ Types::GetConfiguredTableAnalysisRuleOutput
Retrieves a configured table analysis rule.
-
#get_configured_table_association(params = {}) ⇒ Types::GetConfiguredTableAssociationOutput
Retrieves a configured table association.
-
#get_configured_table_association_analysis_rule(params = {}) ⇒ Types::GetConfiguredTableAssociationAnalysisRuleOutput
Retrieves the analysis rule for a configured table association.
-
#get_id_mapping_table(params = {}) ⇒ Types::GetIdMappingTableOutput
Retrieves an ID mapping table.
-
#get_id_namespace_association(params = {}) ⇒ Types::GetIdNamespaceAssociationOutput
Retrieves an ID namespace association.
-
#get_intermediate_table(params = {}) ⇒ Types::GetIntermediateTableOutput
Retrieves an intermediate table.
-
#get_intermediate_table_analysis_rule(params = {}) ⇒ Types::GetIntermediateTableAnalysisRuleOutput
Retrieves the analysis rule for an intermediate table.
-
#get_membership(params = {}) ⇒ Types::GetMembershipOutput
Retrieves a specified membership for an identifier.
-
#get_privacy_budget_template(params = {}) ⇒ Types::GetPrivacyBudgetTemplateOutput
Returns details for a specified privacy budget template.
-
#get_protected_job(params = {}) ⇒ Types::GetProtectedJobOutput
Returns job processing metadata.
-
#get_protected_query(params = {}) ⇒ Types::GetProtectedQueryOutput
Returns query processing metadata.
-
#get_schema(params = {}) ⇒ Types::GetSchemaOutput
Retrieves the schema for a relation within a collaboration.
-
#get_schema_analysis_rule(params = {}) ⇒ Types::GetSchemaAnalysisRuleOutput
Retrieves a schema analysis rule.
-
#list_analysis_log_exports(params = {}) ⇒ Types::ListAnalysisLogExportsOutput
Lists analysis log exports, sorted by the most recent export.
-
#list_analysis_templates(params = {}) ⇒ Types::ListAnalysisTemplatesOutput
Lists analysis templates that the caller owns.
-
#list_collaboration_analysis_templates(params = {}) ⇒ Types::ListCollaborationAnalysisTemplatesOutput
Lists analysis templates within a collaboration.
-
#list_collaboration_change_requests(params = {}) ⇒ Types::ListCollaborationChangeRequestsOutput
Lists all change requests for a collaboration with pagination support.
-
#list_collaboration_configured_audience_model_associations(params = {}) ⇒ Types::ListCollaborationConfiguredAudienceModelAssociationsOutput
Lists configured audience model associations within a collaboration.
-
#list_collaboration_id_namespace_associations(params = {}) ⇒ Types::ListCollaborationIdNamespaceAssociationsOutput
Returns a list of the ID namespace associations in a collaboration.
-
#list_collaboration_privacy_budget_templates(params = {}) ⇒ Types::ListCollaborationPrivacyBudgetTemplatesOutput
Returns an array that summarizes each privacy budget template in a specified collaboration.
-
#list_collaboration_privacy_budgets(params = {}) ⇒ Types::ListCollaborationPrivacyBudgetsOutput
Returns an array that summarizes each privacy budget in a specified collaboration.
-
#list_collaborations(params = {}) ⇒ Types::ListCollaborationsOutput
Lists collaborations the caller owns, is active in, or has been invited to.
-
#list_configured_audience_model_associations(params = {}) ⇒ Types::ListConfiguredAudienceModelAssociationsOutput
Lists information about requested configured audience model associations.
-
#list_configured_table_associations(params = {}) ⇒ Types::ListConfiguredTableAssociationsOutput
Lists configured table associations for a membership.
-
#list_configured_tables(params = {}) ⇒ Types::ListConfiguredTablesOutput
Lists configured tables.
-
#list_id_mapping_tables(params = {}) ⇒ Types::ListIdMappingTablesOutput
Returns a list of ID mapping tables.
-
#list_id_namespace_associations(params = {}) ⇒ Types::ListIdNamespaceAssociationsOutput
Returns a list of ID namespace associations.
-
#list_intermediate_table_versions(params = {}) ⇒ Types::ListIntermediateTableVersionsOutput
Lists the version history of an intermediate table.
-
#list_intermediate_tables(params = {}) ⇒ Types::ListIntermediateTablesOutput
Lists intermediate tables owned by the caller in a membership.
-
#list_members(params = {}) ⇒ Types::ListMembersOutput
Lists all members within a collaboration.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsOutput
Lists all memberships resources within the caller's account.
-
#list_privacy_budget_templates(params = {}) ⇒ Types::ListPrivacyBudgetTemplatesOutput
Returns detailed information about the privacy budget templates in a specified membership.
-
#list_privacy_budgets(params = {}) ⇒ Types::ListPrivacyBudgetsOutput
Returns detailed information about the privacy budgets in a specified membership.
-
#list_protected_jobs(params = {}) ⇒ Types::ListProtectedJobsOutput
Lists protected jobs, sorted by most recent job.
-
#list_protected_queries(params = {}) ⇒ Types::ListProtectedQueriesOutput
Lists protected queries, sorted by the most recent query.
-
#list_schemas(params = {}) ⇒ Types::ListSchemasOutput
Lists the schemas for relations within a collaboration.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all of the tags that have been added to a resource.
-
#populate_id_mapping_table(params = {}) ⇒ Types::PopulateIdMappingTableOutput
Defines the information that's necessary to populate an ID mapping table.
-
#populate_intermediate_table(params = {}) ⇒ Types::PopulateIntermediateTableOutput
Runs the stored query of an intermediate table and makes the results available for querying.
-
#preview_privacy_impact(params = {}) ⇒ Types::PreviewPrivacyImpactOutput
An estimate of the number of aggregation functions that the member who can query can run given epsilon and noise parameters.
-
#start_analysis_log_export(params = {}) ⇒ Types::StartAnalysisLogExportOutput
Starts an export of the Apache Spark logs for a protected query to an Amazon S3 bucket that you own.
-
#start_protected_job(params = {}) ⇒ Types::StartProtectedJobOutput
Creates a protected job that is started by Clean Rooms.
-
#start_protected_query(params = {}) ⇒ Types::StartProtectedQueryOutput
Creates a protected query that is started by Clean Rooms.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource.
-
#update_analysis_template(params = {}) ⇒ Types::UpdateAnalysisTemplateOutput
Updates the analysis template metadata.
-
#update_collaboration(params = {}) ⇒ Types::UpdateCollaborationOutput
Updates collaboration metadata and can only be called by the collaboration owner.
-
#update_collaboration_change_request(params = {}) ⇒ Types::UpdateCollaborationChangeRequestOutput
Updates an existing collaboration change request.
-
#update_configured_audience_model_association(params = {}) ⇒ Types::UpdateConfiguredAudienceModelAssociationOutput
Provides the details necessary to update a configured audience model association.
-
#update_configured_table(params = {}) ⇒ Types::UpdateConfiguredTableOutput
Updates a configured table.
-
#update_configured_table_analysis_rule(params = {}) ⇒ Types::UpdateConfiguredTableAnalysisRuleOutput
Updates a configured table analysis rule.
-
#update_configured_table_association(params = {}) ⇒ Types::UpdateConfiguredTableAssociationOutput
Updates a configured table association.
-
#update_configured_table_association_analysis_rule(params = {}) ⇒ Types::UpdateConfiguredTableAssociationAnalysisRuleOutput
Updates the analysis rule for a configured table association.
-
#update_id_mapping_table(params = {}) ⇒ Types::UpdateIdMappingTableOutput
Provides the details that are necessary to update an ID mapping table.
-
#update_id_namespace_association(params = {}) ⇒ Types::UpdateIdNamespaceAssociationOutput
Provides the details that are necessary to update an ID namespace association.
-
#update_intermediate_table(params = {}) ⇒ Types::UpdateIntermediateTableOutput
Updates an intermediate table.
-
#update_intermediate_table_analysis_rule(params = {}) ⇒ Types::UpdateIntermediateTableAnalysisRuleOutput
Updates the analysis rule policy for an intermediate table.
-
#update_membership(params = {}) ⇒ Types::UpdateMembershipOutput
Updates a membership.
-
#update_privacy_budget_template(params = {}) ⇒ Types::UpdatePrivacyBudgetTemplateOutput
Updates the privacy budget template for the specified collaboration.
-
#update_protected_job(params = {}) ⇒ Types::UpdateProtectedJobOutput
Updates the processing of a currently running job.
-
#update_protected_query(params = {}) ⇒ Types::UpdateProtectedQueryOutput
Updates the processing of a currently running query.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cleanrooms/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7478 7479 7480 |
# File 'lib/aws-sdk-cleanrooms/client.rb', line 7478 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7481 7482 7483 |
# File 'lib/aws-sdk-cleanrooms/client.rb', line 7481 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_collaboration_analysis_template(params = {}) ⇒ Types::BatchGetCollaborationAnalysisTemplateOutput
Retrieves multiple analysis templates within a collaboration by their Amazon Resource Names (ARNs).
87 |
# File 'sig/client.rbs', line 87
def batch_get_collaboration_analysis_template: (
|
#batch_get_schema(params = {}) ⇒ Types::BatchGetSchemaOutput
Retrieves multiple schemas by their identifiers.
99 |
# File 'sig/client.rbs', line 99
def batch_get_schema: (
|
#batch_get_schema_analysis_rule(params = {}) ⇒ Types::BatchGetSchemaAnalysisRuleOutput
Retrieves multiple analysis rule schemas.
111 |
# File 'sig/client.rbs', line 111
def batch_get_schema_analysis_rule: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 |
# File 'lib/aws-sdk-cleanrooms/client.rb', line 7451 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CleanRooms') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cleanrooms' context[:gem_version] = '1.78.0' Seahorse::Client::Request.new(handlers, context) end |
#create_analysis_template(params = {}) ⇒ Types::CreateAnalysisTemplateOutput
Creates a new analysis template.
127 |
# File 'sig/client.rbs', line 127
def create_analysis_template: (
|
#create_collaboration(params = {}) ⇒ Types::CreateCollaborationOutput
Creates a new collaboration.
189 |
# File 'sig/client.rbs', line 189
def create_collaboration: (
|
#create_collaboration_change_request(params = {}) ⇒ Types::CreateCollaborationChangeRequestOutput
Creates a new change request to modify an existing collaboration. This enables post-creation modifications to collaborations through a structured API-driven approach.
230 |
# File 'sig/client.rbs', line 230
def create_collaboration_change_request: (
|
#create_configured_audience_model_association(params = {}) ⇒ Types::CreateConfiguredAudienceModelAssociationOutput
Provides the details necessary to create a configured audience model association.
259 |
# File 'sig/client.rbs', line 259
def create_configured_audience_model_association: (
|
#create_configured_table(params = {}) ⇒ Types::CreateConfiguredTableOutput
Creates a new configured table resource.
274 |
# File 'sig/client.rbs', line 274
def create_configured_table: (
|
#create_configured_table_analysis_rule(params = {}) ⇒ Types::CreateConfiguredTableAnalysisRuleOutput
Creates a new analysis rule for a configured table. Currently, only one analysis rule can be created for a given configured table.
290 |
# File 'sig/client.rbs', line 290
def create_configured_table_analysis_rule: (
|
#create_configured_table_association(params = {}) ⇒ Types::CreateConfiguredTableAssociationOutput
Creates a configured table association. A configured table association links a configured table with a collaboration.
302 |
# File 'sig/client.rbs', line 302
def create_configured_table_association: (
|
#create_configured_table_association_analysis_rule(params = {}) ⇒ Types::CreateConfiguredTableAssociationAnalysisRuleOutput
Creates a new analysis rule for an associated configured table.
317 |
# File 'sig/client.rbs', line 317
def create_configured_table_association_analysis_rule: (
|
#create_id_mapping_table(params = {}) ⇒ Types::CreateIdMappingTableOutput
Creates an ID mapping table.
330 |
# File 'sig/client.rbs', line 330
def create_id_mapping_table: (
|
#create_id_namespace_association(params = {}) ⇒ Types::CreateIdNamespaceAssociationOutput
Creates an ID namespace association.
348 |
# File 'sig/client.rbs', line 348
def create_id_namespace_association: (
|
#create_intermediate_table(params = {}) ⇒ Types::CreateIntermediateTableOutput
Creates an intermediate table in a membership. The intermediate table
is owned by the member with the CAN_QUERY ability. To populate the
table with results, use PopulateIntermediateTable.
368 |
# File 'sig/client.rbs', line 368
def create_intermediate_table: (
|
#create_intermediate_table_analysis_rule(params = {}) ⇒ Types::CreateIntermediateTableAnalysisRuleOutput
Creates an analysis rule for an intermediate table. Only the CUSTOM analysis rule type is supported. Only the intermediate table owner can call this operation.
389 |
# File 'sig/client.rbs', line 389
def create_intermediate_table_analysis_rule: (
|
#create_membership(params = {}) ⇒ Types::CreateMembershipOutput
Creates a membership for a specific collaboration identifier and joins the collaboration.
402 |
# File 'sig/client.rbs', line 402
def create_membership: (
|
#create_privacy_budget_template(params = {}) ⇒ Types::CreatePrivacyBudgetTemplateOutput
Creates a privacy budget template for a specified collaboration. Each collaboration can have only one privacy budget template. If you need to change the privacy budget template, use the UpdatePrivacyBudgetTemplate operation.
427 |
# File 'sig/client.rbs', line 427
def create_privacy_budget_template: (
|
#delete_analysis_template(params = {}) ⇒ Struct
Deletes an analysis template.
455 |
# File 'sig/client.rbs', line 455
def delete_analysis_template: (
|
#delete_collaboration(params = {}) ⇒ Struct
Deletes a collaboration. It can only be called by the collaboration owner.
465 |
# File 'sig/client.rbs', line 465
def delete_collaboration: (
|
#delete_configured_audience_model_association(params = {}) ⇒ Struct
Provides the information necessary to delete a configured audience model association.
474 |
# File 'sig/client.rbs', line 474
def delete_configured_audience_model_association: (
|
#delete_configured_table(params = {}) ⇒ Struct
Deletes a configured table.
484 |
# File 'sig/client.rbs', line 484
def delete_configured_table: (
|
#delete_configured_table_analysis_rule(params = {}) ⇒ Struct
Deletes a configured table analysis rule.
493 |
# File 'sig/client.rbs', line 493
def delete_configured_table_analysis_rule: (
|
#delete_configured_table_association(params = {}) ⇒ Struct
Deletes a configured table association.
503 |
# File 'sig/client.rbs', line 503
def delete_configured_table_association: (
|
#delete_configured_table_association_analysis_rule(params = {}) ⇒ Struct
Deletes an analysis rule for a configured table association.
513 |
# File 'sig/client.rbs', line 513
def delete_configured_table_association_analysis_rule: (
|
#delete_id_mapping_table(params = {}) ⇒ Struct
Deletes an ID mapping table.
524 |
# File 'sig/client.rbs', line 524
def delete_id_mapping_table: (
|
#delete_id_namespace_association(params = {}) ⇒ Struct
Deletes an ID namespace association.
534 |
# File 'sig/client.rbs', line 534
def delete_id_namespace_association: (
|
#delete_intermediate_table(params = {}) ⇒ Struct
Deletes an intermediate table. The delete is idempotent. Only the intermediate table owner can call this operation.
544 |
# File 'sig/client.rbs', line 544
def delete_intermediate_table: (
|
#delete_intermediate_table_analysis_rule(params = {}) ⇒ Struct
Deletes an analysis rule from an intermediate table. After the analysis rule is deleted, the intermediate table becomes unqueryable until a new analysis rule is attached. Only the intermediate table owner can call this operation.
554 |
# File 'sig/client.rbs', line 554
def delete_intermediate_table_analysis_rule: (
|
#delete_member(params = {}) ⇒ Struct
Removes the specified member from a collaboration. The removed member is placed in the Removed status and can't interact with the collaboration. The removed member's data is inaccessible to active members of the collaboration.
565 |
# File 'sig/client.rbs', line 565
def delete_member: (
|
#delete_membership(params = {}) ⇒ Struct
Deletes a specified membership. All resources under a membership must be deleted.
575 |
# File 'sig/client.rbs', line 575
def delete_membership: (
|
#delete_privacy_budget_template(params = {}) ⇒ Struct
Deletes a privacy budget template for a specified collaboration.
584 |
# File 'sig/client.rbs', line 584
def delete_privacy_budget_template: (
|
#disallow_intermediate_table(params = {}) ⇒ Struct
Marks an intermediate table as invalid when it references the caller's base table. The data provider (base table owner) calls this operation, not the intermediate table owner. By default, the operation also marks all descendant intermediate tables as invalid.
594 |
# File 'sig/client.rbs', line 594
def disallow_intermediate_table: (
|
#get_analysis_log_export(params = {}) ⇒ Types::GetAnalysisLogExportOutput
Returns information about an analysis log export, including its current status and, if the export failed, the reason for the failure.
Poll this operation until the status is SUCCESS or FAILED. An
export can't be canceled after it starts.
606 |
# File 'sig/client.rbs', line 606
def get_analysis_log_export: (
|
#get_analysis_template(params = {}) ⇒ Types::GetAnalysisTemplateOutput
Retrieves an analysis template.
617 |
# File 'sig/client.rbs', line 617
def get_analysis_template: (
|
#get_collaboration(params = {}) ⇒ Types::GetCollaborationOutput
Returns metadata about a collaboration.
628 |
# File 'sig/client.rbs', line 628
def get_collaboration: (
|
#get_collaboration_analysis_template(params = {}) ⇒ Types::GetCollaborationAnalysisTemplateOutput
Retrieves an analysis template within a collaboration.
638 |
# File 'sig/client.rbs', line 638
def get_collaboration_analysis_template: (
|
#get_collaboration_change_request(params = {}) ⇒ Types::GetCollaborationChangeRequestOutput
Retrieves detailed information about a specific collaboration change request.
649 |
# File 'sig/client.rbs', line 649
def get_collaboration_change_request: (
|
#get_collaboration_configured_audience_model_association(params = {}) ⇒ Types::GetCollaborationConfiguredAudienceModelAssociationOutput
Retrieves a configured audience model association within a collaboration.
660 |
# File 'sig/client.rbs', line 660
def get_collaboration_configured_audience_model_association: (
|
#get_collaboration_id_namespace_association(params = {}) ⇒ Types::GetCollaborationIdNamespaceAssociationOutput
Retrieves an ID namespace association from a specific collaboration.
671 |
# File 'sig/client.rbs', line 671
def get_collaboration_id_namespace_association: (
|
#get_collaboration_privacy_budget_template(params = {}) ⇒ Types::GetCollaborationPrivacyBudgetTemplateOutput
Returns details about a specified privacy budget template.
682 |
# File 'sig/client.rbs', line 682
def get_collaboration_privacy_budget_template: (
|
#get_configured_audience_model_association(params = {}) ⇒ Types::GetConfiguredAudienceModelAssociationOutput
Returns information about a configured audience model association.
693 |
# File 'sig/client.rbs', line 693
def get_configured_audience_model_association: (
|
#get_configured_table(params = {}) ⇒ Types::GetConfiguredTableOutput
Retrieves a configured table.
704 |
# File 'sig/client.rbs', line 704
def get_configured_table: (
|
#get_configured_table_analysis_rule(params = {}) ⇒ Types::GetConfiguredTableAnalysisRuleOutput
Retrieves a configured table analysis rule.
714 |
# File 'sig/client.rbs', line 714
def get_configured_table_analysis_rule: (
|
#get_configured_table_association(params = {}) ⇒ Types::GetConfiguredTableAssociationOutput
Retrieves a configured table association.
725 |
# File 'sig/client.rbs', line 725
def get_configured_table_association: (
|
#get_configured_table_association_analysis_rule(params = {}) ⇒ Types::GetConfiguredTableAssociationAnalysisRuleOutput
Retrieves the analysis rule for a configured table association.
736 |
# File 'sig/client.rbs', line 736
def get_configured_table_association_analysis_rule: (
|
#get_id_mapping_table(params = {}) ⇒ Types::GetIdMappingTableOutput
Retrieves an ID mapping table.
748 |
# File 'sig/client.rbs', line 748
def get_id_mapping_table: (
|
#get_id_namespace_association(params = {}) ⇒ Types::GetIdNamespaceAssociationOutput
Retrieves an ID namespace association.
759 |
# File 'sig/client.rbs', line 759
def get_id_namespace_association: (
|
#get_intermediate_table(params = {}) ⇒ Types::GetIntermediateTableOutput
Retrieves an intermediate table. Returns the full details of the intermediate table, including schema, table dependencies, inherited constraints, child resources, and status. Only the intermediate table owner can call this operation.
770 |
# File 'sig/client.rbs', line 770
def get_intermediate_table: (
|
#get_intermediate_table_analysis_rule(params = {}) ⇒ Types::GetIntermediateTableAnalysisRuleOutput
Retrieves the analysis rule for an intermediate table.
781 |
# File 'sig/client.rbs', line 781
def get_intermediate_table_analysis_rule: (
|
#get_membership(params = {}) ⇒ Types::GetMembershipOutput
Retrieves a specified membership for an identifier.
793 |
# File 'sig/client.rbs', line 793
def get_membership: (
|
#get_privacy_budget_template(params = {}) ⇒ Types::GetPrivacyBudgetTemplateOutput
Returns details for a specified privacy budget template.
803 |
# File 'sig/client.rbs', line 803
def get_privacy_budget_template: (
|
#get_protected_job(params = {}) ⇒ Types::GetProtectedJobOutput
Returns job processing metadata.
814 |
# File 'sig/client.rbs', line 814
def get_protected_job: (
|
#get_protected_query(params = {}) ⇒ Types::GetProtectedQueryOutput
Returns query processing metadata.
825 |
# File 'sig/client.rbs', line 825
def get_protected_query: (
|
#get_schema(params = {}) ⇒ Types::GetSchemaOutput
Retrieves the schema for a relation within a collaboration.
836 |
# File 'sig/client.rbs', line 836
def get_schema: (
|
#get_schema_analysis_rule(params = {}) ⇒ Types::GetSchemaAnalysisRuleOutput
Retrieves a schema analysis rule.
847 |
# File 'sig/client.rbs', line 847
def get_schema_analysis_rule: (
|
#list_analysis_log_exports(params = {}) ⇒ Types::ListAnalysisLogExportsOutput
Lists analysis log exports, sorted by the most recent export. Results
are paginated. Use the nextToken parameter to retrieve additional
results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
860 |
# File 'sig/client.rbs', line 860
def list_analysis_log_exports: (
|
#list_analysis_templates(params = {}) ⇒ Types::ListAnalysisTemplatesOutput
Lists analysis templates that the caller owns.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
875 |
# File 'sig/client.rbs', line 875
def list_analysis_templates: (
|
#list_collaboration_analysis_templates(params = {}) ⇒ Types::ListCollaborationAnalysisTemplatesOutput
Lists analysis templates within a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
888 |
# File 'sig/client.rbs', line 888
def list_collaboration_analysis_templates: (
|
#list_collaboration_change_requests(params = {}) ⇒ Types::ListCollaborationChangeRequestsOutput
Lists all change requests for a collaboration with pagination support. Returns change requests sorted by creation time.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
901 |
# File 'sig/client.rbs', line 901
def list_collaboration_change_requests: (
|
#list_collaboration_configured_audience_model_associations(params = {}) ⇒ Types::ListCollaborationConfiguredAudienceModelAssociationsOutput
Lists configured audience model associations within a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
915 |
# File 'sig/client.rbs', line 915
def list_collaboration_configured_audience_model_associations: (
|
#list_collaboration_id_namespace_associations(params = {}) ⇒ Types::ListCollaborationIdNamespaceAssociationsOutput
Returns a list of the ID namespace associations in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
928 |
# File 'sig/client.rbs', line 928
def list_collaboration_id_namespace_associations: (
|
#list_collaboration_privacy_budget_templates(params = {}) ⇒ Types::ListCollaborationPrivacyBudgetTemplatesOutput
Returns an array that summarizes each privacy budget template in a specified collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
941 |
# File 'sig/client.rbs', line 941
def list_collaboration_privacy_budget_templates: (
|
#list_collaboration_privacy_budgets(params = {}) ⇒ Types::ListCollaborationPrivacyBudgetsOutput
Returns an array that summarizes each privacy budget in a specified collaboration. The summary includes the collaboration ARN, creation time, creating account, and privacy budget details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
954 |
# File 'sig/client.rbs', line 954
def list_collaboration_privacy_budgets: (
|
#list_collaborations(params = {}) ⇒ Types::ListCollaborationsOutput
Lists collaborations the caller owns, is active in, or has been invited to.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
969 |
# File 'sig/client.rbs', line 969
def list_collaborations: (
|
#list_configured_audience_model_associations(params = {}) ⇒ Types::ListConfiguredAudienceModelAssociationsOutput
Lists information about requested configured audience model associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
982 |
# File 'sig/client.rbs', line 982
def list_configured_audience_model_associations: (
|
#list_configured_table_associations(params = {}) ⇒ Types::ListConfiguredTableAssociationsOutput
Lists configured table associations for a membership.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
995 |
# File 'sig/client.rbs', line 995
def list_configured_table_associations: (
|
#list_configured_tables(params = {}) ⇒ Types::ListConfiguredTablesOutput
Lists configured tables.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1008 |
# File 'sig/client.rbs', line 1008
def list_configured_tables: (
|
#list_id_mapping_tables(params = {}) ⇒ Types::ListIdMappingTablesOutput
Returns a list of ID mapping tables.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1020 |
# File 'sig/client.rbs', line 1020
def list_id_mapping_tables: (
|
#list_id_namespace_associations(params = {}) ⇒ Types::ListIdNamespaceAssociationsOutput
Returns a list of ID namespace associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1033 |
# File 'sig/client.rbs', line 1033
def list_id_namespace_associations: (
|
#list_intermediate_table_versions(params = {}) ⇒ Types::ListIntermediateTableVersionsOutput
Lists the version history of an intermediate table. Each call to
PopulateIntermediateTable creates a new version. We recommend using
pagination to ensure that the operation returns quickly and
successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1046 |
# File 'sig/client.rbs', line 1046
def list_intermediate_table_versions: (
|
#list_intermediate_tables(params = {}) ⇒ Types::ListIntermediateTablesOutput
Lists intermediate tables owned by the caller in a membership. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1060 |
# File 'sig/client.rbs', line 1060
def list_intermediate_tables: (
|
#list_members(params = {}) ⇒ Types::ListMembersOutput
Lists all members within a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1073 |
# File 'sig/client.rbs', line 1073
def list_members: (
|
#list_memberships(params = {}) ⇒ Types::ListMembershipsOutput
Lists all memberships resources within the caller's account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1086 |
# File 'sig/client.rbs', line 1086
def list_memberships: (
|
#list_privacy_budget_templates(params = {}) ⇒ Types::ListPrivacyBudgetTemplatesOutput
Returns detailed information about the privacy budget templates in a specified membership.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1099 |
# File 'sig/client.rbs', line 1099
def list_privacy_budget_templates: (
|
#list_privacy_budgets(params = {}) ⇒ Types::ListPrivacyBudgetsOutput
Returns detailed information about the privacy budgets in a specified membership.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1112 |
# File 'sig/client.rbs', line 1112
def list_privacy_budgets: (
|
#list_protected_jobs(params = {}) ⇒ Types::ListProtectedJobsOutput
Lists protected jobs, sorted by most recent job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1127 |
# File 'sig/client.rbs', line 1127
def list_protected_jobs: (
|
#list_protected_queries(params = {}) ⇒ Types::ListProtectedQueriesOutput
Lists protected queries, sorted by the most recent query.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1141 |
# File 'sig/client.rbs', line 1141
def list_protected_queries: (
|
#list_schemas(params = {}) ⇒ Types::ListSchemasOutput
Lists the schemas for relations within a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1155 |
# File 'sig/client.rbs', line 1155
def list_schemas: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all of the tags that have been added to a resource.
1168 |
# File 'sig/client.rbs', line 1168
def list_tags_for_resource: (
|
#populate_id_mapping_table(params = {}) ⇒ Types::PopulateIdMappingTableOutput
Defines the information that's necessary to populate an ID mapping table.
1178 |
# File 'sig/client.rbs', line 1178
def populate_id_mapping_table: (
|
#populate_intermediate_table(params = {}) ⇒ Types::PopulateIntermediateTableOutput
Runs the stored query of an intermediate table and makes the results
available for querying. Each call creates a new version. Use
GetProtectedQuery with the returned analysis ID to track progress.
Only the intermediate table owner can call this operation.
1192 |
# File 'sig/client.rbs', line 1192
def populate_intermediate_table: (
|
#preview_privacy_impact(params = {}) ⇒ Types::PreviewPrivacyImpactOutput
An estimate of the number of aggregation functions that the member who can query can run given epsilon and noise parameters.
1214 |
# File 'sig/client.rbs', line 1214
def preview_privacy_impact: (
|
#start_analysis_log_export(params = {}) ⇒ Types::StartAnalysisLogExportOutput
Starts an export of the Apache Spark logs for a protected query to an Amazon S3 bucket that you own. Use the exported logs to diagnose a query that failed or that ran more slowly than you expected.
Clean Rooms exports a redacted copy of the Spark logs instead of the raw logs. Analyze the exported logs with the tooling of your choice, such as Spark History Server. For details about what the exported logs contain, see https://docs.aws.amazon.com/clean-rooms/latest/userguide/export-analysis-logs-contents.html.
The export runs asynchronously and returns with a status of
IN_PROGRESS. Call GetAnalysisLogExport to poll for the final
status.
To use this operation, you must have the
CAN_EXPORT_QUERY_ANALYSIS_LOG ability for your membership. You must
also be the query runner or the query payer. Having the ability alone
is not sufficient.
The query must have reached a terminal state, and it must have reached the execution stage. A query that failed validation or that was canceled before it started produces no Spark logs.
Log export isn't supported for queries that use differential privacy, and isn't supported for PySpark jobs.
The destination bucket must be in the same Amazon Web Services Region as the collaboration. Cross-Region export isn't supported.
For more information, see https://docs.aws.amazon.com/clean-rooms/latest/userguide/export-analysis-logs.html.
1230 |
# File 'sig/client.rbs', line 1230
def start_analysis_log_export: (
|
#start_protected_job(params = {}) ⇒ Types::StartProtectedJobOutput
Creates a protected job that is started by Clean Rooms.
1250 |
# File 'sig/client.rbs', line 1250
def start_protected_job: (
|
#start_protected_query(params = {}) ⇒ Types::StartProtectedQueryOutput
Creates a protected query that is started by Clean Rooms.
1282 |
# File 'sig/client.rbs', line 1282
def start_protected_query: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a resource.
1340 |
# File 'sig/client.rbs', line 1340
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource.
1350 |
# File 'sig/client.rbs', line 1350
def untag_resource: (
|
#update_analysis_template(params = {}) ⇒ Types::UpdateAnalysisTemplateOutput
Updates the analysis template metadata.
1361 |
# File 'sig/client.rbs', line 1361
def update_analysis_template: (
|
#update_collaboration(params = {}) ⇒ Types::UpdateCollaborationOutput
Updates collaboration metadata and can only be called by the collaboration owner.
1373 |
# File 'sig/client.rbs', line 1373
def update_collaboration: (
|
#update_collaboration_change_request(params = {}) ⇒ Types::UpdateCollaborationChangeRequestOutput
Updates an existing collaboration change request. This operation allows approval actions for pending change requests in collaborations (APPROVE, DENY, CANCEL, COMMIT).
For change requests without automatic approval, a member in the collaboration can manually APPROVE or DENY a change request. The collaboration owner can manually CANCEL or COMMIT a change request.
1386 |
# File 'sig/client.rbs', line 1386
def update_collaboration_change_request: (
|
#update_configured_audience_model_association(params = {}) ⇒ Types::UpdateConfiguredAudienceModelAssociationOutput
Provides the details necessary to update a configured audience model association.
1398 |
# File 'sig/client.rbs', line 1398
def update_configured_audience_model_association: (
|
#update_configured_table(params = {}) ⇒ Types::UpdateConfiguredTableOutput
Updates a configured table.
1411 |
# File 'sig/client.rbs', line 1411
def update_configured_table: (
|
#update_configured_table_analysis_rule(params = {}) ⇒ Types::UpdateConfiguredTableAnalysisRuleOutput
Updates a configured table analysis rule.
1427 |
# File 'sig/client.rbs', line 1427
def update_configured_table_analysis_rule: (
|
#update_configured_table_association(params = {}) ⇒ Types::UpdateConfiguredTableAssociationOutput
Updates a configured table association.
1439 |
# File 'sig/client.rbs', line 1439
def update_configured_table_association: (
|
#update_configured_table_association_analysis_rule(params = {}) ⇒ Types::UpdateConfiguredTableAssociationAnalysisRuleOutput
Updates the analysis rule for a configured table association.
1452 |
# File 'sig/client.rbs', line 1452
def update_configured_table_association_analysis_rule: (
|
#update_id_mapping_table(params = {}) ⇒ Types::UpdateIdMappingTableOutput
Provides the details that are necessary to update an ID mapping table.
1465 |
# File 'sig/client.rbs', line 1465
def update_id_mapping_table: (
|
#update_id_namespace_association(params = {}) ⇒ Types::UpdateIdNamespaceAssociationOutput
Provides the details that are necessary to update an ID namespace association.
1478 |
# File 'sig/client.rbs', line 1478
def update_id_namespace_association: (
|
#update_intermediate_table(params = {}) ⇒ Types::UpdateIntermediateTableOutput
Updates an intermediate table. You can update the description, KMS key ARN, and column types of existing columns. Only the intermediate table owner can call this operation.
1494 |
# File 'sig/client.rbs', line 1494
def update_intermediate_table: (
|
#update_intermediate_table_analysis_rule(params = {}) ⇒ Types::UpdateIntermediateTableAnalysisRuleOutput
Updates the analysis rule policy for an intermediate table. Only the intermediate table owner can call this operation.
1513 |
# File 'sig/client.rbs', line 1513
def update_intermediate_table_analysis_rule: (
|
#update_membership(params = {}) ⇒ Types::UpdateMembershipOutput
Updates a membership.
1526 |
# File 'sig/client.rbs', line 1526
def update_membership: (
|
#update_privacy_budget_template(params = {}) ⇒ Types::UpdatePrivacyBudgetTemplateOutput
Updates the privacy budget template for the specified collaboration.
1549 |
# File 'sig/client.rbs', line 1549
def update_privacy_budget_template: (
|
#update_protected_job(params = {}) ⇒ Types::UpdateProtectedJobOutput
Updates the processing of a currently running job.
1576 |
# File 'sig/client.rbs', line 1576
def update_protected_job: (
|
#update_protected_query(params = {}) ⇒ Types::UpdateProtectedQueryOutput
Updates the processing of a currently running query.
1588 |
# File 'sig/client.rbs', line 1588
def update_protected_query: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7471 7472 7473 |
# File 'lib/aws-sdk-cleanrooms/client.rb', line 7471 def waiter_names [] end |