Module: Aws::CleanRooms::Types

Defined in:
lib/aws-sdk-cleanrooms/types.rb

Defined Under Namespace

Classes: AccessBudget, AccessBudgetDetails, AccessBudgetsPrivacyTemplateParametersInput, AccessBudgetsPrivacyTemplateParametersOutput, AccessBudgetsPrivacyTemplateUpdateParameters, AccessDeniedException, AggregateColumn, AggregationConstraint, AnalysisParameter, AnalysisRule, AnalysisRuleAggregation, AnalysisRuleCustom, AnalysisRuleIdMappingTable, AnalysisRuleList, AnalysisRulePolicy, AnalysisRulePolicyV1, AnalysisSchema, AnalysisSource, AnalysisSourceMetadata, AnalysisTemplate, AnalysisTemplateArtifact, AnalysisTemplateArtifactMetadata, AnalysisTemplateArtifacts, AnalysisTemplateSummary, AnalysisTemplateValidationStatusDetail, AnalysisTemplateValidationStatusReason, ApprovalStatusDetails, AthenaTableReference, BatchGetCollaborationAnalysisTemplateError, BatchGetCollaborationAnalysisTemplateInput, BatchGetCollaborationAnalysisTemplateOutput, BatchGetSchemaAnalysisRuleError, BatchGetSchemaAnalysisRuleInput, BatchGetSchemaAnalysisRuleOutput, BatchGetSchemaError, BatchGetSchemaInput, BatchGetSchemaOutput, BilledJobResourceUtilization, BilledResourceUtilization, BudgetParameter, Change, ChangeInput, ChangeSpecification, Collaboration, CollaborationAnalysisTemplate, CollaborationAnalysisTemplateSummary, CollaborationChangeRequest, CollaborationChangeRequestSummary, CollaborationChangeSpecification, CollaborationConfiguredAudienceModelAssociation, CollaborationConfiguredAudienceModelAssociationSummary, CollaborationIdNamespaceAssociation, CollaborationIdNamespaceAssociationSummary, CollaborationPrivacyBudgetSummary, CollaborationPrivacyBudgetTemplate, CollaborationPrivacyBudgetTemplateSummary, CollaborationSummary, Column, ColumnClassificationDetails, ComputeConfiguration, ConfigurationDetails, ConfiguredAudienceModelAssociation, ConfiguredAudienceModelAssociationSummary, ConfiguredTable, ConfiguredTableAnalysisRule, ConfiguredTableAnalysisRulePolicy, ConfiguredTableAnalysisRulePolicyV1, ConfiguredTableAssociation, ConfiguredTableAssociationAnalysisRule, ConfiguredTableAssociationAnalysisRuleAggregation, ConfiguredTableAssociationAnalysisRuleCustom, ConfiguredTableAssociationAnalysisRuleList, ConfiguredTableAssociationAnalysisRulePolicy, ConfiguredTableAssociationAnalysisRulePolicyV1, ConfiguredTableAssociationSummary, ConfiguredTableSummary, ConflictException, ConsolidatedPolicy, ConsolidatedPolicyAggregation, ConsolidatedPolicyCustom, ConsolidatedPolicyList, ConsolidatedPolicyV1, CreateAnalysisTemplateInput, CreateAnalysisTemplateOutput, CreateCollaborationChangeRequestInput, CreateCollaborationChangeRequestOutput, CreateCollaborationInput, CreateCollaborationOutput, CreateConfiguredAudienceModelAssociationInput, CreateConfiguredAudienceModelAssociationOutput, CreateConfiguredTableAnalysisRuleInput, CreateConfiguredTableAnalysisRuleOutput, CreateConfiguredTableAssociationAnalysisRuleInput, CreateConfiguredTableAssociationAnalysisRuleOutput, CreateConfiguredTableAssociationInput, CreateConfiguredTableAssociationOutput, CreateConfiguredTableInput, CreateConfiguredTableOutput, CreateIdMappingTableInput, CreateIdMappingTableOutput, CreateIdNamespaceAssociationInput, CreateIdNamespaceAssociationOutput, CreateMembershipInput, CreateMembershipOutput, CreatePrivacyBudgetTemplateInput, CreatePrivacyBudgetTemplateOutput, DataEncryptionMetadata, DeleteAnalysisTemplateInput, DeleteAnalysisTemplateOutput, DeleteCollaborationInput, DeleteCollaborationOutput, DeleteConfiguredAudienceModelAssociationInput, DeleteConfiguredAudienceModelAssociationOutput, DeleteConfiguredTableAnalysisRuleInput, DeleteConfiguredTableAnalysisRuleOutput, DeleteConfiguredTableAssociationAnalysisRuleInput, DeleteConfiguredTableAssociationAnalysisRuleOutput, DeleteConfiguredTableAssociationInput, DeleteConfiguredTableAssociationOutput, DeleteConfiguredTableInput, DeleteConfiguredTableOutput, DeleteIdMappingTableInput, DeleteIdMappingTableOutput, DeleteIdNamespaceAssociationInput, DeleteIdNamespaceAssociationOutput, DeleteMemberInput, DeleteMemberOutput, DeleteMembershipInput, DeleteMembershipOutput, DeletePrivacyBudgetTemplateInput, DeletePrivacyBudgetTemplateOutput, DifferentialPrivacyColumn, DifferentialPrivacyConfiguration, DifferentialPrivacyParameters, DifferentialPrivacyPreviewAggregation, DifferentialPrivacyPreviewParametersInput, DifferentialPrivacyPrivacyBudget, DifferentialPrivacyPrivacyBudgetAggregation, DifferentialPrivacyPrivacyImpact, DifferentialPrivacySensitivityParameters, DifferentialPrivacyTemplateParametersInput, DifferentialPrivacyTemplateParametersOutput, DifferentialPrivacyTemplateUpdateParameters, DirectAnalysisConfigurationDetails, ErrorMessageConfiguration, GetAnalysisTemplateInput, GetAnalysisTemplateOutput, GetCollaborationAnalysisTemplateInput, GetCollaborationAnalysisTemplateOutput, GetCollaborationChangeRequestInput, GetCollaborationChangeRequestOutput, GetCollaborationConfiguredAudienceModelAssociationInput, GetCollaborationConfiguredAudienceModelAssociationOutput, GetCollaborationIdNamespaceAssociationInput, GetCollaborationIdNamespaceAssociationOutput, GetCollaborationInput, GetCollaborationOutput, GetCollaborationPrivacyBudgetTemplateInput, GetCollaborationPrivacyBudgetTemplateOutput, GetConfiguredAudienceModelAssociationInput, GetConfiguredAudienceModelAssociationOutput, GetConfiguredTableAnalysisRuleInput, GetConfiguredTableAnalysisRuleOutput, GetConfiguredTableAssociationAnalysisRuleInput, GetConfiguredTableAssociationAnalysisRuleOutput, GetConfiguredTableAssociationInput, GetConfiguredTableAssociationOutput, GetConfiguredTableInput, GetConfiguredTableOutput, GetIdMappingTableInput, GetIdMappingTableOutput, GetIdNamespaceAssociationInput, GetIdNamespaceAssociationOutput, GetMembershipInput, GetMembershipOutput, GetPrivacyBudgetTemplateInput, GetPrivacyBudgetTemplateOutput, GetProtectedJobInput, GetProtectedJobOutput, GetProtectedQueryInput, GetProtectedQueryOutput, GetSchemaAnalysisRuleInput, GetSchemaAnalysisRuleOutput, GetSchemaInput, GetSchemaOutput, GlueTableReference, Hash, IdMappingConfig, IdMappingTable, IdMappingTableInputReferenceConfig, IdMappingTableInputReferenceProperties, IdMappingTableInputSource, IdMappingTableSchemaTypeProperties, IdMappingTableSummary, IdNamespaceAssociation, IdNamespaceAssociationInputReferenceConfig, IdNamespaceAssociationInputReferenceProperties, IdNamespaceAssociationInputReferencePropertiesSummary, IdNamespaceAssociationSummary, InternalServerException, JobComputePaymentConfig, ListAnalysisTemplatesInput, ListAnalysisTemplatesOutput, ListCollaborationAnalysisTemplatesInput, ListCollaborationAnalysisTemplatesOutput, ListCollaborationChangeRequestsInput, ListCollaborationChangeRequestsOutput, ListCollaborationConfiguredAudienceModelAssociationsInput, ListCollaborationConfiguredAudienceModelAssociationsOutput, ListCollaborationIdNamespaceAssociationsInput, ListCollaborationIdNamespaceAssociationsOutput, ListCollaborationPrivacyBudgetTemplatesInput, ListCollaborationPrivacyBudgetTemplatesOutput, ListCollaborationPrivacyBudgetsInput, ListCollaborationPrivacyBudgetsOutput, ListCollaborationsInput, ListCollaborationsOutput, ListConfiguredAudienceModelAssociationsInput, ListConfiguredAudienceModelAssociationsOutput, ListConfiguredTableAssociationsInput, ListConfiguredTableAssociationsOutput, ListConfiguredTablesInput, ListConfiguredTablesOutput, ListIdMappingTablesInput, ListIdMappingTablesOutput, ListIdNamespaceAssociationsInput, ListIdNamespaceAssociationsOutput, ListMembersInput, ListMembersOutput, ListMembershipsInput, ListMembershipsOutput, ListPrivacyBudgetTemplatesInput, ListPrivacyBudgetTemplatesOutput, ListPrivacyBudgetsInput, ListPrivacyBudgetsOutput, ListProtectedJobsInput, ListProtectedJobsOutput, ListProtectedQueriesInput, ListProtectedQueriesOutput, ListSchemasInput, ListSchemasOutput, ListTagsForResourceInput, ListTagsForResourceOutput, MLMemberAbilities, MLPaymentConfig, MLSyntheticDataParameters, MemberChangeSpecification, MemberSpecification, MemberSummary, Membership, MembershipJobComputePaymentConfig, MembershipMLPaymentConfig, MembershipModelInferencePaymentConfig, MembershipModelTrainingPaymentConfig, MembershipPaymentConfiguration, MembershipProtectedJobOutputConfiguration, MembershipProtectedJobResultConfiguration, MembershipProtectedQueryOutputConfiguration, MembershipProtectedQueryResultConfiguration, MembershipQueryComputePaymentConfig, MembershipSummary, MembershipSyntheticDataGenerationPaymentConfig, ModelInferencePaymentConfig, ModelTrainingPaymentConfig, PaymentConfiguration, PopulateIdMappingTableInput, PopulateIdMappingTableOutput, PreviewPrivacyImpactInput, PreviewPrivacyImpactOutput, PreviewPrivacyImpactParametersInput, PrivacyBudget, PrivacyBudgetSummary, PrivacyBudgetTemplate, PrivacyBudgetTemplateParametersInput, PrivacyBudgetTemplateParametersOutput, PrivacyBudgetTemplateSummary, PrivacyBudgetTemplateUpdateParameters, PrivacyImpact, ProtectedJob, ProtectedJobComputeConfiguration, ProtectedJobConfigurationDetails, ProtectedJobDirectAnalysisConfigurationDetails, ProtectedJobError, ProtectedJobMemberOutputConfigurationInput, ProtectedJobMemberOutputConfigurationOutput, ProtectedJobOutput, ProtectedJobOutputConfigurationInput, ProtectedJobOutputConfigurationOutput, ProtectedJobParameters, ProtectedJobReceiverConfiguration, ProtectedJobResult, ProtectedJobResultConfigurationInput, ProtectedJobResultConfigurationOutput, ProtectedJobS3Output, ProtectedJobS3OutputConfigurationInput, ProtectedJobS3OutputConfigurationOutput, ProtectedJobSingleMemberOutput, ProtectedJobStatistics, ProtectedJobSummary, ProtectedJobWorkerComputeConfiguration, ProtectedQuery, ProtectedQueryDistributeOutput, ProtectedQueryDistributeOutputConfiguration, ProtectedQueryDistributeOutputConfigurationLocation, ProtectedQueryError, ProtectedQueryMemberOutputConfiguration, ProtectedQueryOutput, ProtectedQueryOutputConfiguration, ProtectedQueryResult, ProtectedQueryResultConfiguration, ProtectedQueryS3Output, ProtectedQueryS3OutputConfiguration, ProtectedQuerySQLParameters, ProtectedQuerySingleMemberOutput, ProtectedQueryStatistics, ProtectedQuerySummary, QueryComputePaymentConfig, QueryConstraint, QueryConstraintRequireOverlap, ReceiverConfiguration, ResourceNotFoundException, S3Location, Schema, SchemaAnalysisRuleRequest, SchemaStatusDetail, SchemaStatusReason, SchemaSummary, SchemaTypeProperties, ServiceQuotaExceededException, SnowflakeTableReference, SnowflakeTableSchema, SnowflakeTableSchemaV1, StartProtectedJobInput, StartProtectedJobOutput, StartProtectedQueryInput, StartProtectedQueryOutput, SyntheticDataColumnProperties, SyntheticDataGenerationPaymentConfig, SyntheticDataParameters, TableReference, TagResourceInput, TagResourceOutput, ThrottlingException, UntagResourceInput, UntagResourceOutput, UpdateAnalysisTemplateInput, UpdateAnalysisTemplateOutput, UpdateCollaborationChangeRequestInput, UpdateCollaborationChangeRequestOutput, UpdateCollaborationInput, UpdateCollaborationOutput, UpdateConfiguredAudienceModelAssociationInput, UpdateConfiguredAudienceModelAssociationOutput, UpdateConfiguredTableAnalysisRuleInput, UpdateConfiguredTableAnalysisRuleOutput, UpdateConfiguredTableAssociationAnalysisRuleInput, UpdateConfiguredTableAssociationAnalysisRuleOutput, UpdateConfiguredTableAssociationInput, UpdateConfiguredTableAssociationOutput, UpdateConfiguredTableInput, UpdateConfiguredTableOutput, UpdateIdMappingTableInput, UpdateIdMappingTableOutput, UpdateIdNamespaceAssociationInput, UpdateIdNamespaceAssociationOutput, UpdateMembershipInput, UpdateMembershipOutput, UpdatePrivacyBudgetTemplateInput, UpdatePrivacyBudgetTemplateOutput, UpdateProtectedJobInput, UpdateProtectedJobOutput, UpdateProtectedQueryInput, UpdateProtectedQueryOutput, ValidationException, ValidationExceptionField, WorkerComputeConfiguration, WorkerComputeConfigurationProperties

Instance Attribute Summary collapse

Instance Attribute Details

#access_budgetTypes::AccessBudgetsPrivacyTemplateUpdateParameters

The new access budget configuration that completely replaces the existing access budget settings in the privacy budget template.



7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7556

class PrivacyBudget < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudget; end
  class AccessBudget < PrivacyBudget; end
  class Unknown < PrivacyBudget; end
end

#aggregationTypes::ConsolidatedPolicyAggregation

The aggregation setting for the consolidated policy.



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/aws-sdk-cleanrooms/types.rb', line 529

class AnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :id_mapping_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < AnalysisRulePolicyV1; end
  class Aggregation < AnalysisRulePolicyV1; end
  class Custom < AnalysisRulePolicyV1; end
  class IdMappingTable < AnalysisRulePolicyV1; end
  class Unknown < AnalysisRulePolicyV1; end
end

#artifactsTypes::AnalysisTemplateArtifactMetadata

The artifacts of the analysis source metadata.



576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/aws-sdk-cleanrooms/types.rb', line 576

class AnalysisSource < Struct.new(
  :text,
  :artifacts,
  :unknown)
  SENSITIVE = [:text]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < AnalysisSource; end
  class Artifacts < AnalysisSource; end
  class Unknown < AnalysisSource; end
end

#athenaTypes::AthenaTableReference

If present, a reference to the Athena table referred to by this table reference.



9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
9513
9514
9515
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9502

class TableReference < Struct.new(
  :glue,
  :snowflake,
  :athena,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Glue < TableReference; end
  class Snowflake < TableReference; end
  class Athena < TableReference; end
  class Unknown < TableReference; end
end

#collaborationTypes::CollaborationChangeSpecification

The collaboration configuration changes being requested. Currently, this only supports modifying which change types are auto-approved for the collaboration.



1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1265

class ChangeSpecification < Struct.new(
  :member,
  :collaboration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Member < ChangeSpecification; end
  class Collaboration < ChangeSpecification; end
  class Unknown < ChangeSpecification; end
end

#customTypes::ConsolidatedPolicyCustom

Custom policy



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/aws-sdk-cleanrooms/types.rb', line 529

class AnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :id_mapping_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < AnalysisRulePolicyV1; end
  class Aggregation < AnalysisRulePolicyV1; end
  class Custom < AnalysisRulePolicyV1; end
  class IdMappingTable < AnalysisRulePolicyV1; end
  class Unknown < AnalysisRulePolicyV1; end
end

#differential_privacyTypes::DifferentialPrivacyPrivacyImpact

An object that lists the number and type of aggregation functions you can perform.



7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7528

class PreviewPrivacyImpactParametersInput < Struct.new(
  :differential_privacy,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PreviewPrivacyImpactParametersInput; end
  class Unknown < PreviewPrivacyImpactParametersInput; end
end

#direct_analysis_configuration_detailsTypes::ProtectedJobDirectAnalysisConfigurationDetails

The details needed to configure the direct analysis.



2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2305

class ConfigurationDetails < Struct.new(
  :direct_analysis_configuration_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DirectAnalysisConfigurationDetails < ConfigurationDetails; end
  class Unknown < ConfigurationDetails; end
end

#distributeTypes::ProtectedQueryDistributeOutputConfiguration

Required configuration for a protected query with a distribute output type.



8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8574

class ProtectedQueryOutput < Struct.new(
  :s3,
  :member_list,
  :distribute,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ProtectedQueryOutput; end
  class MemberList < ProtectedQueryOutput; end
  class Distribute < ProtectedQueryOutput; end
  class Unknown < ProtectedQueryOutput; end
end

#glueTypes::GlueTableReference

If present, a reference to the Glue table referred to by this table reference.



9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
9513
9514
9515
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9502

class TableReference < Struct.new(
  :glue,
  :snowflake,
  :athena,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Glue < TableReference; end
  class Snowflake < TableReference; end
  class Athena < TableReference; end
  class Unknown < TableReference; end
end

#id_mapping_tableTypes::IdMappingTableSchemaTypeProperties

The ID mapping table for the schema type properties.



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/aws-sdk-cleanrooms/types.rb', line 529

class AnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :id_mapping_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < AnalysisRulePolicyV1; end
  class Aggregation < AnalysisRulePolicyV1; end
  class Custom < AnalysisRulePolicyV1; end
  class IdMappingTable < AnalysisRulePolicyV1; end
  class Unknown < AnalysisRulePolicyV1; end
end

#listTypes::ConsolidatedPolicyList

The list of consolidated policies.



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/aws-sdk-cleanrooms/types.rb', line 529

class AnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :id_mapping_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < AnalysisRulePolicyV1; end
  class Aggregation < AnalysisRulePolicyV1; end
  class Custom < AnalysisRulePolicyV1; end
  class IdMappingTable < AnalysisRulePolicyV1; end
  class Unknown < AnalysisRulePolicyV1; end
end

#memberTypes::ProtectedQueryMemberOutputConfiguration

Required configuration for a protected query with a member output type.



1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1265

class ChangeSpecification < Struct.new(
  :member,
  :collaboration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Member < ChangeSpecification; end
  class Collaboration < ChangeSpecification; end
  class Unknown < ChangeSpecification; end
end

#member_listArray<Types::ProtectedQuerySingleMemberOutput>

The list of member Amazon Web Services account(s) that received the results of the query.



8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8070

class ProtectedJobOutput < Struct.new(
  :s3,
  :member_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ProtectedJobOutput; end
  class MemberList < ProtectedJobOutput; end
  class Unknown < ProtectedJobOutput; end
end

#ml_synthetic_data_parametersTypes::MLSyntheticDataParameters

The machine learning-specific parameters for synthetic data generation.



9468
9469
9470
9471
9472
9473
9474
9475
9476
9477
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9468

class SyntheticDataParameters < Struct.new(
  :ml_synthetic_data_parameters,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MlSyntheticDataParameters < SyntheticDataParameters; end
  class Unknown < SyntheticDataParameters; end
end

#require_overlapTypes::QueryConstraintRequireOverlap

An array of column names that specifies which columns are required in the JOIN statement.



8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8840

class QueryConstraint < Struct.new(
  :require_overlap,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RequireOverlap < QueryConstraint; end
  class Unknown < QueryConstraint; end
end

#s3Types::ProtectedQueryS3OutputConfiguration

Required configuration for a protected query with an s3 output type.



7150
7151
7152
7153
7154
7155
7156
7157
7158
7159
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7150

class MembershipProtectedJobOutputConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < MembershipProtectedJobOutputConfiguration; end
  class Unknown < MembershipProtectedJobOutputConfiguration; end
end

#snowflakeTypes::SnowflakeTableReference

If present, a reference to the Snowflake table referred to by this table reference.



9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
9513
9514
9515
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9502

class TableReference < Struct.new(
  :glue,
  :snowflake,
  :athena,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Glue < TableReference; end
  class Snowflake < TableReference; end
  class Athena < TableReference; end
  class Unknown < TableReference; end
end

#sparkHash<String,String>

The Spark configuration properties for SQL workloads. This map contains key-value pairs that configure Apache Spark settings to optimize performance for your data processing jobs. You can specify up to 50 Spark properties, with each key being 1-200 characters and each value being 0-500 characters. These properties allow you to adjust compute capacity for large datasets and complex workloads.

Returns:

  • (Hash<String,String>)


10274
10275
10276
10277
10278
10279
10280
10281
10282
10283
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10274

class WorkerComputeConfigurationProperties < Struct.new(
  :spark,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Spark < WorkerComputeConfigurationProperties; end
  class Unknown < WorkerComputeConfigurationProperties; end
end

#textString

The query text.

Returns:

  • (String)


576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/aws-sdk-cleanrooms/types.rb', line 576

class AnalysisSource < Struct.new(
  :text,
  :artifacts,
  :unknown)
  SENSITIVE = [:text]
  include Aws::Structure
  include Aws::Structure::Union

  class Text < AnalysisSource; end
  class Artifacts < AnalysisSource; end
  class Unknown < AnalysisSource; end
end

#v1Array<Types::SnowflakeTableSchemaV1>

The schema of a Snowflake table.

Returns:



492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-cleanrooms/types.rb', line 492

class AnalysisRulePolicy < Struct.new(
  :v1,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class V1 < AnalysisRulePolicy; end
  class Unknown < AnalysisRulePolicy; end
end

#workerTypes::ProtectedJobWorkerComputeConfiguration

The worker configuration for the compute environment.



2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2284

class ComputeConfiguration < Struct.new(
  :worker,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Worker < ComputeConfiguration; end
  class Unknown < ComputeConfiguration; end
end