Class: Aws::CleanRooms::Types::AnalysisLogExportOutputConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisLogExportOutputConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains configuration details for analysis log export output.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3 ⇒ Types::AnalysisLogExportS3OutputConfiguration
Required configuration for an analysis log export with an
s3output type.
Instance Attribute Details
#s3 ⇒ Types::AnalysisLogExportS3OutputConfiguration
Required configuration for an analysis log export with an s3
output type.
331 332 333 334 335 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 331 class AnalysisLogExportOutputConfiguration < Struct.new( :s3) SENSITIVE = [] include Aws::Structure end |