Class: Aws::CleanRooms::Types::AnalysisLogExportSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

A summary of an analysis log export, including its identifier, status, analysis type, and creation time. Returned by ListAnalysisLogExports.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The unique identifier of the protected query that the analysis logs were exported for.

Returns:

  • (String)


426
427
428
429
430
431
432
433
434
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426

class AnalysisLogExportSummary < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :status,
  :create_time)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_log_export_idString

The unique identifier of the analysis log export.

Returns:

  • (String)


426
427
428
429
430
431
432
433
434
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426

class AnalysisLogExportSummary < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :status,
  :create_time)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_typeString

The type of analysis that the logs were exported for. Currently, only PROTECTED_QUERY is supported.

Returns:

  • (String)


426
427
428
429
430
431
432
433
434
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426

class AnalysisLogExportSummary < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :status,
  :create_time)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time the analysis log export was created.

Returns:

  • (Time)


426
427
428
429
430
431
432
433
434
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426

class AnalysisLogExportSummary < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :status,
  :create_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the analysis log export. Possible values are:

  • IN_PROGRESS – The export is currently running.

  • SUCCESS – The export completed successfully.

  • FAILED – The export failed.

Returns:

  • (String)


426
427
428
429
430
431
432
433
434
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426

class AnalysisLogExportSummary < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :status,
  :create_time)
  SENSITIVE = []
  include Aws::Structure
end