Class: Aws::CleanRooms::Types::AnalysisParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Optional. The member who can query can provide this placeholder for a literal data value in an analysis template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value ⇒ String
Optional.
-
#name ⇒ String
The name of the parameter.
-
#type ⇒ String
The type of parameter.
Instance Attribute Details
#default_value ⇒ String
Optional. The default value that is applied in the analysis template. The member who can query can override this value in the query editor.
456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 456 class AnalysisParameter < Struct.new( :name, :type, :default_value) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the parameter. The name must use only alphanumeric or underscore (_) characters.
456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 456 class AnalysisParameter < Struct.new( :name, :type, :default_value) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of parameter.
456 457 458 459 460 461 462 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 456 class AnalysisParameter < Struct.new( :name, :type, :default_value) SENSITIVE = [] include Aws::Structure end |