Class: Aws::CleanRooms::Types::AnalysisRuleAggregation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

A type of analysis rule that enables query structure and specified queries that produce aggregate statistics.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_analysesString

An indicator as to whether additional analyses (such as Clean Rooms ML) can be applied to the output of the direct query.

The additionalAnalyses parameter is currently supported for the list analysis rule (AnalysisRuleList) and the custom analysis rule (AnalysisRuleCustom).

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#aggregate_columnsArray<Types::AggregateColumn>

The columns that query runners are allowed to use in aggregation queries.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_join_operatorsArray<String>

Which logical operators (if any) are to be used in an INNER JOIN match condition. Default is AND.

Returns:

  • (Array<String>)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#dimension_columnsArray<String>

The columns that query runners are allowed to select, group by, or filter by.

Returns:

  • (Array<String>)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#join_columnsArray<String>

Columns in configured table that can be used in join statements and/or as aggregate columns. They can never be outputted directly.

Returns:

  • (Array<String>)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#join_requiredString

Control that requires member who runs query to do a join with their configured table and/or other configured table in query.

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#output_constraintsArray<Types::AggregationConstraint>

Columns that must meet a specific threshold value (after an aggregation function is applied to it) for each output row to be returned.

Returns:



622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#scalar_functionsArray<String>

Set of scalar functions that are allowed to be used on dimension columns and the output of aggregation of metrics.

Returns:

  • (Array<String>)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-cleanrooms/types.rb', line 622

class AnalysisRuleAggregation < Struct.new(
  :aggregate_columns,
  :join_columns,
  :join_required,
  :allowed_join_operators,
  :dimension_columns,
  :scalar_functions,
  :output_constraints,
  :additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end