Class: Aws::CleanRooms::Types::AnalysisRuleCustom

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

A type of analysis rule that enables the table owner to approve custom SQL queries on their configured tables. It supports differential privacy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_analysesString

An indicator as to whether additional analyses (such as Clean Rooms ML) can be applied to the output of the direct query.



412
413
414
415
416
417
418
419
420
# File 'lib/aws-sdk-cleanrooms/types.rb', line 412

class AnalysisRuleCustom < Struct.new(
  :allowed_analyses,
  :allowed_analysis_providers,
  :additional_analyses,
  :disallowed_output_columns,
  :differential_privacy)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_analysesArray<String>

The ARN of the analysis templates that are allowed by the custom analysis rule.



412
413
414
415
416
417
418
419
420
# File 'lib/aws-sdk-cleanrooms/types.rb', line 412

class AnalysisRuleCustom < Struct.new(
  :allowed_analyses,
  :allowed_analysis_providers,
  :additional_analyses,
  :disallowed_output_columns,
  :differential_privacy)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_analysis_providersArray<String>

The IDs of the Amazon Web Services accounts that are allowed to query by the custom analysis rule. Required when allowedAnalyses is ANY_QUERY.



412
413
414
415
416
417
418
419
420
# File 'lib/aws-sdk-cleanrooms/types.rb', line 412

class AnalysisRuleCustom < Struct.new(
  :allowed_analyses,
  :allowed_analysis_providers,
  :additional_analyses,
  :disallowed_output_columns,
  :differential_privacy)
  SENSITIVE = []
  include Aws::Structure
end

#differential_privacyTypes::DifferentialPrivacyConfiguration

The differential privacy configuration.



412
413
414
415
416
417
418
419
420
# File 'lib/aws-sdk-cleanrooms/types.rb', line 412

class AnalysisRuleCustom < Struct.new(
  :allowed_analyses,
  :allowed_analysis_providers,
  :additional_analyses,
  :disallowed_output_columns,
  :differential_privacy)
  SENSITIVE = []
  include Aws::Structure
end

#disallowed_output_columnsArray<String>

A list of columns that aren’t allowed to be shown in the query output.



412
413
414
415
416
417
418
419
420
# File 'lib/aws-sdk-cleanrooms/types.rb', line 412

class AnalysisRuleCustom < Struct.new(
  :allowed_analyses,
  :allowed_analysis_providers,
  :additional_analyses,
  :disallowed_output_columns,
  :differential_privacy)
  SENSITIVE = []
  include Aws::Structure
end