Class: Aws::CleanRooms::Types::AnalysisRulePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

AnalysisRulePolicy is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AnalysisRulePolicy corresponding to the set member.

Controls on the query specifications that can be run on configured table.

Defined Under Namespace

Classes: Unknown, V1

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



701
702
703
# File 'lib/aws-sdk-cleanrooms/types.rb', line 701

def unknown
  @unknown
end

#v1Types::AnalysisRulePolicyV1

Controls on the query specifications that can be run on configured table.



701
702
703
704
705
706
707
708
709
710
# File 'lib/aws-sdk-cleanrooms/types.rb', line 701

class AnalysisRulePolicy < Struct.new(
  :v1,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class V1 < AnalysisRulePolicy; end
  class Unknown < AnalysisRulePolicy; end
end