Class: Aws::CleanRooms::Types::AnalysisTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The analysis template.
Constant Summary collapse
- SENSITIVE =
[:analysis_parameters]
Instance Attribute Summary collapse
-
#analysis_parameters ⇒ Array<Types::AnalysisParameter>
The parameters of the analysis template.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
-
#collaboration_arn ⇒ String
The unique ARN for the analysis template’s associated collaboration.
-
#collaboration_id ⇒ String
The unique ID for the associated collaboration of the analysis template.
-
#create_time ⇒ Time
The time that the analysis template was created.
-
#description ⇒ String
The description of the analysis template.
-
#error_message_configuration ⇒ Types::ErrorMessageConfiguration
The configuration that specifies the level of detail in error messages returned by analyses using this template.
-
#format ⇒ String
The format of the analysis template.
-
#id ⇒ String
The identifier for the analysis template.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the member who created the analysis template.
-
#membership_id ⇒ String
The identifier of a member who created the analysis template.
-
#name ⇒ String
The name of the analysis template.
-
#schema ⇒ Types::AnalysisSchema
The entire schema object.
-
#source ⇒ Types::AnalysisSource
The source of the analysis template.
-
#source_metadata ⇒ Types::AnalysisSourceMetadata
The source metadata for the analysis template.
-
#synthetic_data_parameters ⇒ Types::SyntheticDataParameters
The parameters used to generate synthetic data for this analysis template.
-
#update_time ⇒ Time
The time that the analysis template was last updated.
-
#validations ⇒ Array<Types::AnalysisTemplateValidationStatusDetail>
Information about the validations performed on the analysis template.
Instance Attribute Details
#analysis_parameters ⇒ Array<Types::AnalysisParameter>
The parameters of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique ARN for the analysis template’s associated collaboration.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#collaboration_id ⇒ String
The unique ID for the associated collaboration of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#create_time ⇒ Time
The time that the analysis template was created.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#description ⇒ String
The description of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#error_message_configuration ⇒ Types::ErrorMessageConfiguration
The configuration that specifies the level of detail in error
messages returned by analyses using this template. When set to
DETAILED, error messages include more information to help
troubleshoot issues with PySpark jobs. Detailed error messages may
expose underlying data, including sensitive information. Recommended
for faster troubleshooting in development and testing environments.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#format ⇒ String
The format of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#id ⇒ String
The identifier for the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the member who created the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#membership_id ⇒ String
The identifier of a member who created the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#name ⇒ String
The name of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#schema ⇒ Types::AnalysisSchema
The entire schema object.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#source ⇒ Types::AnalysisSource
The source of the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#source_metadata ⇒ Types::AnalysisSourceMetadata
The source metadata for the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#synthetic_data_parameters ⇒ Types::SyntheticDataParameters
The parameters used to generate synthetic data for this analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#update_time ⇒ Time
The time that the analysis template was last updated.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#validations ⇒ Array<Types::AnalysisTemplateValidationStatusDetail>
Information about the validations performed on the analysis template.
977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 977 class AnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :membership_id, :membership_arn, :description, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |