Class: Aws::CleanRooms::Types::AnalysisTemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisTemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The metadata of the analysis template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
-
#collaboration_arn ⇒ String
The unique ARN for the analysis template summary’s associated collaboration.
-
#collaboration_id ⇒ String
A unique identifier for the collaboration that the analysis template summary belongs to.
-
#create_time ⇒ Time
The time that the analysis template summary was created.
-
#description ⇒ String
The description of the analysis template.
-
#id ⇒ String
The identifier of the analysis template.
-
#is_synthetic_data ⇒ Boolean
Indicates if this analysis template summary generated synthetic data.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the member who created the analysis template.
-
#membership_id ⇒ String
The identifier for a membership resource.
-
#name ⇒ String
The name of the analysis template.
-
#update_time ⇒ Time
The time that the analysis template summary was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique ARN for the analysis template summary’s associated collaboration.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
A unique identifier for the collaboration that the analysis template summary belongs to. Currently accepts collaboration ID.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time that the analysis template summary was created.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the analysis template.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the analysis template.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#is_synthetic_data ⇒ Boolean
Indicates if this analysis template summary generated synthetic data.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the member who created the analysis template.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The identifier for a membership resource.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the analysis template.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time that the analysis template summary was last updated.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1110 class AnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |