Class: Aws::CleanRooms::Types::AnalysisTemplateValidationStatusDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The status details of the analysis template validation. Clean Rooms Differential Privacy uses a general-purpose query structure to support complex SQL queries and validates whether an analysis template fits that general-purpose query structure. Validation is performed when analysis templates are created and fetched. Because analysis templates are immutable by design, we recommend that you create analysis templates after you associate the configured tables with their analysis rule to your collaboration.

For more information, see https://docs.aws.amazon.com/clean-rooms/latest/userguide/analysis-rules-custom.html#custom-diff-privacy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reasonsArray<Types::AnalysisTemplateValidationStatusReason>

The reasons for the validation results.



1156
1157
1158
1159
1160
1161
1162
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1156

class AnalysisTemplateValidationStatusDetail < Struct.new(
  :type,
  :status,
  :reasons)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the validation.

Returns:

  • (String)


1156
1157
1158
1159
1160
1161
1162
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1156

class AnalysisTemplateValidationStatusDetail < Struct.new(
  :type,
  :status,
  :reasons)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of validation that was performed.

Returns:

  • (String)


1156
1157
1158
1159
1160
1161
1162
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1156

class AnalysisTemplateValidationStatusDetail < Struct.new(
  :type,
  :status,
  :reasons)
  SENSITIVE = []
  include Aws::Structure
end