Class: Aws::CleanRooms::Types::BatchGetCollaborationAnalysisTemplateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collaboration_analysis_templatesArray<Types::CollaborationAnalysisTemplate>

The retrieved list of analysis templates within a collaboration.



1009
1010
1011
1012
1013
1014
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1009

class BatchGetCollaborationAnalysisTemplateOutput < Struct.new(
  :collaboration_analysis_templates,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::BatchGetCollaborationAnalysisTemplateError>

Error reasons for collaboration analysis templates that could not be retrieved. One error is returned for every collaboration analysis template that could not be retrieved.



1009
1010
1011
1012
1013
1014
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1009

class BatchGetCollaborationAnalysisTemplateOutput < Struct.new(
  :collaboration_analysis_templates,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end