Class: Aws::CleanRooms::Types::BudgetParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Individual budget parameter configuration that defines specific budget allocation settings for access budgets.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_refreshString

Whether this individual budget parameter automatically refreshes when the budget period resets.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1401

class BudgetParameter < Struct.new(
  :type,
  :budget,
  :auto_refresh)
  SENSITIVE = []
  include Aws::Structure
end

#budgetInteger

The budget allocation amount for this specific parameter.

Returns:

  • (Integer)


1401
1402
1403
1404
1405
1406
1407
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1401

class BudgetParameter < Struct.new(
  :type,
  :budget,
  :auto_refresh)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of budget parameter being configured.

Returns:

  • (String)


1401
1402
1403
1404
1405
1406
1407
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1401

class BudgetParameter < Struct.new(
  :type,
  :budget,
  :auto_refresh)
  SENSITIVE = []
  include Aws::Structure
end