Class: Aws::CleanRooms::Types::ChangeSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

ChangeSpecification is a union - when making an API calls you must set exactly one of the members.

Note:

ChangeSpecification is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ChangeSpecification corresponding to the set member.

A union that contains the specification details for different types of changes.

Defined Under Namespace

Classes: Collaboration, Member, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collaborationTypes::CollaborationChangeSpecification

The collaboration configuration changes being requested. Currently, this only supports modifying which change types are auto-approved for the collaboration.



1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1474

class ChangeSpecification < Struct.new(
  :member,
  :collaboration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Member < ChangeSpecification; end
  class Collaboration < ChangeSpecification; end
  class Unknown < ChangeSpecification; end
end

#memberTypes::MemberChangeSpecification

The member change specification when the change type is MEMBER.



1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1474

class ChangeSpecification < Struct.new(
  :member,
  :collaboration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Member < ChangeSpecification; end
  class Collaboration < ChangeSpecification; end
  class Unknown < ChangeSpecification; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1474
1475
1476
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1474

def unknown
  @unknown
end