Class: Aws::CleanRooms::Types::CollaborationAnalysisTemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationAnalysisTemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The metadata of the analysis template within a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
-
#collaboration_arn ⇒ String
The unique ARN for the analysis template’s associated collaboration.
-
#collaboration_id ⇒ String
A unique identifier for the collaboration that the analysis templates belong to.
-
#create_time ⇒ Time
The time that the summary of the analysis template in a collaboration was created.
-
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration.
-
#description ⇒ String
The description of the analysis template.
-
#id ⇒ String
The identifier of the analysis template.
-
#is_synthetic_data ⇒ Boolean
Indicates if this collaboration analysis template uses synthetic data generation.
-
#name ⇒ String
The name of the analysis template.
-
#update_time ⇒ Time
The time that the summary of the analysis template in the collaboration was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique ARN for the analysis template’s associated collaboration.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
A unique identifier for the collaboration that the analysis templates belong to. Currently accepts collaboration ID.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time that the summary of the analysis template in a collaboration was created.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the analysis template.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the analysis template.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#is_synthetic_data ⇒ Boolean
Indicates if this collaboration analysis template uses synthetic data generation.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the analysis template.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time that the summary of the analysis template in the collaboration was last updated.
1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1876 class CollaborationAnalysisTemplateSummary < Struct.new( :arn, :create_time, :id, :name, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :description, :is_synthetic_data) SENSITIVE = [] include Aws::Structure end |