Class: Aws::CleanRooms::Types::CollaborationChangeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Represents a request to modify a collaboration. Change requests enable structured modifications to collaborations after they have been created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approvalsHash<String,Types::ApprovalStatusDetails>

A list of approval details from collaboration members, including approval status and multi-party approval workflow information.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#changesArray<Types::Change>

The list of changes specified in this change request.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_idString

The unique identifier for the collaboration being modified.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time when the change request was created.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier for the change request.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#is_auto_approvedBoolean

Whether the change request was automatically approved based on the collaboration’s auto-approval settings.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the change request. Valid values are PENDING, APPROVED, DENIED, COMMITTED, and CANCELLED.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The time when the change request was last updated.

Returns:



1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1614

class CollaborationChangeRequest < Struct.new(
  :id,
  :collaboration_id,
  :create_time,
  :update_time,
  :status,
  :is_auto_approved,
  :changes,
  :approvals)
  SENSITIVE = []
  include Aws::Structure
end