Class: Aws::CleanRooms::Types::CollaborationChangeRequestSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationChangeRequestSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Summary information about a collaboration change request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approvals ⇒ Hash<String,Types::ApprovalStatusDetails>
Summary of approval statuses from all collaboration members for this change request.
-
#changes ⇒ Array<Types::Change>
Summary of the changes in this change request.
-
#collaboration_id ⇒ String
The unique identifier for the collaboration.
-
#create_time ⇒ Time
The time when the change request was created.
-
#id ⇒ String
The unique identifier for the change request.
-
#is_auto_approved ⇒ Boolean
Whether the change request was automatically approved.
-
#status ⇒ String
The current status of the change request.
-
#update_time ⇒ Time
The time when the change request was last updated.
Instance Attribute Details
#approvals ⇒ Hash<String,Types::ApprovalStatusDetails>
Summary of approval statuses from all collaboration members for this change request.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#changes ⇒ Array<Types::Change>
Summary of the changes in this change request.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier for the collaboration.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the change request was created.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the change request.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#is_auto_approved ⇒ Boolean
Whether the change request was automatically approved.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the change request.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time when the change request was last updated.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1664 class CollaborationChangeRequestSummary < Struct.new( :id, :collaboration_id, :create_time, :update_time, :status, :is_auto_approved, :changes, :approvals) SENSITIVE = [] include Aws::Structure end |