Class: Aws::CleanRooms::Types::CollaborationIdNamespaceAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Defines details for the collaboration ID namespace association.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_arnString

The Amazon Resource Name (ARN) of the collaboration that contains the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_idString

The unique identifier of the collaboration that contains the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the collaboration ID namespace association was created.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#creator_account_idString

The unique identifier of the Amazon Web Services account that created the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#id_mapping_configTypes::IdMappingConfig

The configuration settings for the ID mapping table.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#input_reference_configTypes::IdNamespaceAssociationInputReferenceConfig

The input reference configuration that’s necessary to create the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#input_reference_propertiesTypes::IdNamespaceAssociationInputReferenceProperties

The input reference properties that are needed to create the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the collaboration ID namespace association.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The most recent time at which the collaboration ID namespace was updated.



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1880

class CollaborationIdNamespaceAssociation < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :name,
  :description,
  :creator_account_id,
  :create_time,
  :update_time,
  :input_reference_config,
  :input_reference_properties,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end