Class: Aws::CleanRooms::Types::CollaborationPrivacyBudgetTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationPrivacyBudgetTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An array that specifies the information for a collaboration's privacy budget template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the collaboration privacy budget template.
-
#auto_refresh ⇒ String
How often the privacy budget refreshes.
-
#collaboration_arn ⇒ String
The ARN of the collaboration that includes this collaboration privacy budget template.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that includes this collaboration privacy budget template.
-
#create_time ⇒ Time
The time at which the collaboration privacy budget template was created.
-
#creator_account_id ⇒ String
The unique identifier of the account that created this collaboration privacy budget template.
-
#id ⇒ String
The unique identifier of the collaboration privacy budget template.
-
#parameters ⇒ Types::PrivacyBudgetTemplateParametersOutput
Specifies the epsilon and noise parameters for the privacy budget template.
-
#privacy_budget_type ⇒ String
The type of privacy budget template.
-
#update_time ⇒ Time
The most recent time at which the collaboration privacy budget template was updated.
Instance Attribute Details
#arn ⇒ String
The ARN of the collaboration privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#auto_refresh ⇒ String
How often the privacy budget refreshes.
If you plan to regularly bring new data into the collaboration, use
CALENDAR_MONTH to automatically get a new privacy budget for the
collaboration every calendar month. Choosing this option allows
arbitrary amounts of information to be revealed about rows of the
data when repeatedly queried across refreshes. Avoid choosing this
if the same rows will be repeatedly queried between privacy budget
refreshes.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The ARN of the collaboration that includes this collaboration privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that includes this collaboration privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the collaboration privacy budget template was created.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The unique identifier of the account that created this collaboration privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the collaboration privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::PrivacyBudgetTemplateParametersOutput
Specifies the epsilon and noise parameters for the privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#privacy_budget_type ⇒ String
The type of privacy budget template.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the collaboration privacy budget template was updated.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2410 class CollaborationPrivacyBudgetTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :creator_account_id, :create_time, :update_time, :privacy_budget_type, :auto_refresh, :parameters) SENSITIVE = [] include Aws::Structure end |