Class: Aws::CleanRooms::Types::ColumnClassificationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains classification information for data columns, including mappings that specify how columns should be handled during synthetic data generation and privacy analysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_mappingArray<Types::SyntheticDataColumnProperties>

A mapping that defines the classification of data columns for synthetic data generation and specifies how each column should be handled during the privacy-preserving data synthesis process.



2265
2266
2267
2268
2269
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2265

class ColumnClassificationDetails < Struct.new(
  :column_mapping)
  SENSITIVE = []
  include Aws::Structure
end