Class: Aws::CleanRooms::Types::ComparisonControls

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Specifies how a query can compare the columns in a table, including literal comparisons and column-to-column comparisons.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_column_comparison_columnsArray<String>

The columns that a query can compare to another column, for example, in a join, a WHERE clause, a GROUP BY clause, or a window function. Clean Rooms rejects a query that uses any other column in a column-to-column comparison. Specify an empty list to block column-to-column comparison on every column.

Returns:

  • (Array<String>)


2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2650

class ComparisonControls < Struct.new(
  :allowed_literal_comparison_columns,
  :allowed_column_comparison_columns)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_literal_comparison_columnsArray<String>

The columns that a query can compare to literal values, for example, in a WHERE clause. Clean Rooms rejects a query that compares any other column to a literal value. Specify an empty list to block literal comparison on every column. You can't specify a column that you also use as an identity column in an aggregation threshold.

Returns:

  • (Array<String>)


2650
2651
2652
2653
2654
2655
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2650

class ComparisonControls < Struct.new(
  :allowed_literal_comparison_columns,
  :allowed_column_comparison_columns)
  SENSITIVE = []
  include Aws::Structure
end