Class: Aws::CleanRooms::Types::ConfiguredTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A table that has been configured for use in a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_columns ⇒ Array<String>
The columns within the underlying Glue table that can be used within collaborations.
-
#analysis_method ⇒ String
The analysis method for the configured table.
-
#analysis_rule_types ⇒ Array<String>
The types of analysis rules associated with this configured table.
-
#arn ⇒ String
The unique ARN for the configured table.
-
#create_time ⇒ Time
The time the configured table was created.
-
#description ⇒ String
A description for the configured table.
-
#id ⇒ String
The unique ID for the configured table.
-
#name ⇒ String
A name for the configured table.
-
#selected_analysis_methods ⇒ Array<String>
The selected analysis methods for the configured table.
-
#table_reference ⇒ Types::TableReference
The table that this configured table represents.
-
#update_time ⇒ Time
The time the configured table was last updated.
Instance Attribute Details
#allowed_columns ⇒ Array<String>
The columns within the underlying Glue table that can be used within collaborations.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#analysis_method ⇒ String
The analysis method for the configured table.
DIRECT_QUERY allows SQL queries to be run directly on this table.
DIRECT_JOB allows PySpark jobs to be run directly on this table.
MULTIPLE allows both SQL queries and PySpark jobs to be run
directly on this table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#analysis_rule_types ⇒ Array<String>
The types of analysis rules associated with this configured table. Currently, only one analysis rule may be associated with a configured table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique ARN for the configured table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the configured table was created.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the configured table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for the configured table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the configured table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#selected_analysis_methods ⇒ Array<String>
The selected analysis methods for the configured table.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#table_reference ⇒ Types::TableReference
The table that this configured table represents.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the configured table was last updated
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2913 class ConfiguredTable < Struct.new( :id, :arn, :name, :description, :table_reference, :create_time, :update_time, :analysis_rule_types, :analysis_method, :allowed_columns, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |