Class: Aws::CleanRooms::Types::ConfiguredTableAnalysisRulePolicyV1

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

ConfiguredTableAnalysisRulePolicyV1 is a union - when making an API calls you must set exactly one of the members.

Note:

ConfiguredTableAnalysisRulePolicyV1 is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConfiguredTableAnalysisRulePolicyV1 corresponding to the set member.

Controls on the query specifications that can be run on a configured table.

Defined Under Namespace

Classes: Aggregation, Custom, List, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregationTypes::AnalysisRuleAggregation

Analysis rule type that enables only aggregation queries on a configured table.



3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3020

class ConfiguredTableAnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConfiguredTableAnalysisRulePolicyV1; end
  class Aggregation < ConfiguredTableAnalysisRulePolicyV1; end
  class Custom < ConfiguredTableAnalysisRulePolicyV1; end
  class Unknown < ConfiguredTableAnalysisRulePolicyV1; end
end

#customTypes::AnalysisRuleCustom

A type of analysis rule that enables the table owner to approve custom SQL queries on their configured tables. It supports differential privacy, minimum aggregation thresholds, and comparison controls.



3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3020

class ConfiguredTableAnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConfiguredTableAnalysisRulePolicyV1; end
  class Aggregation < ConfiguredTableAnalysisRulePolicyV1; end
  class Custom < ConfiguredTableAnalysisRulePolicyV1; end
  class Unknown < ConfiguredTableAnalysisRulePolicyV1; end
end

#listTypes::AnalysisRuleList

Analysis rule type that enables only list queries on a configured table.



3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3020

class ConfiguredTableAnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConfiguredTableAnalysisRulePolicyV1; end
  class Aggregation < ConfiguredTableAnalysisRulePolicyV1; end
  class Custom < ConfiguredTableAnalysisRulePolicyV1; end
  class Unknown < ConfiguredTableAnalysisRulePolicyV1; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3020
3021
3022
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3020

def unknown
  @unknown
end