Class: Aws::CleanRooms::Types::ConfiguredTableAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A configured table association links a configured table to a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule_types ⇒ Array<String>
The analysis rule types for the configured table association.
-
#arn ⇒ String
The unique ARN for the configured table association.
-
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this configured table association.
-
#configured_table_arn ⇒ String
The unique ARN for the configured table that the association refers to.
-
#configured_table_id ⇒ String
The unique ID for the configured table that the association refers to.
-
#create_time ⇒ Time
The time the configured table association was created.
-
#description ⇒ String
A description of the configured table association.
-
#id ⇒ String
The unique ID for the configured table association.
-
#membership_arn ⇒ String
The unique ARN for the membership this configured table association belongs to.
-
#membership_id ⇒ String
The unique ID for the membership this configured table association belongs to.
-
#name ⇒ String
The name of the configured table association, in lowercase.
-
#role_arn ⇒ String
The service will assume this role to access catalog metadata and query the table.
-
#update_time ⇒ Time
The time the configured table association was last updated.
Instance Attribute Details
#analysis_rule_types ⇒ Array<String>
The analysis rule types for the configured table association.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique ARN for the configured table association.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this configured table association.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#configured_table_arn ⇒ String
The unique ARN for the configured table that the association refers to.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#configured_table_id ⇒ String
The unique ID for the configured table that the association refers to.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the configured table association was created.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the configured table association.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for the configured table association.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The unique ARN for the membership this configured table association belongs to.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique ID for the membership this configured table association belongs to.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured table association, in lowercase. The table is identified by this name when running protected queries against the underlying data.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The service will assume this role to access catalog metadata and query the table.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the configured table association was last updated.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3100 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |