Class: Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An analysis rule for a configured table association. This analysis
rule specifies how data from the table can be used within its
associated collaboration. In the console, the
ConfiguredTableAssociationAnalysisRule is referred to as the
collaboration analysis rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configured_table_association_arn ⇒ String
The Amazon Resource Name (ARN) of the configured table association.
-
#configured_table_association_id ⇒ String
The unique identifier for the configured table association.
-
#create_time ⇒ Time
The creation time of the configured table association analysis rule.
-
#membership_identifier ⇒ String
The membership identifier for the configured table association analysis rule.
-
#policy ⇒ Types::ConfiguredTableAssociationAnalysisRulePolicy
The policy of the configured table association analysis rule.
-
#type ⇒ String
The type of the configured table association analysis rule.
-
#update_time ⇒ Time
The update time of the configured table association analysis rule.
Instance Attribute Details
#configured_table_association_arn ⇒ String
The Amazon Resource Name (ARN) of the configured table association.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#configured_table_association_id ⇒ String
The unique identifier for the configured table association.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The creation time of the configured table association analysis rule.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership identifier for the configured table association analysis rule.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ Types::ConfiguredTableAssociationAnalysisRulePolicy
The policy of the configured table association analysis rule.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the configured table association analysis rule.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The update time of the configured table association analysis rule.
3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3053 class ConfiguredTableAssociationAnalysisRule < Struct.new( :membership_identifier, :configured_table_association_id, :configured_table_association_arn, :policy, :type, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |