Class: Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRuleAggregation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The configured table association analysis rule applied to a configured table with the aggregation analysis rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_additional_analysesArray<String>

The list of resources or wildcards (ARNs) that are allowed to perform additional analysis on query output.

The allowedAdditionalAnalyses parameter is currently supported for the list analysis rule (AnalysisRuleList) and the custom analysis rule (AnalysisRuleCustom).

Returns:

  • (Array<String>)


2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2793

class ConfiguredTableAssociationAnalysisRuleAggregation < Struct.new(
  :allowed_result_receivers,
  :allowed_additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_result_receiversArray<String>

The list of collaboration members who are allowed to receive results of queries run with this configured table.

Returns:

  • (Array<String>)


2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2793

class ConfiguredTableAssociationAnalysisRuleAggregation < Struct.new(
  :allowed_result_receivers,
  :allowed_additional_analyses)
  SENSITIVE = []
  include Aws::Structure
end