Class: Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRulePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

ConfiguredTableAssociationAnalysisRulePolicy is a union - when making an API calls you must set exactly one of the members.

Note:

ConfiguredTableAssociationAnalysisRulePolicy is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConfiguredTableAssociationAnalysisRulePolicy corresponding to the set member.

Controls on the query specifications that can be run on an associated configured table.

Defined Under Namespace

Classes: Unknown, V1

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3250
3251
3252
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3250

def unknown
  @unknown
end

#v1Types::ConfiguredTableAssociationAnalysisRulePolicyV1

The policy for the configured table association analysis rule.



3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3250

class ConfiguredTableAssociationAnalysisRulePolicy < Struct.new(
  :v1,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class V1 < ConfiguredTableAssociationAnalysisRulePolicy; end
  class Unknown < ConfiguredTableAssociationAnalysisRulePolicy; end
end