Class: Aws::CleanRooms::Types::ConfiguredTableAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The configured table association summary for the objects listed by the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_rule_typesArray<String>

The analysis rule types that are associated with the configured table associations in this summary.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The unique ARN for the configured table association.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#configured_table_idString

The unique configured table ID that this configured table association refers to.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time the configured table association was created.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique ID for the configured table association.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#membership_arnString

The unique ARN for the membership that the configured table association belongs to.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The unique ID for the membership that the configured table association belongs to.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the configured table association. The table is identified by this name when running Protected Queries against the underlying data.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The time the configured table association was last updated.



2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2955

class ConfiguredTableAssociationSummary < Struct.new(
  :configured_table_id,
  :membership_id,
  :membership_arn,
  :name,
  :create_time,
  :update_time,
  :id,
  :arn,
  :analysis_rule_types)
  SENSITIVE = []
  include Aws::Structure
end