Class: Aws::CleanRooms::Types::ConsolidatedPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConsolidatedPolicy
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Note:
ConsolidatedPolicy is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConsolidatedPolicy corresponding to the set member.
Controls on the analysis specifications that can be run on a configured table.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#v1 ⇒ Types::ConsolidatedPolicyV1
The consolidated policy version 1.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
3370 3371 3372 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3370 def unknown @unknown end |
#v1 ⇒ Types::ConsolidatedPolicyV1
The consolidated policy version 1.
3370 3371 3372 3373 3374 3375 3376 3377 3378 3379 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3370 class ConsolidatedPolicy < Struct.new( :v1, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class V1 < ConsolidatedPolicy; end class Unknown < ConsolidatedPolicy; end end |