Class: Aws::CleanRooms::Types::ConsolidatedPolicyV1

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

ConsolidatedPolicyV1 is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConsolidatedPolicyV1 corresponding to the set member.

Controls on the analysis specifications that can be run on a configured table.

Defined Under Namespace

Classes: Aggregation, Custom, List, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregationTypes::ConsolidatedPolicyAggregation

The aggregation setting for the consolidated policy.



3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3546

class ConsolidatedPolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConsolidatedPolicyV1; end
  class Aggregation < ConsolidatedPolicyV1; end
  class Custom < ConsolidatedPolicyV1; end
  class Unknown < ConsolidatedPolicyV1; end
end

#customTypes::ConsolidatedPolicyCustom

Custom policy



3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3546

class ConsolidatedPolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConsolidatedPolicyV1; end
  class Aggregation < ConsolidatedPolicyV1; end
  class Custom < ConsolidatedPolicyV1; end
  class Unknown < ConsolidatedPolicyV1; end
end

#listTypes::ConsolidatedPolicyList

The list of consolidated policies.



3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3546

class ConsolidatedPolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConsolidatedPolicyV1; end
  class Aggregation < ConsolidatedPolicyV1; end
  class Custom < ConsolidatedPolicyV1; end
  class Unknown < ConsolidatedPolicyV1; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3546
3547
3548
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3546

def unknown
  @unknown
end