Class: Aws::CleanRooms::Types::CreateAnalysisTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CreateAnalysisTemplateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:analysis_parameters]
Instance Attribute Summary collapse
-
#analysis_parameters ⇒ Array<Types::AnalysisParameter>
The parameters of the analysis template.
-
#description ⇒ String
The description of the analysis template.
-
#error_message_configuration ⇒ Types::ErrorMessageConfiguration
The configuration that specifies the level of detail in error messages returned by analyses using this template.
-
#format ⇒ String
The format of the analysis template.
-
#membership_identifier ⇒ String
The identifier for a membership resource.
-
#name ⇒ String
The name of the analysis template.
-
#schema ⇒ Types::AnalysisSchema
A relation within an analysis.
-
#source ⇒ Types::AnalysisSource
The information in the analysis template.
-
#synthetic_data_parameters ⇒ Types::SyntheticDataParameters
The parameters for generating synthetic data when running the analysis template.
-
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it.
Instance Attribute Details
#analysis_parameters ⇒ Array<Types::AnalysisParameter>
The parameters of the analysis template.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#description ⇒ String
The description of the analysis template.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#error_message_configuration ⇒ Types::ErrorMessageConfiguration
The configuration that specifies the level of detail in error
messages returned by analyses using this template. When set to
DETAILED, error messages include more information to help
troubleshoot issues with PySpark jobs. Detailed error messages may
expose underlying data, including sensitive information. Recommended
for faster troubleshooting in development and testing environments.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#format ⇒ String
The format of the analysis template.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#membership_identifier ⇒ String
The identifier for a membership resource.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#name ⇒ String
The name of the analysis template.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#schema ⇒ Types::AnalysisSchema
A relation within an analysis.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#source ⇒ Types::AnalysisSource
The information in the analysis template.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#synthetic_data_parameters ⇒ Types::SyntheticDataParameters
The parameters for generating synthetic data when running the analysis template.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3612 class CreateAnalysisTemplateInput < Struct.new( :description, :membership_identifier, :name, :format, :source, :tags, :analysis_parameters, :schema, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |