Class: Aws::CleanRooms::Types::CreateConfiguredAudienceModelAssociationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CreateConfiguredAudienceModelAssociationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configured_audience_model_arn ⇒ String
A unique identifier for the configured audience model that you want to associate.
-
#configured_audience_model_association_name ⇒ String
The name of the configured audience model association.
-
#description ⇒ String
A description of the configured audience model association.
-
#manage_resource_policies ⇒ Boolean
When
TRUE, indicates that the resource policy for the configured audience model resource being associated is configured for Clean Rooms to manage permissions related to the given collaboration. -
#membership_identifier ⇒ String
A unique identifier for one of your memberships for a collaboration.
-
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it.
Instance Attribute Details
#configured_audience_model_arn ⇒ String
A unique identifier for the configured audience model that you want to associate.
3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3844 class CreateConfiguredAudienceModelAssociationInput < Struct.new( :membership_identifier, :configured_audience_model_arn, :configured_audience_model_association_name, :manage_resource_policies, :tags, :description) SENSITIVE = [] include Aws::Structure end |
#configured_audience_model_association_name ⇒ String
The name of the configured audience model association.
3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3844 class CreateConfiguredAudienceModelAssociationInput < Struct.new( :membership_identifier, :configured_audience_model_arn, :configured_audience_model_association_name, :manage_resource_policies, :tags, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the configured audience model association.
3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3844 class CreateConfiguredAudienceModelAssociationInput < Struct.new( :membership_identifier, :configured_audience_model_arn, :configured_audience_model_association_name, :manage_resource_policies, :tags, :description) SENSITIVE = [] include Aws::Structure end |
#manage_resource_policies ⇒ Boolean
When TRUE, indicates that the resource policy for the configured
audience model resource being associated is configured for Clean
Rooms to manage permissions related to the given collaboration. When
FALSE, indicates that the configured audience model resource owner
will manage permissions related to the given collaboration.
Setting this to TRUE requires you to have permissions to create,
update, and delete the resource policy for the cleanrooms-ml
resource when you call the DeleteConfiguredAudienceModelAssociation
resource. In addition, if you are the collaboration creator and
specify TRUE, you must have the same permissions when you call the
DeleteMember and DeleteCollaboration APIs.
3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3844 class CreateConfiguredAudienceModelAssociationInput < Struct.new( :membership_identifier, :configured_audience_model_arn, :configured_audience_model_association_name, :manage_resource_policies, :tags, :description) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
A unique identifier for one of your memberships for a collaboration. The configured audience model is associated to the collaboration that this membership belongs to. Accepts a membership ID.
3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3844 class CreateConfiguredAudienceModelAssociationInput < Struct.new( :membership_identifier, :configured_audience_model_arn, :configured_audience_model_association_name, :manage_resource_policies, :tags, :description) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3844 class CreateConfiguredAudienceModelAssociationInput < Struct.new( :membership_identifier, :configured_audience_model_arn, :configured_audience_model_association_name, :manage_resource_policies, :tags, :description) SENSITIVE = [] include Aws::Structure end |