Class: Aws::CleanRooms::Types::CreateConfiguredTableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CreateConfiguredTableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_columns ⇒ Array<String>
The columns of the underlying table that can be used by collaborations or analysis rules.
-
#analysis_method ⇒ String
The analysis method allowed for the configured tables.
-
#description ⇒ String
A description for the configured table.
-
#name ⇒ String
The name of the configured table.
-
#selected_analysis_methods ⇒ Array<String>
The analysis methods to enable for the configured table.
-
#table_reference ⇒ Types::TableReference
A reference to the table being configured.
-
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it.
Instance Attribute Details
#allowed_columns ⇒ Array<String>
The columns of the underlying table that can be used by collaborations or analysis rules.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |
#analysis_method ⇒ String
The analysis method allowed for the configured tables.
DIRECT_QUERY allows SQL queries to be run directly on this table.
DIRECT_JOB allows PySpark jobs to be run directly on this table.
MULTIPLE allows both SQL queries and PySpark jobs to be run
directly on this table.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the configured table.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured table.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |
#selected_analysis_methods ⇒ Array<String>
The analysis methods to enable for the configured table. When configured, you must specify at least two analysis methods.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |
#table_reference ⇒ Types::TableReference
A reference to the table being configured.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4157 class CreateConfiguredTableInput < Struct.new( :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods, :tags) SENSITIVE = [] include Aws::Structure end |