Class: Aws::CleanRooms::Types::CreateIdMappingTableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CreateIdMappingTableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the ID mapping table.
-
#input_reference_config ⇒ Types::IdMappingTableInputReferenceConfig
The input reference configuration needed to create the ID mapping table.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key.
-
#membership_identifier ⇒ String
The unique identifier of the membership that contains the ID mapping table.
-
#name ⇒ String
A name for the ID mapping table.
-
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it.
Instance Attribute Details
#description ⇒ String
A description of the ID mapping table.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4214 class CreateIdMappingTableInput < Struct.new( :membership_identifier, :name, :description, :input_reference_config, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#input_reference_config ⇒ Types::IdMappingTableInputReferenceConfig
The input reference configuration needed to create the ID mapping table.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4214 class CreateIdMappingTableInput < Struct.new( :membership_identifier, :name, :description, :input_reference_config, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key. This value is used to encrypt the mapping table data that is stored by Clean Rooms.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4214 class CreateIdMappingTableInput < Struct.new( :membership_identifier, :name, :description, :input_reference_config, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The unique identifier of the membership that contains the ID mapping table.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4214 class CreateIdMappingTableInput < Struct.new( :membership_identifier, :name, :description, :input_reference_config, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the ID mapping table.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4214 class CreateIdMappingTableInput < Struct.new( :membership_identifier, :name, :description, :input_reference_config, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4214 class CreateIdMappingTableInput < Struct.new( :membership_identifier, :name, :description, :input_reference_config, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |