Class: Aws::CleanRooms::Types::CreateIdNamespaceAssociationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the ID namespace association.



3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3850

class CreateIdNamespaceAssociationInput < Struct.new(
  :membership_identifier,
  :input_reference_config,
  :tags,
  :name,
  :description,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#id_mapping_configTypes::IdMappingConfig

The configuration settings for the ID mapping table.



3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3850

class CreateIdNamespaceAssociationInput < Struct.new(
  :membership_identifier,
  :input_reference_config,
  :tags,
  :name,
  :description,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#input_reference_configTypes::IdNamespaceAssociationInputReferenceConfig

The input reference configuration needed to create the ID namespace association.



3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3850

class CreateIdNamespaceAssociationInput < Struct.new(
  :membership_identifier,
  :input_reference_config,
  :tags,
  :name,
  :description,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership that contains the ID namespace association.



3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3850

class CreateIdNamespaceAssociationInput < Struct.new(
  :membership_identifier,
  :input_reference_config,
  :tags,
  :name,
  :description,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the ID namespace association.



3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3850

class CreateIdNamespaceAssociationInput < Struct.new(
  :membership_identifier,
  :input_reference_config,
  :tags,
  :name,
  :description,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.



3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3850

class CreateIdNamespaceAssociationInput < Struct.new(
  :membership_identifier,
  :input_reference_config,
  :tags,
  :name,
  :description,
  :id_mapping_config)
  SENSITIVE = []
  include Aws::Structure
end