Class: Aws::CleanRooms::Types::CreateIntermediateTableAnalysisRuleInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_rule_policyTypes::IntermediateTableAnalysisRulePolicy

The analysis rule policy to apply to the intermediate table.



4200
4201
4202
4203
4204
4205
4206
4207
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4200

class CreateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_rule_typeString

The type of analysis rule to create. Currently, only CUSTOM is supported.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4200

class CreateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end

#intermediate_table_identifierString

The unique identifier of the intermediate table for which to create the analysis rule.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4200

class CreateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership that contains the intermediate table.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4200

class CreateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end