Class: Aws::CleanRooms::Types::CreateIntermediateTableAnalysisRuleOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CreateIntermediateTableAnalysisRuleOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule ⇒ Types::IntermediateTableAnalysisRule
The analysis rule that was created for the intermediate table.
Instance Attribute Details
#analysis_rule ⇒ Types::IntermediateTableAnalysisRule
The analysis rule that was created for the intermediate table.
4018 4019 4020 4021 4022 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4018 class CreateIntermediateTableAnalysisRuleOutput < Struct.new( :analysis_rule) SENSITIVE = [] include Aws::Structure end |