Class: Aws::CleanRooms::Types::CreateIntermediateTableInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the intermediate table.

Returns:

  • (String)


4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the customer-managed KMS key used to encrypt the intermediate table data.

Returns:

  • (String)


4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership where the intermediate table is created.

Returns:

  • (String)


4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The display name for the intermediate table.

Returns:

  • (String)


4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#population_analysis_configurationTypes::PopulationAnalysisConfiguration

The configuration that defines the analysis used to populate the intermediate table.



4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#retention_in_daysInteger

The number of days to retain populated data versions.

Returns:

  • (Integer)


4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.

Returns:

  • (Hash<String,String>)


4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257

class CreateIntermediateTableInput < Struct.new(
  :membership_identifier,
  :name,
  :description,
  :population_analysis_configuration,
  :kms_key_arn,
  :retention_in_days,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end