Class: Aws::CleanRooms::Types::CreatePrivacyBudgetTemplateInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_refreshString

How often the privacy budget refreshes.

If you plan to regularly bring new data into the collaboration, you can use CALENDAR_MONTH to automatically get a new privacy budget for the collaboration every calendar month. Choosing this option allows arbitrary amounts of information to be revealed about rows of the data when repeatedly queries across refreshes. Avoid choosing this if the same rows will be repeatedly queried between privacy budget refreshes.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4519

class CreatePrivacyBudgetTemplateInput < Struct.new(
  :membership_identifier,
  :auto_refresh,
  :privacy_budget_type,
  :parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

A unique identifier for one of your memberships for a collaboration. The privacy budget template is created in the collaboration that this membership belongs to. Accepts a membership ID.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4519

class CreatePrivacyBudgetTemplateInput < Struct.new(
  :membership_identifier,
  :auto_refresh,
  :privacy_budget_type,
  :parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::PrivacyBudgetTemplateParametersInput

Specifies your parameters for the privacy budget template.



4519
4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4519

class CreatePrivacyBudgetTemplateInput < Struct.new(
  :membership_identifier,
  :auto_refresh,
  :privacy_budget_type,
  :parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_budget_typeString

Specifies the type of the privacy budget template.

Returns:

  • (String)


4519
4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4519

class CreatePrivacyBudgetTemplateInput < Struct.new(
  :membership_identifier,
  :auto_refresh,
  :privacy_budget_type,
  :parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.

Returns:

  • (Hash<String,String>)


4519
4520
4521
4522
4523
4524
4525
4526
4527
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4519

class CreatePrivacyBudgetTemplateInput < Struct.new(
  :membership_identifier,
  :auto_refresh,
  :privacy_budget_type,
  :parameters,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end