Class: Aws::CleanRooms::Types::DifferentialPrivacySensitivityParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::DifferentialPrivacySensitivityParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Provides the sensitivity parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_expression ⇒ String
The aggregation expression that was run.
-
#aggregation_type ⇒ String
The type of aggregation function that was run.
-
#max_column_value ⇒ Float
The upper bound of the aggregation expression.
-
#min_column_value ⇒ Float
The lower bound of the aggregation expression.
-
#user_contribution_limit ⇒ Integer
The maximum number of rows contributed by a user in a SQL query.
Instance Attribute Details
#aggregation_expression ⇒ String
The aggregation expression that was run.
5069 5070 5071 5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5069 class DifferentialPrivacySensitivityParameters < Struct.new( :aggregation_type, :aggregation_expression, :user_contribution_limit, :min_column_value, :max_column_value) SENSITIVE = [] include Aws::Structure end |
#aggregation_type ⇒ String
The type of aggregation function that was run.
5069 5070 5071 5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5069 class DifferentialPrivacySensitivityParameters < Struct.new( :aggregation_type, :aggregation_expression, :user_contribution_limit, :min_column_value, :max_column_value) SENSITIVE = [] include Aws::Structure end |
#max_column_value ⇒ Float
The upper bound of the aggregation expression.
5069 5070 5071 5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5069 class DifferentialPrivacySensitivityParameters < Struct.new( :aggregation_type, :aggregation_expression, :user_contribution_limit, :min_column_value, :max_column_value) SENSITIVE = [] include Aws::Structure end |
#min_column_value ⇒ Float
The lower bound of the aggregation expression.
5069 5070 5071 5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5069 class DifferentialPrivacySensitivityParameters < Struct.new( :aggregation_type, :aggregation_expression, :user_contribution_limit, :min_column_value, :max_column_value) SENSITIVE = [] include Aws::Structure end |
#user_contribution_limit ⇒ Integer
The maximum number of rows contributed by a user in a SQL query.
5069 5070 5071 5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5069 class DifferentialPrivacySensitivityParameters < Struct.new( :aggregation_type, :aggregation_expression, :user_contribution_limit, :min_column_value, :max_column_value) SENSITIVE = [] include Aws::Structure end |