Class: Aws::CleanRooms::Types::DifferentialPrivacyTemplateUpdateParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The epsilon and noise parameter values that you want to update in the differential privacy template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#epsilonInteger

The updated epsilon value that you want to use.

Returns:

  • (Integer)


5026
5027
5028
5029
5030
5031
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5026

class DifferentialPrivacyTemplateUpdateParameters < Struct.new(
  :epsilon,
  :users_noise_per_query)
  SENSITIVE = []
  include Aws::Structure
end

#users_noise_per_queryInteger

The updated value of noise added per query. It is measured in terms of the number of users whose contributions you want to obscure. This value governs the rate at which the privacy budget is depleted.

Returns:

  • (Integer)


5026
5027
5028
5029
5030
5031
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5026

class DifferentialPrivacyTemplateUpdateParameters < Struct.new(
  :epsilon,
  :users_noise_per_query)
  SENSITIVE = []
  include Aws::Structure
end