Class: Aws::CleanRooms::Types::DisallowIntermediateTableInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_descendantsBoolean

Specifies whether to cascade the disallow action to descendant intermediate tables. Default is true.

Returns:

  • (Boolean)


5064
5065
5066
5067
5068
5069
5070
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5064

class DisallowIntermediateTableInput < Struct.new(
  :membership_identifier,
  :intermediate_table_name,
  :include_descendants)
  SENSITIVE = []
  include Aws::Structure
end

#intermediate_table_nameString

The name of the intermediate table to disallow.

Returns:

  • (String)


5064
5065
5066
5067
5068
5069
5070
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5064

class DisallowIntermediateTableInput < Struct.new(
  :membership_identifier,
  :intermediate_table_name,
  :include_descendants)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership that contains the intermediate table to disallow.

Returns:

  • (String)


5064
5065
5066
5067
5068
5069
5070
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5064

class DisallowIntermediateTableInput < Struct.new(
  :membership_identifier,
  :intermediate_table_name,
  :include_descendants)
  SENSITIVE = []
  include Aws::Structure
end