Class: Aws::CleanRooms::Types::ErrorMessageConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

A structure that defines the level of detail included in error messages returned by PySpark jobs. This configuration allows you to control the verbosity of error messages to help with troubleshooting PySpark jobs while maintaining appropriate security controls.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The level of detail for error messages returned by the PySpark job. When set to DETAILED, error messages include more information to help troubleshoot issues with your PySpark job.

Because this setting may expose sensitive data, it is recommended for development and testing environments.

Returns:

  • (String)


4897
4898
4899
4900
4901
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4897

class ErrorMessageConfiguration < Struct.new(
  :type)
  SENSITIVE = []
  include Aws::Structure
end