Class: Aws::CleanRooms::Types::GetAnalysisLogExportInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_log_export_identifierString

The unique identifier of the analysis log export to retrieve.

Returns:

  • (String)


5109
5110
5111
5112
5113
5114
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5109

class GetAnalysisLogExportInput < Struct.new(
  :membership_identifier,
  :analysis_log_export_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

A unique identifier for the membership that the analysis log export belongs to. Currently accepts the membership ID.

Returns:

  • (String)


5109
5110
5111
5112
5113
5114
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5109

class GetAnalysisLogExportInput < Struct.new(
  :membership_identifier,
  :analysis_log_export_identifier)
  SENSITIVE = []
  include Aws::Structure
end