Class: Aws::CleanRooms::Types::GetIntermediateTableAnalysisRuleInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::GetIntermediateTableAnalysisRuleInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule_type ⇒ String
The type of analysis rule to retrieve.
-
#intermediate_table_identifier ⇒ String
The unique identifier of the intermediate table for which to retrieve the analysis rule.
-
#membership_identifier ⇒ String
The unique identifier of the membership that contains the intermediate table.
Instance Attribute Details
#analysis_rule_type ⇒ String
The type of analysis rule to retrieve. Currently, only CUSTOM is
supported.
5570 5571 5572 5573 5574 5575 5576 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5570 class GetIntermediateTableAnalysisRuleInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :analysis_rule_type) SENSITIVE = [] include Aws::Structure end |
#intermediate_table_identifier ⇒ String
The unique identifier of the intermediate table for which to retrieve the analysis rule.
5570 5571 5572 5573 5574 5575 5576 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5570 class GetIntermediateTableAnalysisRuleInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :analysis_rule_type) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The unique identifier of the membership that contains the intermediate table.
5570 5571 5572 5573 5574 5575 5576 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5570 class GetIntermediateTableAnalysisRuleInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :analysis_rule_type) SENSITIVE = [] include Aws::Structure end |