Class: Aws::CleanRooms::Types::IdMappingTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IdMappingTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Describes information about the ID mapping table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the ID mapping table.
-
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this ID mapping table.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this ID mapping table.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this ID mapping table.
-
#create_time ⇒ Time
The time at which the ID mapping table was created.
-
#description ⇒ String
The description of the ID mapping table.
-
#id ⇒ String
The unique identifier of the ID mapping table.
-
#input_reference_config ⇒ Types::IdMappingTableInputReferenceConfig
The input reference configuration for the ID mapping table.
-
#input_reference_properties ⇒ Types::IdMappingTableInputReferenceProperties
The input reference properties for the ID mapping table.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership resource for the ID mapping table.
-
#membership_id ⇒ String
The unique identifier of the membership resource for the ID mapping table.
-
#name ⇒ String
The name of the ID mapping table.
-
#update_time ⇒ Time
The most recent time at which the ID mapping table was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the ID mapping table was created.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#input_reference_config ⇒ Types::IdMappingTableInputReferenceConfig
The input reference configuration for the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#input_reference_properties ⇒ Types::IdMappingTableInputReferenceProperties
The input reference properties for the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership resource for the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership resource for the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the ID mapping table.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the ID mapping table was updated.
5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5698 class IdMappingTable < Struct.new( :id, :arn, :input_reference_config, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :description, :name, :create_time, :update_time, :input_reference_properties, :kms_key_arn, :child_resources) SENSITIVE = [] include Aws::Structure end |