Class: Aws::CleanRooms::Types::IdNamespaceAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IdNamespaceAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Provides information to create the ID namespace association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the ID namespace association.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this ID namespace association.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this ID namespace association.
-
#create_time ⇒ Time
The time at which the ID namespace association was created.
-
#description ⇒ String
The description of the ID namespace association.
-
#id ⇒ String
The unique identifier for this ID namespace association.
-
#id_mapping_config ⇒ Types::IdMappingConfig
The configuration settings for the ID mapping table.
-
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration for the ID namespace association.
-
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferenceProperties
The input reference properties for the ID namespace association.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership resource for this ID namespace association.
-
#membership_id ⇒ String
The unique identifier of the membership resource for this ID namespace association.
-
#name ⇒ String
The name of this ID namespace association.
-
#update_time ⇒ Time
The most recent time at which the ID namespace association was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the ID namespace association was created.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for this ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#id_mapping_config ⇒ Types::IdMappingConfig
The configuration settings for the ID mapping table.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration for the ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferenceProperties
The input reference properties for the ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership resource for this ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership resource for this ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of this ID namespace association.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the ID namespace association was updated.
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6261 class IdNamespaceAssociation < Struct.new( :id, :arn, :membership_id, :membership_arn, :collaboration_id, :collaboration_arn, :name, :description, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |