Class: Aws::CleanRooms::Types::IdNamespaceAssociationInputReferenceConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IdNamespaceAssociationInputReferenceConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Provides the information for the ID namespace association input reference configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_reference_arn ⇒ String
The Amazon Resource Name (ARN) of the Entity Resolution resource that is being associated to the collaboration.
-
#manage_resource_policies ⇒ Boolean
When
TRUE, Clean Rooms manages permissions for the ID namespace association resource.
Instance Attribute Details
#input_reference_arn ⇒ String
The Amazon Resource Name (ARN) of the Entity Resolution resource that is being associated to the collaboration. Valid resource ARNs are from the ID namespaces that you own.
6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6298 class IdNamespaceAssociationInputReferenceConfig < Struct.new( :input_reference_arn, :manage_resource_policies) SENSITIVE = [] include Aws::Structure end |
#manage_resource_policies ⇒ Boolean
When TRUE, Clean Rooms manages permissions for the ID namespace
association resource.
When FALSE, the resource owner manages permissions for the ID
namespace association resource.
6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6298 class IdNamespaceAssociationInputReferenceConfig < Struct.new( :input_reference_arn, :manage_resource_policies) SENSITIVE = [] include Aws::Structure end |