Class: Aws::CleanRooms::Types::InheritedAllowedResultReceivers

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains the inherited allowed result receivers constraint and its sources from parent tables.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sourcesArray<Types::InheritedAllowedResultReceiversSource>

The list of parent tables that contribute to this inherited constraint.



6435
6436
6437
6438
6439
6440
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6435

class InheritedAllowedResultReceivers < Struct.new(
  :value,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#valueArray<String>

The effective list of Amazon Web Services account IDs allowed to receive results, inherited from parent tables.

Returns:

  • (Array<String>)


6435
6436
6437
6438
6439
6440
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6435

class InheritedAllowedResultReceivers < Struct.new(
  :value,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end