Class: Aws::CleanRooms::Types::IntermediateTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IntermediateTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains the details of an intermediate table in Clean Rooms. An intermediate table stores a query definition and its materialized results within a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule_types ⇒ Array<String>
The types of analysis rules associated with the intermediate table.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the intermediate table.
-
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this intermediate table.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the intermediate table.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains the intermediate table.
-
#create_time ⇒ Time
The time the intermediate table was created.
-
#description ⇒ String
The description of the intermediate table.
-
#id ⇒ String
The unique identifier of the intermediate table.
-
#intermediate_table_version ⇒ Types::IntermediateTableActiveVersion
The details of the currently active version of the intermediate table.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the intermediate table data.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership that contains the intermediate table.
-
#membership_id ⇒ String
The unique identifier of the membership that contains the intermediate table.
-
#name ⇒ String
The name of the intermediate table.
-
#population_analysis_configuration ⇒ Types::PopulationAnalysisConfiguration
The analysis configuration that defines the query used to populate the intermediate table.
-
#retention_in_days ⇒ Integer
The number of days that populated data is retained before expiring.
-
#schema ⇒ Types::IntermediateTableSchema
The schema of the intermediate table, containing column definitions.
-
#status ⇒ String
The current status of the intermediate table.
-
#status_reason ⇒ String
The reason for the current status of the intermediate table.
-
#table_dependencies ⇒ Array<Types::IntermediateTableDependency>
The list of base tables that this intermediate table depends on.
-
#update_time ⇒ Time
The time the intermediate table was last updated.
Instance Attribute Details
#analysis_rule_types ⇒ Array<String>
The types of analysis rules associated with the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the intermediate table was created.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#intermediate_table_version ⇒ Types::IntermediateTableActiveVersion
The details of the currently active version of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the intermediate table data.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership that contains the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership that contains the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#population_analysis_configuration ⇒ Types::PopulationAnalysisConfiguration
The analysis configuration that defines the query used to populate the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days that populated data is retained before expiring.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ Types::IntermediateTableSchema
The schema of the intermediate table, containing column definitions. Available after the table has been successfully populated.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the intermediate table.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#table_dependencies ⇒ Array<Types::IntermediateTableDependency>
The list of base tables that this intermediate table depends on.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the intermediate table was last updated.
6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6594 class IntermediateTable < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :child_resources, :create_time, :update_time, :status, :status_reason, :kms_key_arn, :population_analysis_configuration, :retention_in_days, :table_dependencies, :intermediate_table_version, :analysis_rule_types, :schema) SENSITIVE = [] include Aws::Structure end |