Class: Aws::CleanRooms::Types::IntermediateTableAnalysisRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains the details of an analysis rule for an intermediate table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_rule_policyTypes::IntermediateTableAnalysisRulePolicy

The policy of the analysis rule.



6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6696

class IntermediateTableAnalysisRule < Struct.new(
  :intermediate_table_identifier,
  :intermediate_table_arn,
  :analysis_rule_policy,
  :analysis_rule_type,
  :create_time,
  :update_time)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_rule_typeString

The type of the analysis rule.

Returns:

  • (String)


6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6696

class IntermediateTableAnalysisRule < Struct.new(
  :intermediate_table_identifier,
  :intermediate_table_arn,
  :analysis_rule_policy,
  :analysis_rule_type,
  :create_time,
  :update_time)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time the analysis rule was created.

Returns:

  • (Time)


6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6696

class IntermediateTableAnalysisRule < Struct.new(
  :intermediate_table_identifier,
  :intermediate_table_arn,
  :analysis_rule_policy,
  :analysis_rule_type,
  :create_time,
  :update_time)
  SENSITIVE = []
  include Aws::Structure
end

#intermediate_table_arnString

The Amazon Resource Name (ARN) of the intermediate table associated with this analysis rule.

Returns:

  • (String)


6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6696

class IntermediateTableAnalysisRule < Struct.new(
  :intermediate_table_identifier,
  :intermediate_table_arn,
  :analysis_rule_policy,
  :analysis_rule_type,
  :create_time,
  :update_time)
  SENSITIVE = []
  include Aws::Structure
end

#intermediate_table_identifierString

The unique identifier of the intermediate table associated with this analysis rule.

Returns:

  • (String)


6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6696

class IntermediateTableAnalysisRule < Struct.new(
  :intermediate_table_identifier,
  :intermediate_table_arn,
  :analysis_rule_policy,
  :analysis_rule_type,
  :create_time,
  :update_time)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The time the analysis rule was last updated.

Returns:

  • (Time)


6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6696

class IntermediateTableAnalysisRule < Struct.new(
  :intermediate_table_identifier,
  :intermediate_table_arn,
  :analysis_rule_policy,
  :analysis_rule_type,
  :create_time,
  :update_time)
  SENSITIVE = []
  include Aws::Structure
end