Class: Aws::CleanRooms::Types::IntermediateTableAnalysisRuleCustom
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IntermediateTableAnalysisRuleCustom
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains the custom analysis rule configuration for an intermediate table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_analyses ⇒ String
The setting that controls whether additional analyses are allowed on the intermediate table.
-
#aggregation_thresholds ⇒ Array<Types::AggregationThreshold>
The aggregation thresholds that each query output group must satisfy.
-
#allowed_additional_analyses ⇒ Array<String>
The list of allowed additional analyses for the intermediate table.
-
#allowed_analyses ⇒ Array<String>
The list of allowed analyses that can be performed on the intermediate table.
-
#allowed_analysis_providers ⇒ Array<String>
The list of Amazon Web Services account IDs for the allowed analysis providers.
-
#allowed_result_receivers ⇒ Array<String>
The list of Amazon Web Services account IDs that are allowed to receive results from queries run on the intermediate table.
-
#comparison_controls ⇒ Types::ComparisonControls
The controls that restrict how a query can compare the columns in the intermediate table.
-
#differential_privacy ⇒ Types::DifferentialPrivacyConfiguration
Specifies the unique identifier for your users.
-
#disallowed_output_columns ⇒ Array<String>
The list of columns that are not allowed in the query output.
Instance Attribute Details
#additional_analyses ⇒ String
The setting that controls whether additional analyses are allowed on the intermediate table.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#aggregation_thresholds ⇒ Array<Types::AggregationThreshold>
The aggregation thresholds that each query output group must
satisfy. Clean Rooms filters out any group that represents fewer
than the specified number of distinct identities. You can specify at
most one threshold. You can't use aggregation thresholds with
differential privacy, or when allowedAnalyses allows only jobs.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#allowed_additional_analyses ⇒ Array<String>
The list of allowed additional analyses for the intermediate table.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#allowed_analyses ⇒ Array<String>
The list of allowed analyses that can be performed on the intermediate table.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#allowed_analysis_providers ⇒ Array<String>
The list of Amazon Web Services account IDs for the allowed analysis providers.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#allowed_result_receivers ⇒ Array<String>
The list of Amazon Web Services account IDs that are allowed to receive results from queries run on the intermediate table.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#comparison_controls ⇒ Types::ComparisonControls
The controls that restrict how a query can compare the columns in
the intermediate table. You can't use comparison controls with
differential privacy, or when allowedAnalyses allows only jobs.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#differential_privacy ⇒ Types::DifferentialPrivacyConfiguration
Specifies the unique identifier for your users.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |
#disallowed_output_columns ⇒ Array<String>
The list of columns that are not allowed in the query output.
6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6870 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns, :aggregation_thresholds, :comparison_controls) SENSITIVE = [] include Aws::Structure end |