Class: Aws::CleanRooms::Types::IntermediateTableAnalysisRulePolicyV1

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

IntermediateTableAnalysisRulePolicyV1 is a union - when making an API calls you must set exactly one of the members.

Note:

IntermediateTableAnalysisRulePolicyV1 is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IntermediateTableAnalysisRulePolicyV1 corresponding to the set member.

Contains the version 1 policy for an intermediate table analysis rule.

Defined Under Namespace

Classes: Custom, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customTypes::IntermediateTableAnalysisRuleCustom

The custom analysis rule policy.



6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6791

class IntermediateTableAnalysisRulePolicyV1 < Struct.new(
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Custom < IntermediateTableAnalysisRulePolicyV1; end
  class Unknown < IntermediateTableAnalysisRulePolicyV1; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6791
6792
6793
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6791

def unknown
  @unknown
end