Class: Aws::CleanRooms::Types::IntermediateTableDependency
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IntermediateTableDependency
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains information about a base table that an intermediate table depends on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creator_account_id ⇒ String
The Amazon Web Services account ID of the member who owns the dependency table.
-
#id ⇒ String
The unique identifier of the dependency table.
-
#name ⇒ String
The name of the dependency table.
-
#parent_type ⇒ String
The type of dependency, either direct or indirect.
-
#type ⇒ String
The type of the dependency table.
Instance Attribute Details
#creator_account_id ⇒ String
The Amazon Web Services account ID of the member who owns the dependency table.
6873 6874 6875 6876 6877 6878 6879 6880 6881 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6873 class IntermediateTableDependency < Struct.new( :id, :name, :type, :parent_type, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the dependency table.
6873 6874 6875 6876 6877 6878 6879 6880 6881 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6873 class IntermediateTableDependency < Struct.new( :id, :name, :type, :parent_type, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the dependency table.
6873 6874 6875 6876 6877 6878 6879 6880 6881 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6873 class IntermediateTableDependency < Struct.new( :id, :name, :type, :parent_type, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#parent_type ⇒ String
The type of dependency, either direct or indirect. A direct dependency is a table explicitly referenced in the stored query. An indirect dependency is a table referenced through another intermediate table.
6873 6874 6875 6876 6877 6878 6879 6880 6881 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6873 class IntermediateTableDependency < Struct.new( :id, :name, :type, :parent_type, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the dependency table.
6873 6874 6875 6876 6877 6878 6879 6880 6881 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6873 class IntermediateTableDependency < Struct.new( :id, :name, :type, :parent_type, :creator_account_id) SENSITIVE = [] include Aws::Structure end |