Class: Aws::CleanRooms::Types::IntermediateTableSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IntermediateTableSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains summary information about an intermediate table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule_types ⇒ Array<String>
The types of analysis rules associated with the intermediate table.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the intermediate table.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the intermediate table.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains the intermediate table.
-
#create_time ⇒ Time
The time the intermediate table was created.
-
#description ⇒ String
The description of the intermediate table.
-
#id ⇒ String
The unique identifier of the intermediate table.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership that contains the intermediate table.
-
#membership_id ⇒ String
The unique identifier of the membership that contains the intermediate table.
-
#name ⇒ String
The name of the intermediate table.
-
#retention_in_days ⇒ Integer
The number of days that populated data is retained before expiring.
-
#status ⇒ String
The current status of the intermediate table.
-
#update_time ⇒ Time
The time the intermediate table was last updated.
Instance Attribute Details
#analysis_rule_types ⇒ Array<String>
The types of analysis rules associated with the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the intermediate table was created.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership that contains the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership that contains the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days that populated data is retained before expiring.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the intermediate table.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the intermediate table was last updated.
7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7154 class IntermediateTableSummary < Struct.new( :id, :arn, :name, :description, :membership_arn, :membership_id, :collaboration_arn, :collaboration_id, :create_time, :update_time, :status, :retention_in_days, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |