Class: Aws::CleanRooms::Types::IntermediateTableVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains summary information about a version of an intermediate table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The identifier of the protected query that created this version.

Returns:

  • (String)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_typeString

The type of analysis that created this version.

Returns:

  • (String)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time the version was created.

Returns:

  • (Time)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timeTime

The time when this version expires based on the retention period.

Returns:

  • (Time)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key used to encrypt this version's data.

Returns:

  • (String)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the version.

Returns:

  • (String)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#table_idString

The unique identifier of the intermediate table that this version belongs to.

Returns:

  • (String)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The unique identifier of the version.

Returns:

  • (String)


7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082

class IntermediateTableVersionSummary < Struct.new(
  :version_id,
  :table_id,
  :create_time,
  :analysis_id,
  :status,
  :analysis_type,
  :kms_key_arn,
  :expiration_time)
  SENSITIVE = []
  include Aws::Structure
end