Class: Aws::CleanRooms::Types::JobComputePaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::JobComputePaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the collaboration member's payment responsibilities set by the collaboration creator for query and job compute costs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration creator has configured the collaboration member to pay for query and job compute costs (
TRUE) or has not configured the collaboration member to pay for query and job compute costs (FALSE).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration creator has configured the
collaboration member to pay for query and job compute costs (TRUE)
or has not configured the collaboration member to pay for query and
job compute costs (FALSE).
One or more members can be configured as payer candidates for query and job compute costs.
An error is returned if the collaboration creator sets a FALSE
value for the member who can run queries and jobs.
7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7127 class JobComputePaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |