Class: Aws::CleanRooms::Types::ListConfiguredAudienceModelAssociationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListConfiguredAudienceModelAssociationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned for an API request call.
-
#membership_identifier ⇒ String
A unique identifier for a membership that contains the configured audience model associations that you want to retrieve.
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned for an API request
call. The service chooses a default number if you don't set one.
The service might return a nextToken even if the maxResults
value has not been met.
7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7690 class ListConfiguredAudienceModelAssociationsInput < Struct.new( :membership_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
A unique identifier for a membership that contains the configured audience model associations that you want to retrieve.
7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7690 class ListConfiguredAudienceModelAssociationsInput < Struct.new( :membership_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
7690 7691 7692 7693 7694 7695 7696 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7690 class ListConfiguredAudienceModelAssociationsInput < Struct.new( :membership_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |