Class: Aws::CleanRooms::Types::ListIntermediateTableVersionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListIntermediateTableVersionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#intermediate_table_identifier ⇒ String
The unique identifier of the intermediate table for which to list versions.
-
#max_results ⇒ Integer
The maximum number of results that are returned for an API request call.
-
#membership_identifier ⇒ String
The unique identifier of the membership that contains the intermediate table.
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
Instance Attribute Details
#intermediate_table_identifier ⇒ String
The unique identifier of the intermediate table for which to list versions.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7904 class ListIntermediateTableVersionsInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results that are returned for an API request
call. The service chooses a default number if you don't set one.
The service might return a nextToken even if the maxResults
value has not been met.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7904 class ListIntermediateTableVersionsInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The unique identifier of the membership that contains the intermediate table.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7904 class ListIntermediateTableVersionsInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
7904 7905 7906 7907 7908 7909 7910 7911 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7904 class ListIntermediateTableVersionsInput < Struct.new( :membership_identifier, :intermediate_table_identifier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |