Class: Aws::CleanRooms::Types::ListIntermediateTableVersionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListIntermediateTableVersionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#intermediate_table_version_summaries ⇒ Array<Types::IntermediateTableVersionSummary>
The list of intermediate table version summaries.
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
Instance Attribute Details
#intermediate_table_version_summaries ⇒ Array<Types::IntermediateTableVersionSummary>
The list of intermediate table version summaries.
7923 7924 7925 7926 7927 7928 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7923 class ListIntermediateTableVersionsOutput < Struct.new( :intermediate_table_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
7923 7924 7925 7926 7927 7928 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7923 class ListIntermediateTableVersionsOutput < Struct.new( :intermediate_table_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |