Class: Aws::CleanRooms::Types::ListIntermediateTablesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results that are returned for an API request call. The service chooses a default number if you don't set one. The service might return a nextToken even if the maxResults value has not been met.

Returns:



7948
7949
7950
7951
7952
7953
7954
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7948

class ListIntermediateTablesInput < Struct.new(
  :membership_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership for which to list intermediate tables.

Returns:



7948
7949
7950
7951
7952
7953
7954
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7948

class ListIntermediateTablesInput < Struct.new(
  :membership_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token that's used to fetch the next set of results.

Returns:



7948
7949
7950
7951
7952
7953
7954
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7948

class ListIntermediateTablesInput < Struct.new(
  :membership_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end