Class: Aws::CleanRooms::Types::ListIntermediateTablesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListIntermediateTablesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#intermediate_table_summaries ⇒ Array<Types::IntermediateTableSummary>
The list of intermediate table summaries.
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
Instance Attribute Details
#intermediate_table_summaries ⇒ Array<Types::IntermediateTableSummary>
The list of intermediate table summaries.
7966 7967 7968 7969 7970 7971 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7966 class ListIntermediateTablesOutput < Struct.new( :intermediate_table_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
7966 7967 7968 7969 7970 7971 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7966 class ListIntermediateTablesOutput < Struct.new( :intermediate_table_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |