Class: Aws::CleanRooms::Types::ListPrivacyBudgetTemplatesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results that are returned for an API request call. The service chooses a default number if you don't set one. The service might return a nextToken even if the maxResults value has not been met.

Returns:



8076
8077
8078
8079
8080
8081
8082
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8076

class ListPrivacyBudgetTemplatesInput < Struct.new(
  :membership_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

A unique identifier for one of your memberships for a collaboration. The privacy budget templates are retrieved from the collaboration that this membership belongs to. Accepts a membership ID.

Returns:



8076
8077
8078
8079
8080
8081
8082
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8076

class ListPrivacyBudgetTemplatesInput < Struct.new(
  :membership_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token that's used to fetch the next set of results.

Returns:



8076
8077
8078
8079
8080
8081
8082
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8076

class ListPrivacyBudgetTemplatesInput < Struct.new(
  :membership_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end