Class: Aws::CleanRooms::Types::ListPrivacyBudgetsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_budget_resource_arnString

The Amazon Resource Name (ARN) of the access budget resource to filter privacy budgets by.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6473

class ListPrivacyBudgetsInput < Struct.new(
  :membership_identifier,
  :privacy_budget_type,
  :next_token,
  :max_results,
  :access_budget_resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results that are returned for an API request call. The service chooses a default number if you don’t set one. The service might return a nextToken even if the maxResults value has not been met.

Returns:

  • (Integer)


6473
6474
6475
6476
6477
6478
6479
6480
6481
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6473

class ListPrivacyBudgetsInput < Struct.new(
  :membership_identifier,
  :privacy_budget_type,
  :next_token,
  :max_results,
  :access_budget_resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

A unique identifier for one of your memberships for a collaboration. The privacy budget is retrieved from the collaboration that this membership belongs to. Accepts a membership ID.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6473

class ListPrivacyBudgetsInput < Struct.new(
  :membership_identifier,
  :privacy_budget_type,
  :next_token,
  :max_results,
  :access_budget_resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token that’s used to fetch the next set of results.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6473

class ListPrivacyBudgetsInput < Struct.new(
  :membership_identifier,
  :privacy_budget_type,
  :next_token,
  :max_results,
  :access_budget_resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_budget_typeString

The privacy budget type.

Returns:

  • (String)


6473
6474
6475
6476
6477
6478
6479
6480
6481
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6473

class ListPrivacyBudgetsInput < Struct.new(
  :membership_identifier,
  :privacy_budget_type,
  :next_token,
  :max_results,
  :access_budget_resource_arn)
  SENSITIVE = []
  include Aws::Structure
end