Class: Aws::CleanRooms::Types::ListProtectedJobsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListProtectedJobsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned for an API request call.
-
#membership_identifier ⇒ String
The identifier for the membership in the collaboration.
-
#next_token ⇒ String
The pagination token that’s used to fetch the next set of results.
-
#status ⇒ String
A filter on the status of the protected job.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned for an API request call. The service chooses a default number if you don’t set one. The service might return a nextToken even if the maxResults value has not been met.
6523 6524 6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6523 class ListProtectedJobsInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The identifier for the membership in the collaboration.
6523 6524 6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6523 class ListProtectedJobsInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that’s used to fetch the next set of results.
6523 6524 6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6523 class ListProtectedJobsInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A filter on the status of the protected job.
6523 6524 6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6523 class ListProtectedJobsInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |