Class: Aws::CleanRooms::Types::ListProtectedJobsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListProtectedJobsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
-
#protected_jobs ⇒ Array<Types::ProtectedJobSummary>
A list of protected job summaries.
Instance Attribute Details
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
8200 8201 8202 8203 8204 8205 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8200 class ListProtectedJobsOutput < Struct.new( :next_token, :protected_jobs) SENSITIVE = [] include Aws::Structure end |
#protected_jobs ⇒ Array<Types::ProtectedJobSummary>
A list of protected job summaries.
8200 8201 8202 8203 8204 8205 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8200 class ListProtectedJobsOutput < Struct.new( :next_token, :protected_jobs) SENSITIVE = [] include Aws::Structure end |