Class: Aws::CleanRooms::Types::ListProtectedQueriesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ListProtectedQueriesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned for an API request call.
-
#membership_identifier ⇒ String
The identifier for the membership in the collaboration.
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
-
#status ⇒ String
A filter on the status of the protected query.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned for an API request
call. The service chooses a default number if you don't set one.
The service might return a nextToken even if the maxResults
value has not been met.
8228 8229 8230 8231 8232 8233 8234 8235 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8228 class ListProtectedQueriesInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The identifier for the membership in the collaboration.
8228 8229 8230 8231 8232 8233 8234 8235 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8228 class ListProtectedQueriesInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
8228 8229 8230 8231 8232 8233 8234 8235 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8228 class ListProtectedQueriesInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A filter on the status of the protected query.
8228 8229 8230 8231 8232 8233 8234 8235 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8228 class ListProtectedQueriesInput < Struct.new( :membership_identifier, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |