Class: Aws::CleanRooms::Types::MemberChangeSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Specifies changes to collaboration membership, including adding new members with their abilities and display names.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID of the member to add to the collaboration.

Returns:

  • (String)


8320
8321
8322
8323
8324
8325
8326
8327
8328
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8320

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :ml_member_abilities,
  :payment_configuration,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

Specifies the display name that will be shown for this member in the collaboration. While this field is required when inviting new members, it becomes optional when modifying abilities of existing collaboration members.

Returns:

  • (String)


8320
8321
8322
8323
8324
8325
8326
8327
8328
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8320

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :ml_member_abilities,
  :payment_configuration,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#member_abilitiesArray<String>

The abilities granted to the collaboration member. These determine what actions the member can perform within the collaboration.

The following values are currently not supported: CAN_QUERY and CAN_RUN_JOB.

Set the value of memberAbilities to [] to allow a member to contribute data.

Set the value of memberAbilities to [CAN_RECEIVE_RESULTS] to allow a member to contribute data and receive results.

Set the value of memberAbilities to [CAN_EXPORT_QUERY_ANALYSIS_LOG] so that the member can export the analysis logs for a protected query. Having this ability isn't sufficient on its own: You can export logs only for queries that you ran or paid for.

Returns:

  • (Array<String>)


8320
8321
8322
8323
8324
8325
8326
8327
8328
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8320

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :ml_member_abilities,
  :payment_configuration,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#ml_member_abilitiesTypes::MLMemberAbilities

The ML member abilities for a collaboration member.



8320
8321
8322
8323
8324
8325
8326
8327
8328
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8320

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :ml_member_abilities,
  :payment_configuration,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#payment_configurationTypes::PaymentConfiguration

An object representing the collaboration member's payment responsibilities set by the collaboration creator.



8320
8321
8322
8323
8324
8325
8326
8327
8328
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8320

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :ml_member_abilities,
  :payment_configuration,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end