Class: Aws::CleanRooms::Types::MembershipJobComputePaymentConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

An object representing the payment responsibilities accepted by the collaboration member for query and job compute costs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_responsibleBoolean

Indicates whether the collaboration member has accepted to pay for job compute costs (TRUE) or has not accepted to pay for query and job compute costs (FALSE).

There can be one or more members who are designated as payer candidates for queries and jobs.

An error message is returned for the following reasons:

  • If you set the value to FALSE but you are responsible to pay for query and job compute costs.

  • If you set the value to TRUE but you are not responsible to pay for query and job compute costs.

Returns:

  • (Boolean)


8283
8284
8285
8286
8287
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8283

class MembershipJobComputePaymentConfig < Struct.new(
  :is_responsible)
  SENSITIVE = []
  include Aws::Structure
end