Class: Aws::CleanRooms::Types::MembershipMLPaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipMLPaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the collaboration member’s machine learning payment responsibilities set by the collaboration creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_inference ⇒ Types::MembershipModelInferencePaymentConfig
The payment responsibilities accepted by the member for model inference.
-
#model_training ⇒ Types::MembershipModelTrainingPaymentConfig
The payment responsibilities accepted by the member for model training.
-
#synthetic_data_generation ⇒ Types::MembershipSyntheticDataGenerationPaymentConfig
The payment configuration for synthetic data generation for this machine learning membership.
Instance Attribute Details
#model_inference ⇒ Types::MembershipModelInferencePaymentConfig
The payment responsibilities accepted by the member for model inference.
7047 7048 7049 7050 7051 7052 7053 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7047 class MembershipMLPaymentConfig < Struct.new( :model_training, :model_inference, :synthetic_data_generation) SENSITIVE = [] include Aws::Structure end |
#model_training ⇒ Types::MembershipModelTrainingPaymentConfig
The payment responsibilities accepted by the member for model training.
7047 7048 7049 7050 7051 7052 7053 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7047 class MembershipMLPaymentConfig < Struct.new( :model_training, :model_inference, :synthetic_data_generation) SENSITIVE = [] include Aws::Structure end |
#synthetic_data_generation ⇒ Types::MembershipSyntheticDataGenerationPaymentConfig
The payment configuration for synthetic data generation for this machine learning membership.
7047 7048 7049 7050 7051 7052 7053 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7047 class MembershipMLPaymentConfig < Struct.new( :model_training, :model_inference, :synthetic_data_generation) SENSITIVE = [] include Aws::Structure end |