Class: Aws::CleanRooms::Types::MembershipModelInferencePaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipModelInferencePaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the collaboration member’s model inference payment responsibilities set by the collaboration creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for model inference costs (
TRUE) or has not accepted to pay for model inference costs (FALSE).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for model inference costs (TRUE) or has not accepted to pay for model inference costs (FALSE).
If the collaboration creator has not specified anyone to pay for model inference costs, then the member who can query is the default payer.
An error message is returned for the following reasons:
-
If you set the value to
FALSEbut you are responsible to pay for model inference costs. -
If you set the value to
TRUEbut you are not responsible to pay for model inference costs.
7075 7076 7077 7078 7079 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7075 class MembershipModelInferencePaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |