Class: Aws::CleanRooms::Types::MembershipPaymentConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipPaymentConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the payment responsibilities accepted by the collaboration member.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_compute ⇒ Types::MembershipJobComputePaymentConfig
The payment responsibilities accepted by the collaboration member for job compute costs.
-
#machine_learning ⇒ Types::MembershipMLPaymentConfig
The payment responsibilities accepted by the collaboration member for machine learning costs.
-
#query_compute ⇒ Types::MembershipQueryComputePaymentConfig
The payment responsibilities accepted by the collaboration member for query compute costs.
Instance Attribute Details
#job_compute ⇒ Types::MembershipJobComputePaymentConfig
The payment responsibilities accepted by the collaboration member for job compute costs.
7133 7134 7135 7136 7137 7138 7139 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7133 class MembershipPaymentConfiguration < Struct.new( :query_compute, :machine_learning, :job_compute) SENSITIVE = [] include Aws::Structure end |
#machine_learning ⇒ Types::MembershipMLPaymentConfig
The payment responsibilities accepted by the collaboration member for machine learning costs.
7133 7134 7135 7136 7137 7138 7139 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7133 class MembershipPaymentConfiguration < Struct.new( :query_compute, :machine_learning, :job_compute) SENSITIVE = [] include Aws::Structure end |
#query_compute ⇒ Types::MembershipQueryComputePaymentConfig
The payment responsibilities accepted by the collaboration member for query compute costs.
7133 7134 7135 7136 7137 7138 7139 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7133 class MembershipPaymentConfiguration < Struct.new( :query_compute, :machine_learning, :job_compute) SENSITIVE = [] include Aws::Structure end |