Class: Aws::CleanRooms::Types::MembershipProtectedJobOutputConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipProtectedJobOutputConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Note:
MembershipProtectedJobOutputConfiguration is a union - when making an API calls you must set exactly one of the members.
Note:
MembershipProtectedJobOutputConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MembershipProtectedJobOutputConfiguration corresponding to the set member.
Contains configurations for protected job results.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3 ⇒ Types::ProtectedJobS3OutputConfigurationInput
Contains the configuration to write the job results to S3.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3 ⇒ Types::ProtectedJobS3OutputConfigurationInput
Contains the configuration to write the job results to S3.
7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7150 class MembershipProtectedJobOutputConfiguration < Struct.new( :s3, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < MembershipProtectedJobOutputConfiguration; end class Unknown < MembershipProtectedJobOutputConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7150 7151 7152 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7150 def unknown @unknown end |