Class: Aws::CleanRooms::Types::MembershipProtectedQueryOutputConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

MembershipProtectedQueryOutputConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

MembershipProtectedQueryOutputConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MembershipProtectedQueryOutputConfiguration corresponding to the set member.

Contains configurations for protected query results.

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::ProtectedQueryS3OutputConfiguration

Contains the configuration to write the query results to S3.



8873
8874
8875
8876
8877
8878
8879
8880
8881
8882
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8873

class MembershipProtectedQueryOutputConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < MembershipProtectedQueryOutputConfiguration; end
  class Unknown < MembershipProtectedQueryOutputConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



8873
8874
8875
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8873

def unknown
  @unknown
end