Class: Aws::CleanRooms::Types::MembershipQueryComputePaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipQueryComputePaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the payment responsibilities accepted by the collaboration member for query compute costs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for query compute costs (
TRUE) or has not accepted to pay for query compute costs (FALSE).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for query compute costs (TRUE) or has not accepted to pay for query compute costs (FALSE).
If the collaboration creator has not specified anyone to pay for query compute costs, then the member who can query is the default payer.
An error message is returned for the following reasons:
-
If you set the value to
FALSEbut you are responsible to pay for query compute costs. -
If you set the value to
TRUEbut you are not responsible to pay for query compute costs.
7249 7250 7251 7252 7253 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7249 class MembershipQueryComputePaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |