Class: Aws::CleanRooms::Types::MembershipSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The membership object listed by the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The unique ARN for the membership.
-
#collaboration_arn ⇒ String
The unique ARN for the membership's associated collaboration.
-
#collaboration_creator_account_id ⇒ String
The identifier of the Amazon Web Services principal that created the collaboration.
-
#collaboration_creator_display_name ⇒ String
The display name of the collaboration creator.
-
#collaboration_id ⇒ String
The unique ID for the membership's collaboration.
-
#collaboration_name ⇒ String
The name for the membership's collaboration.
-
#create_time ⇒ Time
The time when the membership was created.
-
#id ⇒ String
The unique ID for the membership's collaboration.
-
#member_abilities ⇒ Array<String>
The abilities granted to the collaboration member.
-
#ml_member_abilities ⇒ Types::MLMemberAbilities
Provides a summary of the ML abilities for the collaboration member.
-
#payment_configuration ⇒ Types::MembershipPaymentConfiguration
The payment responsibilities accepted by the collaboration member.
-
#status ⇒ String
The status of the membership.
-
#update_time ⇒ Time
The time the membership metadata was last updated.
Instance Attribute Details
#arn ⇒ String
The unique ARN for the membership.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique ARN for the membership's associated collaboration.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#collaboration_creator_account_id ⇒ String
The identifier of the Amazon Web Services principal that created the collaboration. Currently only supports Amazon Web Services account ID.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#collaboration_creator_display_name ⇒ String
The display name of the collaboration creator.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique ID for the membership's collaboration.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#collaboration_name ⇒ String
The name for the membership's collaboration.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the membership was created.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for the membership's collaboration.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#member_abilities ⇒ Array<String>
The abilities granted to the collaboration member.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#ml_member_abilities ⇒ Types::MLMemberAbilities
Provides a summary of the ML abilities for the collaboration member.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#payment_configuration ⇒ Types::MembershipPaymentConfiguration
The payment responsibilities accepted by the collaboration member.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the membership.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the membership metadata was last updated.
8992 8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8992 class MembershipSummary < Struct.new( :id, :arn, :collaboration_arn, :collaboration_id, :collaboration_creator_account_id, :collaboration_creator_display_name, :collaboration_name, :create_time, :update_time, :status, :member_abilities, :ml_member_abilities, :payment_configuration) SENSITIVE = [] include Aws::Structure end |