Class: Aws::CleanRooms::Types::ModelInferencePaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ModelInferencePaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the collaboration member’s model inference payment responsibilities set by the collaboration creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration creator has configured the collaboration member to pay for model inference costs (
TRUE) or has not configured the collaboration member to pay for model inference costs (FALSE).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration creator has configured the collaboration member to pay for model inference costs (TRUE) or has not configured the collaboration member to pay for model inference costs (FALSE).
Exactly one member can be configured to pay for model inference costs. An error is returned if the collaboration creator sets a TRUE value for more than one member in the collaboration.
If the collaboration creator hasn’t specified anyone as the member paying for model inference costs, then the member who can query is the default payer. An error is returned if the collaboration creator sets a FALSE value for the member who can query.
7368 7369 7370 7371 7372 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7368 class ModelInferencePaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |