Class: Aws::CleanRooms::Types::ModelTrainingPaymentConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

An object representing the collaboration member's model training payment responsibilities set by the collaboration creator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_responsibleBoolean

Indicates whether the collaboration creator has configured the collaboration member to pay for model training costs (TRUE) or has not configured the collaboration member to pay for model training costs (FALSE).

One or more members can be configured as payer candidates for model training costs.

If the collaboration creator hasn't specified anyone as the member paying for model training costs, then the member who can query is the default payer.

Returns:

  • (Boolean)


9070
9071
9072
9073
9074
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9070

class ModelTrainingPaymentConfig < Struct.new(
  :is_responsible)
  SENSITIVE = []
  include Aws::Structure
end