Class: Aws::CleanRooms::Types::PopulateIdMappingTableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PopulateIdMappingTableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id_mapping_table_identifier ⇒ String
The unique identifier of the ID mapping table that you want to populate.
-
#job_type ⇒ String
The job type of the rule-based ID mapping job.
-
#membership_identifier ⇒ String
The unique identifier of the membership that contains the ID mapping table that you want to populate.
Instance Attribute Details
#id_mapping_table_identifier ⇒ String
The unique identifier of the ID mapping table that you want to populate.
7463 7464 7465 7466 7467 7468 7469 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7463 class PopulateIdMappingTableInput < Struct.new( :id_mapping_table_identifier, :membership_identifier, :job_type) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The job type of the rule-based ID mapping job. Valid values include:
INCREMENTAL: Processes only new or changed data since the last job run. This is the default job type if the ID mapping workflow was created in Entity Resolution with incrementalRunConfig specified.
BATCH: Processes all data from the input source, regardless of previous job runs. This is the default job type if the ID mapping workflow was created in Entity Resolution but incrementalRunConfig wasn’t specified.
DELETE_ONLY: Processes only deletion requests from BatchDeleteUniqueId, which is set in Entity Resolution.
For more information about incrementalRunConfig and BatchDeleteUniqueId, see the [Entity Resolution API Reference].
[1]: docs.aws.amazon.com/entityresolution/latest/apireference/Welcome.html
7463 7464 7465 7466 7467 7468 7469 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7463 class PopulateIdMappingTableInput < Struct.new( :id_mapping_table_identifier, :membership_identifier, :job_type) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The unique identifier of the membership that contains the ID mapping table that you want to populate.
7463 7464 7465 7466 7467 7468 7469 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7463 class PopulateIdMappingTableInput < Struct.new( :id_mapping_table_identifier, :membership_identifier, :job_type) SENSITIVE = [] include Aws::Structure end |