Class: Aws::CleanRooms::Types::PopulationAnalysisConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

PopulationAnalysisConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

PopulationAnalysisConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PopulationAnalysisConfiguration corresponding to the set member.

Contains the configuration that defines the analysis used to populate an intermediate table.

Defined Under Namespace

Classes: SqlParameters, Unknown

Constant Summary collapse

SENSITIVE =
[:sql_parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#sql_parametersTypes::PopulationAnalysisSqlParameters

The SQL parameters for the population analysis, including the query string or analysis template ARN.



9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9257

class PopulationAnalysisConfiguration < Struct.new(
  :sql_parameters,
  :unknown)
  SENSITIVE = [:sql_parameters]
  include Aws::Structure
  include Aws::Structure::Union

  class SqlParameters < PopulationAnalysisConfiguration; end
  class Unknown < PopulationAnalysisConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9257
9258
9259
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9257

def unknown
  @unknown
end