Class: Aws::CleanRooms::Types::PopulationAnalysisSqlParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains the SQL parameters used to populate an intermediate table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_template_arnString

The Amazon Resource Name (ARN) of the analysis template to use for populating the intermediate table.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9128

class PopulationAnalysisSqlParameters < Struct.new(
  :query_string,
  :analysis_template_arn)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The SQL query string used to populate the intermediate table.

Returns:

  • (String)


9128
9129
9130
9131
9132
9133
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9128

class PopulationAnalysisSqlParameters < Struct.new(
  :query_string,
  :analysis_template_arn)
  SENSITIVE = []
  include Aws::Structure
end