Class: Aws::CleanRooms::Types::PreviewPrivacyImpactParametersInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PreviewPrivacyImpactParametersInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Note:
PreviewPrivacyImpactParametersInput is a union - when making an API calls you must set exactly one of the members.
Specifies the updated epsilon and noise parameters to preview. The preview allows you to see how the maximum number of each type of aggregation function would change with the new parameters.
Defined Under Namespace
Classes: DifferentialPrivacy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#differential_privacy ⇒ Types::DifferentialPrivacyPreviewParametersInput
An array that specifies the epsilon and noise parameters.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#differential_privacy ⇒ Types::DifferentialPrivacyPreviewParametersInput
An array that specifies the epsilon and noise parameters.
9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9332 class PreviewPrivacyImpactParametersInput < Struct.new( :differential_privacy, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PreviewPrivacyImpactParametersInput; end class Unknown < PreviewPrivacyImpactParametersInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9332 9333 9334 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9332 def unknown @unknown end |