Class: Aws::CleanRooms::Types::PrivacyBudgetSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

An array that summaries the specified privacy budget. This summary includes collaboration information, creation information, membership information, and privacy budget information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#budgetTypes::PrivacyBudget

The provided privacy budget.



9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_arnString

The ARN of the collaboration that contains this privacy budget.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_idString

The unique identifier of the collaboration that contains this privacy budget.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the privacy budget was created.

Returns:

  • (Time)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the privacy budget.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#membership_arnString

The Amazon Resource Name (ARN) of the member who created the privacy budget summary.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The identifier for a membership resource.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_budget_template_arnString

The ARN of the privacy budget template.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_budget_template_idString

The unique identifier of the privacy budget template.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies the type of the privacy budget.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The most recent time at which the privacy budget was updated.

Returns:

  • (Time)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9272

class PrivacyBudgetSummary < Struct.new(
  :id,
  :privacy_budget_template_id,
  :privacy_budget_template_arn,
  :membership_id,
  :membership_arn,
  :collaboration_id,
  :collaboration_arn,
  :type,
  :create_time,
  :update_time,
  :budget)
  SENSITIVE = []
  include Aws::Structure
end