Class: Aws::CleanRooms::Types::PrivacyBudgetTemplateUpdateParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

PrivacyBudgetTemplateUpdateParameters is a union - when making an API calls you must set exactly one of the members.

The epsilon and noise parameters that you want to update in the privacy budget template.

Direct Known Subclasses

AccessBudget, DifferentialPrivacy, Unknown

Defined Under Namespace

Classes: AccessBudget, DifferentialPrivacy, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_budgetTypes::AccessBudgetsPrivacyTemplateUpdateParameters

The new access budget configuration that completely replaces the existing access budget settings in the privacy budget template.



7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7849

class PrivacyBudgetTemplateUpdateParameters < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudgetTemplateUpdateParameters; end
  class AccessBudget < PrivacyBudgetTemplateUpdateParameters; end
  class Unknown < PrivacyBudgetTemplateUpdateParameters; end
end

#differential_privacyTypes::DifferentialPrivacyTemplateUpdateParameters

An object that specifies the new values for the epsilon and noise parameters.



7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7849

class PrivacyBudgetTemplateUpdateParameters < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudgetTemplateUpdateParameters; end
  class AccessBudget < PrivacyBudgetTemplateUpdateParameters; end
  class Unknown < PrivacyBudgetTemplateUpdateParameters; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7849
7850
7851
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7849

def unknown
  @unknown
end