Class: Aws::CleanRooms::Types::ProtectedJobSingleMemberOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ProtectedJobSingleMemberOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Details about the member who received the job result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the member in the collaboration who can receive results from analyses.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the member in the collaboration who can receive results from analyses.
9931 9932 9933 9934 9935 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9931 class ProtectedJobSingleMemberOutput < Struct.new( :account_id) SENSITIVE = [] include Aws::Structure end |