Class: Aws::CleanRooms::Types::ProtectedJobWorkerComputeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The configuration of the compute resources for a PySpark job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#numberInteger

The number of workers for a PySpark job.

Returns:

  • (Integer)


8361
8362
8363
8364
8365
8366
8367
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8361

class ProtectedJobWorkerComputeConfiguration < Struct.new(
  :type,
  :number,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesTypes::WorkerComputeConfigurationProperties

The configuration properties for the worker compute environment. These properties allow you to customize the compute settings for your Clean Rooms workloads.



8361
8362
8363
8364
8365
8366
8367
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8361

class ProtectedJobWorkerComputeConfiguration < Struct.new(
  :type,
  :number,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The worker compute configuration type.

Returns:

  • (String)


8361
8362
8363
8364
8365
8366
8367
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8361

class ProtectedJobWorkerComputeConfiguration < Struct.new(
  :type,
  :number,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end