Class: Aws::CleanRooms::Types::ProtectedQueryOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

ProtectedQueryOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProtectedQueryOutput corresponding to the set member.

Contains details about the protected query output.

Defined Under Namespace

Classes: Distribute, MemberList, S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#distributeTypes::ProtectedQueryDistributeOutput

Contains output information for protected queries that use a distribute output type. This output type lets you send query results to multiple locations - either to S3 or to collaboration members.

You can only use the distribute output type with the Spark analytics engine.

Returns:



10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10400

class ProtectedQueryOutput < Struct.new(
  :s3,
  :member_list,
  :distribute,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ProtectedQueryOutput; end
  class MemberList < ProtectedQueryOutput; end
  class Distribute < ProtectedQueryOutput; end
  class Unknown < ProtectedQueryOutput; end
end

#member_listArray<Types::ProtectedQuerySingleMemberOutput>

The list of member Amazon Web Services account(s) that received the results of the query.

Returns:



10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10400

class ProtectedQueryOutput < Struct.new(
  :s3,
  :member_list,
  :distribute,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ProtectedQueryOutput; end
  class MemberList < ProtectedQueryOutput; end
  class Distribute < ProtectedQueryOutput; end
  class Unknown < ProtectedQueryOutput; end
end

#s3Types::ProtectedQueryS3Output

If present, the output for a protected query with an S3 output type.

Returns:



10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10400

class ProtectedQueryOutput < Struct.new(
  :s3,
  :member_list,
  :distribute,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ProtectedQueryOutput; end
  class MemberList < ProtectedQueryOutput; end
  class Distribute < ProtectedQueryOutput; end
  class Unknown < ProtectedQueryOutput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • the current value of unknown



10400
10401
10402
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10400

def unknown
  @unknown
end