Class: Aws::CleanRooms::Types::ProtectedQueryOutputConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ProtectedQueryOutputConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
ProtectedQueryOutputConfiguration is a union - when making an API calls you must set exactly one of the members.
ProtectedQueryOutputConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProtectedQueryOutputConfiguration corresponding to the set member.
Contains configuration details for protected query output.
Direct Known Subclasses
Defined Under Namespace
Classes: Distribute, Member, S3, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribute ⇒ Types::ProtectedQueryDistributeOutputConfiguration
Required configuration for a protected query with a
distributeoutput type. -
#member ⇒ Types::ProtectedQueryMemberOutputConfiguration
Required configuration for a protected query with a
memberoutput type. -
#s3 ⇒ Types::ProtectedQueryS3OutputConfiguration
Required configuration for a protected query with an
s3output type. -
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#distribute ⇒ Types::ProtectedQueryDistributeOutputConfiguration
Required configuration for a protected query with a distribute output type.
8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8612 class ProtectedQueryOutputConfiguration < Struct.new( :s3, :member, :distribute, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < ProtectedQueryOutputConfiguration; end class Member < ProtectedQueryOutputConfiguration; end class Distribute < ProtectedQueryOutputConfiguration; end class Unknown < ProtectedQueryOutputConfiguration; end end |
#member ⇒ Types::ProtectedQueryMemberOutputConfiguration
Required configuration for a protected query with a member output type.
8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8612 class ProtectedQueryOutputConfiguration < Struct.new( :s3, :member, :distribute, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < ProtectedQueryOutputConfiguration; end class Member < ProtectedQueryOutputConfiguration; end class Distribute < ProtectedQueryOutputConfiguration; end class Unknown < ProtectedQueryOutputConfiguration; end end |
#s3 ⇒ Types::ProtectedQueryS3OutputConfiguration
Required configuration for a protected query with an s3 output type.
8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8612 class ProtectedQueryOutputConfiguration < Struct.new( :s3, :member, :distribute, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < ProtectedQueryOutputConfiguration; end class Member < ProtectedQueryOutputConfiguration; end class Distribute < ProtectedQueryOutputConfiguration; end class Unknown < ProtectedQueryOutputConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8612 8613 8614 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8612 def unknown @unknown end |