Class: Aws::CleanRooms::Types::QueryConstraint
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::QueryConstraint
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Note:
QueryConstraint is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of QueryConstraint corresponding to the set member.
Provides any necessary query constraint information.
Direct Known Subclasses
Defined Under Namespace
Classes: RequireOverlap, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#require_overlap ⇒ Types::QueryConstraintRequireOverlap
An array of column names that specifies which columns are required in the JOIN statement.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#require_overlap ⇒ Types::QueryConstraintRequireOverlap
An array of column names that specifies which columns are required in the JOIN statement.
8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8881 class QueryConstraint < Struct.new( :require_overlap, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RequireOverlap < QueryConstraint; end class Unknown < QueryConstraint; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8881 8882 8883 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8881 def unknown @unknown end |