Class: Aws::CleanRooms::Types::Schema
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::Schema
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A schema is a relation within a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_method ⇒ String
The analysis method for the schema.
-
#analysis_rule_types ⇒ Array<String>
The analysis rule types that are associated with the schema.
-
#collaboration_arn ⇒ String
The unique Amazon Resource Name (ARN) for the collaboration that the schema belongs to.
-
#collaboration_id ⇒ String
The unique ID for the collaboration that the schema belongs to.
-
#columns ⇒ Array<Types::Column>
The columns for the relation that this schema represents.
-
#create_time ⇒ Time
The time at which the schema was created.
-
#creator_account_id ⇒ String
The unique account ID for the Amazon Web Services account that owns the schema.
-
#description ⇒ String
A description for the schema.
-
#name ⇒ String
A name for the schema.
-
#partition_keys ⇒ Array<Types::Column>
The partition keys for the dataset underlying this schema.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the schema resource.
-
#schema_status_details ⇒ Array<Types::SchemaStatusDetail>
Details about the status of the schema.
-
#schema_type_properties ⇒ Types::SchemaTypeProperties
The schema type properties.
-
#selected_analysis_methods ⇒ Array<String>
The selected analysis methods for the schema.
-
#type ⇒ String
The type of schema.
-
#update_time ⇒ Time
The most recent time at which the schema was updated.
Instance Attribute Details
#analysis_method ⇒ String
The analysis method for the schema.
DIRECT_QUERY allows SQL queries to be run directly on this table.
DIRECT_JOB allows PySpark jobs to be run directly on this table.
MULTIPLE allows both SQL queries and PySpark jobs to be run
directly on this table.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#analysis_rule_types ⇒ Array<String>
The analysis rule types that are associated with the schema. Currently, only one entry is present.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique Amazon Resource Name (ARN) for the collaboration that the schema belongs to.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique ID for the collaboration that the schema belongs to.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#columns ⇒ Array<Types::Column>
The columns for the relation that this schema represents.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the schema was created.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The unique account ID for the Amazon Web Services account that owns the schema.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the schema.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the schema. The schema relation is referred to by this name when queried by a protected query.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Types::Column>
The partition keys for the dataset underlying this schema.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the schema resource.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#schema_status_details ⇒ Array<Types::SchemaStatusDetail>
Details about the status of the schema. Currently, only one entry is present.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#schema_type_properties ⇒ Types::SchemaTypeProperties
The schema type properties.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#selected_analysis_methods ⇒ Array<String>
The selected analysis methods for the schema.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of schema.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the schema was updated.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10851 class Schema < Struct.new( :columns, :partition_keys, :analysis_rule_types, :analysis_method, :selected_analysis_methods, :creator_account_id, :name, :collaboration_id, :collaboration_arn, :description, :create_time, :update_time, :type, :schema_status_details, :resource_arn, :schema_type_properties) SENSITIVE = [] include Aws::Structure end |