Class: Aws::CleanRooms::Types::SchemaStatusDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Information about the schema status.

A status of ‘READY` means that based on the schema analysis rule, queries of the given analysis rule type are properly configured to run queries on this schema.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_rule_typeString

The analysis rule type for which the schema status has been evaluated.

Returns:

  • (String)


9095
9096
9097
9098
9099
9100
9101
9102
9103
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9095

class SchemaStatusDetail < Struct.new(
  :status,
  :reasons,
  :analysis_rule_type,
  :configurations,
  :analysis_type)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_typeString

The type of analysis that can be performed on the schema.

A schema can have an ‘analysisType` of `DIRECT_ANALYSIS`, `ADDITIONAL_ANALYSIS_FOR_AUDIENCE_GENERATION`, or both.

Returns:

  • (String)


9095
9096
9097
9098
9099
9100
9101
9102
9103
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9095

class SchemaStatusDetail < Struct.new(
  :status,
  :reasons,
  :analysis_rule_type,
  :configurations,
  :analysis_type)
  SENSITIVE = []
  include Aws::Structure
end

#configurationsArray<String>

The configuration details of the schema analysis rule for the given type.

Returns:

  • (Array<String>)


9095
9096
9097
9098
9099
9100
9101
9102
9103
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9095

class SchemaStatusDetail < Struct.new(
  :status,
  :reasons,
  :analysis_rule_type,
  :configurations,
  :analysis_type)
  SENSITIVE = []
  include Aws::Structure
end

#reasonsArray<Types::SchemaStatusReason>

The reasons why the schema status is set to its current state.

Returns:



9095
9096
9097
9098
9099
9100
9101
9102
9103
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9095

class SchemaStatusDetail < Struct.new(
  :status,
  :reasons,
  :analysis_rule_type,
  :configurations,
  :analysis_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the schema, indicating if it is ready to query.

Returns:

  • (String)


9095
9096
9097
9098
9099
9100
9101
9102
9103
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9095

class SchemaStatusDetail < Struct.new(
  :status,
  :reasons,
  :analysis_rule_type,
  :configurations,
  :analysis_type)
  SENSITIVE = []
  include Aws::Structure
end