Class: Aws::CleanRooms::Types::SnowflakeTableSchema
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::SnowflakeTableSchema
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Note:
SnowflakeTableSchema is a union - when making an API calls you must set exactly one of the members.
Note:
SnowflakeTableSchema is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SnowflakeTableSchema corresponding to the set member.
The schema of a Snowflake table.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#v1 ⇒ Array<Types::SnowflakeTableSchemaV1>
The schema of a Snowflake table.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
11136 11137 11138 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11136 def unknown @unknown end |
#v1 ⇒ Array<Types::SnowflakeTableSchemaV1>
The schema of a Snowflake table.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11136 class SnowflakeTableSchema < Struct.new( :v1, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class V1 < SnowflakeTableSchema; end class Unknown < SnowflakeTableSchema; end end |