Class: Aws::CleanRooms::Types::SyntheticDataColumnProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::SyntheticDataColumnProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Properties that define how a specific data column should be handled during synthetic data generation, including its name, type, and role in predictive modeling.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_name ⇒ String
The name of the data column as it appears in the dataset.
-
#column_type ⇒ String
The data type of the column, which determines how the synthetic data generation algorithm processes and synthesizes values for this column.
-
#is_predictive_value ⇒ Boolean
Indicates if this column contains predictive values that should be treated as target variables in machine learning models.
Instance Attribute Details
#column_name ⇒ String
The name of the data column as it appears in the dataset.
9440 9441 9442 9443 9444 9445 9446 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9440 class SyntheticDataColumnProperties < Struct.new( :column_name, :column_type, :is_predictive_value) SENSITIVE = [] include Aws::Structure end |
#column_type ⇒ String
The data type of the column, which determines how the synthetic data generation algorithm processes and synthesizes values for this column.
9440 9441 9442 9443 9444 9445 9446 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9440 class SyntheticDataColumnProperties < Struct.new( :column_name, :column_type, :is_predictive_value) SENSITIVE = [] include Aws::Structure end |
#is_predictive_value ⇒ Boolean
Indicates if this column contains predictive values that should be treated as target variables in machine learning models. This affects how the synthetic data generation preserves statistical relationships.
9440 9441 9442 9443 9444 9445 9446 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9440 class SyntheticDataColumnProperties < Struct.new( :column_name, :column_type, :is_predictive_value) SENSITIVE = [] include Aws::Structure end |