Class: Aws::CleanRooms::Types::TableReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::TableReference
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
TableReference is a union - when making an API calls you must set exactly one of the members.
TableReference is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TableReference corresponding to the set member.
A pointer to the dataset that underlies this table.
Defined Under Namespace
Classes: Athena, Glue, Snowflake, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#athena ⇒ Types::AthenaTableReference
If present, a reference to the Athena table referred to by this table reference.
-
#glue ⇒ Types::GlueTableReference
If present, a reference to the Glue table referred to by this table reference.
-
#snowflake ⇒ Types::SnowflakeTableReference
If present, a reference to the Snowflake table referred to by this table reference.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#athena ⇒ Types::AthenaTableReference
If present, a reference to the Athena table referred to by this table reference.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9553 class TableReference < Struct.new( :glue, :snowflake, :athena, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Glue < TableReference; end class Snowflake < TableReference; end class Athena < TableReference; end class Unknown < TableReference; end end |
#glue ⇒ Types::GlueTableReference
If present, a reference to the Glue table referred to by this table reference.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9553 class TableReference < Struct.new( :glue, :snowflake, :athena, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Glue < TableReference; end class Snowflake < TableReference; end class Athena < TableReference; end class Unknown < TableReference; end end |
#snowflake ⇒ Types::SnowflakeTableReference
If present, a reference to the Snowflake table referred to by this table reference.
9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9553 class TableReference < Struct.new( :glue, :snowflake, :athena, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Glue < TableReference; end class Snowflake < TableReference; end class Athena < TableReference; end class Unknown < TableReference; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9553 9554 9555 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9553 def unknown @unknown end |