Class: Aws::CleanRooms::Types::UpdateConfiguredTableAssociationAnalysisRuleOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_ruleTypes::ConfiguredTableAssociationAnalysisRule

The updated analysis rule for the configured table association. In the console, the ConfiguredTableAssociationAnalysisRule is referred to as the collaboration analysis rule.



11240
11241
11242
11243
11244
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11240

class UpdateConfiguredTableAssociationAnalysisRuleOutput < Struct.new(
  :analysis_rule)
  SENSITIVE = []
  include Aws::Structure
end