Class: Aws::CleanRooms::Types::UpdateConfiguredTableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::UpdateConfiguredTableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_columns ⇒ Array<String>
The columns of the underlying table that can be used by collaborations or analysis rules.
-
#analysis_method ⇒ String
The analysis method for the configured table.
-
#configured_table_identifier ⇒ String
The identifier for the configured table to update.
-
#description ⇒ String
A new description for the configured table.
-
#name ⇒ String
A new name for the configured table.
-
#selected_analysis_methods ⇒ Array<String>
The selected analysis methods for the table configuration update.
-
#table_reference ⇒ Types::TableReference
A pointer to the dataset that underlies this table.
Instance Attribute Details
#allowed_columns ⇒ Array<String>
The columns of the underlying table that can be used by collaborations or analysis rules.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#analysis_method ⇒ String
The analysis method for the configured table.
DIRECT_QUERY allows SQL queries to be run directly on this table.
DIRECT_JOB allows PySpark jobs to be run directly on this table.
MULTIPLE allows both SQL queries and PySpark jobs to be run
directly on this table.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#configured_table_identifier ⇒ String
The identifier for the configured table to update. Currently accepts the configured table ID.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A new description for the configured table.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A new name for the configured table.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#selected_analysis_methods ⇒ Array<String>
The selected analysis methods for the table configuration update.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |
#table_reference ⇒ Types::TableReference
A pointer to the dataset that underlies this table.
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 11669 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11659 class UpdateConfiguredTableInput < Struct.new( :configured_table_identifier, :name, :description, :table_reference, :allowed_columns, :analysis_method, :selected_analysis_methods) SENSITIVE = [] include Aws::Structure end |