Class: Aws::CleanRooms::Types::UpdateIntermediateTableAnalysisRuleInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_rule_policyTypes::IntermediateTableAnalysisRulePolicy

The updated analysis rule policy for the intermediate table.



11791
11792
11793
11794
11795
11796
11797
11798
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11791

class UpdateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_rule_typeString

The type of analysis rule to update. Currently, only CUSTOM is supported.

Returns:

  • (String)


11791
11792
11793
11794
11795
11796
11797
11798
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11791

class UpdateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end

#intermediate_table_identifierString

The unique identifier of the intermediate table for which to update the analysis rule.

Returns:

  • (String)


11791
11792
11793
11794
11795
11796
11797
11798
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11791

class UpdateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership that contains the intermediate table.

Returns:

  • (String)


11791
11792
11793
11794
11795
11796
11797
11798
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11791

class UpdateIntermediateTableAnalysisRuleInput < Struct.new(
  :membership_identifier,
  :intermediate_table_identifier,
  :analysis_rule_type,
  :analysis_rule_policy)
  SENSITIVE = []
  include Aws::Structure
end