Class: Aws::CleanRooms::Types::UpdateIntermediateTableInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#columnsArray<Types::IntermediateTableColumn>

The list of columns with updated type definitions. Only the type of existing columns can be updated.

Returns:



11990
11991
11992
11993
11994
11995
11996
11997
11998
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11990

class UpdateIntermediateTableInput < Struct.new(
  :intermediate_table_identifier,
  :membership_identifier,
  :description,
  :kms_key_arn,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A new description for the intermediate table.

Returns:

  • (String)


11990
11991
11992
11993
11994
11995
11996
11997
11998
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11990

class UpdateIntermediateTableInput < Struct.new(
  :intermediate_table_identifier,
  :membership_identifier,
  :description,
  :kms_key_arn,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#intermediate_table_identifierString

The unique identifier of the intermediate table to update.

Returns:

  • (String)


11990
11991
11992
11993
11994
11995
11996
11997
11998
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11990

class UpdateIntermediateTableInput < Struct.new(
  :intermediate_table_identifier,
  :membership_identifier,
  :description,
  :kms_key_arn,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the customer-managed KMS key to use for encrypting future population data.

Returns:

  • (String)


11990
11991
11992
11993
11994
11995
11996
11997
11998
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11990

class UpdateIntermediateTableInput < Struct.new(
  :intermediate_table_identifier,
  :membership_identifier,
  :description,
  :kms_key_arn,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The unique identifier of the membership that contains the intermediate table.

Returns:

  • (String)


11990
11991
11992
11993
11994
11995
11996
11997
11998
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11990

class UpdateIntermediateTableInput < Struct.new(
  :intermediate_table_identifier,
  :membership_identifier,
  :description,
  :kms_key_arn,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end