Class: Aws::CleanRooms::Types::WorkerComputeConfigurationProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::WorkerComputeConfigurationProperties
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
WorkerComputeConfigurationProperties is a union - when making an API calls you must set exactly one of the members.
WorkerComputeConfigurationProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WorkerComputeConfigurationProperties corresponding to the set member.
The configuration properties that define the compute environment settings for workers in Clean Rooms. These properties enable customization of the underlying compute environment to optimize performance for your specific workloads.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#spark ⇒ Hash<String,String>
The Spark configuration properties for SQL and PySpark workloads.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#spark ⇒ Hash<String,String>
The Spark configuration properties for SQL and PySpark workloads. This map contains key-value pairs that configure Apache Spark settings to optimize performance for your data processing jobs. You can specify up to 50 Spark properties, with each key being 1-200 characters and each value being 0-500 characters. These properties allow you to adjust compute capacity for large datasets and complex workloads.
11823 11824 11825 11826 11827 11828 11829 11830 11831 11832 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11823 class WorkerComputeConfigurationProperties < Struct.new( :spark, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Spark < WorkerComputeConfigurationProperties; end class Unknown < WorkerComputeConfigurationProperties; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
11823 11824 11825 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11823 def unknown @unknown end |