Class: Aws::CleanRooms::Types::AnalysisLogExport

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

An export of the redacted Apache Spark logs for a protected query.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The unique identifier of the protected query that the analysis logs were exported for.

Returns:

  • (String)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_log_export_idString

The unique identifier of the analysis log export.

Returns:

  • (String)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_typeString

The type of analysis that the logs were exported for. Currently, only PROTECTED_QUERY is supported.

Returns:

  • (String)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time the analysis log export was created.

Returns:

  • (Time)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::AnalysisLogExportError

The analysis log export error. This is present only when the export status is FAILED.



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The unique identifier of the membership that the analysis log export belongs to.

Returns:

  • (String)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#result_configurationTypes::AnalysisLogExportResultConfiguration

Contains the details needed to write the exported analysis logs.



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the analysis log export. Possible values are:

  • IN_PROGRESS – The export is currently running.

  • SUCCESS – The export completed successfully.

  • FAILED – The export failed. See the error field for details.

Returns:

  • (String)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The time the analysis log export was last updated.

Returns:

  • (Time)


289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289

class AnalysisLogExport < Struct.new(
  :analysis_log_export_id,
  :analysis_id,
  :analysis_type,
  :membership_id,
  :status,
  :result_configuration,
  :create_time,
  :update_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end