Class: Aws::CleanRooms::Types::AnalysisLogExport
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisLogExport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An export of the redacted Apache Spark logs for a protected query.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The unique identifier of the protected query that the analysis logs were exported for.
-
#analysis_log_export_id ⇒ String
The unique identifier of the analysis log export.
-
#analysis_type ⇒ String
The type of analysis that the logs were exported for.
-
#create_time ⇒ Time
The time the analysis log export was created.
-
#error ⇒ Types::AnalysisLogExportError
The analysis log export error.
-
#membership_id ⇒ String
The unique identifier of the membership that the analysis log export belongs to.
-
#result_configuration ⇒ Types::AnalysisLogExportResultConfiguration
Contains the details needed to write the exported analysis logs.
-
#status ⇒ String
The status of the analysis log export.
-
#update_time ⇒ Time
The time the analysis log export was last updated.
Instance Attribute Details
#analysis_id ⇒ String
The unique identifier of the protected query that the analysis logs were exported for.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#analysis_log_export_id ⇒ String
The unique identifier of the analysis log export.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#analysis_type ⇒ String
The type of analysis that the logs were exported for. Currently,
only PROTECTED_QUERY is supported.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the analysis log export was created.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#error ⇒ Types::AnalysisLogExportError
The analysis log export error. This is present only when the export
status is FAILED.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership that the analysis log export belongs to.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#result_configuration ⇒ Types::AnalysisLogExportResultConfiguration
Contains the details needed to write the exported analysis logs.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the analysis log export. Possible values are:
-
IN_PROGRESS– The export is currently running. -
SUCCESS– The export completed successfully. -
FAILED– The export failed. See theerrorfield for details.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the analysis log export was last updated.
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 289 class AnalysisLogExport < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :membership_id, :status, :result_configuration, :create_time, :update_time, :error) SENSITIVE = [] include Aws::Structure end |