Class: Aws::CleanRooms::Types::AnalysisLogExportSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisLogExportSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A summary of an analysis log export, including its identifier, status,
analysis type, and creation time. Returned by
ListAnalysisLogExports.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The unique identifier of the protected query that the analysis logs were exported for.
-
#analysis_log_export_id ⇒ String
The unique identifier of the analysis log export.
-
#analysis_type ⇒ String
The type of analysis that the logs were exported for.
-
#create_time ⇒ Time
The time the analysis log export was created.
-
#status ⇒ String
The status of the analysis log export.
Instance Attribute Details
#analysis_id ⇒ String
The unique identifier of the protected query that the analysis logs were exported for.
426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426 class AnalysisLogExportSummary < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :status, :create_time) SENSITIVE = [] include Aws::Structure end |
#analysis_log_export_id ⇒ String
The unique identifier of the analysis log export.
426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426 class AnalysisLogExportSummary < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :status, :create_time) SENSITIVE = [] include Aws::Structure end |
#analysis_type ⇒ String
The type of analysis that the logs were exported for. Currently,
only PROTECTED_QUERY is supported.
426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426 class AnalysisLogExportSummary < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :status, :create_time) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the analysis log export was created.
426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426 class AnalysisLogExportSummary < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :status, :create_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the analysis log export. Possible values are:
-
IN_PROGRESS– The export is currently running. -
SUCCESS– The export completed successfully. -
FAILED– The export failed.
426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 426 class AnalysisLogExportSummary < Struct.new( :analysis_log_export_id, :analysis_id, :analysis_type, :status, :create_time) SENSITIVE = [] include Aws::Structure end |