Class: Aws::CleanRooms::Types::AnalysisRuleCustom
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AnalysisRuleCustom
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A type of analysis rule that enables the table owner to approve custom SQL queries on their configured tables. It supports differential privacy, minimum aggregation thresholds, and comparison controls.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_analyses ⇒ String
An indicator as to whether additional analyses (such as Clean Rooms ML) can be applied to the output of the direct query.
-
#aggregation_thresholds ⇒ Array<Types::AggregationThreshold>
The aggregation thresholds that each query output group must satisfy.
-
#allowed_additional_analyses ⇒ Array<String>
The list of allowed additional analyses for the custom analysis rule.
-
#allowed_analyses ⇒ Array<String>
The ARN of the analysis templates that are allowed by the custom analysis rule.
-
#allowed_analysis_providers ⇒ Array<String>
The IDs of the Amazon Web Services accounts that are allowed to query by the custom analysis rule.
-
#allowed_result_receivers ⇒ Array<String>
The list of Amazon Web Services account IDs that are allowed to receive results from queries run on the configured table.
-
#comparison_controls ⇒ Types::ComparisonControls
The controls that restrict how a query can compare the columns in the configured table.
-
#differential_privacy ⇒ Types::DifferentialPrivacyConfiguration
The differential privacy configuration.
-
#disallowed_output_columns ⇒ Array<String>
A list of columns that aren't allowed to be shown in the query output.
Instance Attribute Details
#additional_analyses ⇒ String
An indicator as to whether additional analyses (such as Clean Rooms ML) can be applied to the output of the direct query.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#aggregation_thresholds ⇒ Array<Types::AggregationThreshold>
The aggregation thresholds that each query output group must
satisfy. Clean Rooms filters out any group that represents fewer
than the specified number of distinct identities. You can specify at
most one threshold. You can't use aggregation thresholds with
differential privacy, or when allowedAnalyses allows only jobs.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#allowed_additional_analyses ⇒ Array<String>
The list of allowed additional analyses for the custom analysis rule.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#allowed_analyses ⇒ Array<String>
The ARN of the analysis templates that are allowed by the custom analysis rule.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#allowed_analysis_providers ⇒ Array<String>
The IDs of the Amazon Web Services accounts that are allowed to
query by the custom analysis rule. Required when allowedAnalyses
is ANY_QUERY.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#allowed_result_receivers ⇒ Array<String>
The list of Amazon Web Services account IDs that are allowed to receive results from queries run on the configured table.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#comparison_controls ⇒ Types::ComparisonControls
The controls that restrict how a query can compare the columns in
the configured table. You can't use comparison controls with
differential privacy, or when allowedAnalyses allows only jobs.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#differential_privacy ⇒ Types::DifferentialPrivacyConfiguration
The differential privacy configuration.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#disallowed_output_columns ⇒ Array<String>
A list of columns that aren't allowed to be shown in the query output.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 690 class AnalysisRuleCustom < Struct.new( :allowed_analyses, :allowed_analysis_providers, :additional_analyses, :disallowed_output_columns, :differential_privacy, :aggregation_thresholds, :comparison_controls, :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |