Class: Aws::CleanRooms::Types::AnalysisTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The analysis template.

Constant Summary collapse

SENSITIVE =
[:analysis_parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_parametersArray<Types::AnalysisParameter>

The parameters of the analysis template.

Returns:



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#collaboration_arnString

The unique ARN for the analysis template’s associated collaboration.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#collaboration_idString

The unique ID for the associated collaboration of the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#create_timeTime

The time that the analysis template was created.

Returns:

  • (Time)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#descriptionString

The description of the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#error_message_configurationTypes::ErrorMessageConfiguration

The configuration that specifies the level of detail in error messages returned by analyses using this template. When set to DETAILED, error messages include more information to help troubleshoot issues with PySpark jobs. Detailed error messages may expose underlying data, including sensitive information. Recommended for faster troubleshooting in development and testing environments.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#formatString

The format of the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#idString

The identifier for the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#membership_arnString

The Amazon Resource Name (ARN) of the member who created the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#membership_idString

The identifier of a member who created the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#nameString

The name of the analysis template.

Returns:

  • (String)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#schemaTypes::AnalysisSchema

The entire schema object.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#sourceTypes::AnalysisSource

The source of the analysis template.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#source_metadataTypes::AnalysisSourceMetadata

The source metadata for the analysis template.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#synthetic_data_parametersTypes::SyntheticDataParameters

The parameters used to generate synthetic data for this analysis template.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#update_timeTime

The time that the analysis template was last updated.

Returns:

  • (Time)


904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#validationsArray<Types::AnalysisTemplateValidationStatusDetail>

Information about the validations performed on the analysis template.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-cleanrooms/types.rb', line 904

class AnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :membership_id,
  :membership_arn,
  :description,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end