Class: Aws::CleanRooms::Types::AthenaTableReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::AthenaTableReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A reference to a table within Athena.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_name ⇒ String
The catalog name.
-
#database_name ⇒ String
The database name.
-
#output_location ⇒ String
The output location for the Athena table.
-
#region ⇒ String
The Amazon Web Services Region where the Athena table is located.
-
#table_name ⇒ String
The table reference.
-
#work_group ⇒ String
The workgroup of the Athena table reference.
Instance Attribute Details
#catalog_name ⇒ String
The catalog name.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1151 class AthenaTableReference < Struct.new( :region, :work_group, :output_location, :database_name, :table_name, :catalog_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database name.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1151 class AthenaTableReference < Struct.new( :region, :work_group, :output_location, :database_name, :table_name, :catalog_name) SENSITIVE = [] include Aws::Structure end |
#output_location ⇒ String
The output location for the Athena table.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1151 class AthenaTableReference < Struct.new( :region, :work_group, :output_location, :database_name, :table_name, :catalog_name) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the Athena table is located. This parameter is required to uniquely identify and access tables across different Regions.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1151 class AthenaTableReference < Struct.new( :region, :work_group, :output_location, :database_name, :table_name, :catalog_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The table reference.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1151 class AthenaTableReference < Struct.new( :region, :work_group, :output_location, :database_name, :table_name, :catalog_name) SENSITIVE = [] include Aws::Structure end |
#work_group ⇒ String
The workgroup of the Athena table reference.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1151 class AthenaTableReference < Struct.new( :region, :work_group, :output_location, :database_name, :table_name, :catalog_name) SENSITIVE = [] include Aws::Structure end |