Class: Aws::CleanRooms::Types::BudgetParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::BudgetParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Individual budget parameter configuration that defines specific budget allocation settings for access budgets.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_refresh ⇒ String
Whether this individual budget parameter automatically refreshes when the budget period resets.
-
#budget ⇒ Integer
The budget allocation amount for this specific parameter.
-
#type ⇒ String
The type of budget parameter being configured.
Instance Attribute Details
#auto_refresh ⇒ String
Whether this individual budget parameter automatically refreshes when the budget period resets.
1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1204 class BudgetParameter < Struct.new( :type, :budget, :auto_refresh) SENSITIVE = [] include Aws::Structure end |
#budget ⇒ Integer
The budget allocation amount for this specific parameter.
1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1204 class BudgetParameter < Struct.new( :type, :budget, :auto_refresh) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of budget parameter being configured.
1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1204 class BudgetParameter < Struct.new( :type, :budget, :auto_refresh) SENSITIVE = [] include Aws::Structure end |