Class: Aws::CleanRooms::Types::Collaboration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The multi-party data share environment. The collaboration contains metadata about its purpose and participants.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_result_regionsArray<String>

The Amazon Web Services Regions where collaboration query results can be stored. Returns the list of Region identifiers that were specified when the collaboration was created. This list is used to enforce regional storage policies and compliance requirements.

Returns:

  • (Array<String>)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#analytics_engineString

The analytics engine for the collaboration.

After July 16, 2025, the CLEAN_ROOMS_SQL parameter will no longer be available.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The unique ARN for the collaboration.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#auto_approved_change_typesArray<String>

The types of change requests that are automatically approved for this collaboration.

Returns:

  • (Array<String>)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time when the collaboration was created.

Returns:

  • (Time)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#creator_account_idString

The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#creator_display_nameString

A display name of the collaboration creator.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#data_encryption_metadataTypes::DataEncryptionMetadata

The settings for client-side encryption for cryptographic computing.



1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the collaboration provided by the collaboration owner.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique ID for the collaboration.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#is_metrics_enabledBoolean

An indicator as to whether metrics are enabled for the collaboration.

When true, collaboration members can opt in to Amazon CloudWatch metrics for their membership queries.

Returns:

  • (Boolean)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#job_log_statusString

An indicator as to whether job logging has been enabled or disabled for the collaboration.

When ENABLED, Clean Rooms logs details about jobs run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is DISABLED.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#member_statusString

The status of a member in a collaboration.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#membership_arnString

The unique ARN for your membership within the collaboration.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The unique ID for your membership within the collaboration.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A human-readable identifier provided by the collaboration owner. Display names are not unique.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#query_log_statusString

An indicator as to whether query logging has been enabled or disabled for the collaboration.

When ENABLED, Clean Rooms logs details about queries run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is DISABLED.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The time the collaboration metadata was last updated.

Returns:

  • (Time)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1429

class Collaboration < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :creator_account_id,
  :creator_display_name,
  :create_time,
  :update_time,
  :member_status,
  :membership_id,
  :membership_arn,
  :data_encryption_metadata,
  :query_log_status,
  :job_log_status,
  :analytics_engine,
  :auto_approved_change_types,
  :allowed_result_regions,
  :is_metrics_enabled)
  SENSITIVE = []
  include Aws::Structure
end