Class: Aws::CleanRooms::Types::Collaboration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::Collaboration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The multi-party data share environment. The collaboration contains metadata about its purpose and participants.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_result_regions ⇒ Array<String>
The Amazon Web Services Regions where collaboration query results can be stored.
-
#analytics_engine ⇒ String
The analytics engine for the collaboration.
-
#arn ⇒ String
The unique ARN for the collaboration.
-
#auto_approved_change_types ⇒ Array<String>
The types of change requests that are automatically approved for this collaboration.
-
#create_time ⇒ Time
The time when the collaboration was created.
-
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration.
-
#creator_display_name ⇒ String
A display name of the collaboration creator.
-
#data_encryption_metadata ⇒ Types::DataEncryptionMetadata
The settings for client-side encryption for cryptographic computing.
-
#description ⇒ String
A description of the collaboration provided by the collaboration owner.
-
#id ⇒ String
The unique ID for the collaboration.
-
#is_metrics_enabled ⇒ Boolean
An indicator as to whether metrics are enabled for the collaboration.
-
#job_log_status ⇒ String
An indicator as to whether job logging has been enabled or disabled for the collaboration.
-
#member_status ⇒ String
The status of a member in a collaboration.
-
#membership_arn ⇒ String
The unique ARN for your membership within the collaboration.
-
#membership_id ⇒ String
The unique ID for your membership within the collaboration.
-
#name ⇒ String
A human-readable identifier provided by the collaboration owner.
-
#query_log_status ⇒ String
An indicator as to whether query logging has been enabled or disabled for the collaboration.
-
#update_time ⇒ Time
The time the collaboration metadata was last updated.
Instance Attribute Details
#allowed_result_regions ⇒ Array<String>
The Amazon Web Services Regions where collaboration query results can be stored. Returns the list of Region identifiers that were specified when the collaboration was created. This list is used to enforce regional storage policies and compliance requirements.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#analytics_engine ⇒ String
The analytics engine for the collaboration.
<note markdown=“1”> After July 16, 2025, the ‘CLEAN_ROOMS_SQL` parameter will no longer be available.
</note>
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique ARN for the collaboration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#auto_approved_change_types ⇒ Array<String>
The types of change requests that are automatically approved for this collaboration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the collaboration was created.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#creator_display_name ⇒ String
A display name of the collaboration creator.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#data_encryption_metadata ⇒ Types::DataEncryptionMetadata
The settings for client-side encryption for cryptographic computing.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the collaboration provided by the collaboration owner.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for the collaboration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#is_metrics_enabled ⇒ Boolean
An indicator as to whether metrics are enabled for the collaboration.
When ‘true`, collaboration members can opt in to Amazon CloudWatch metrics for their membership queries.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#job_log_status ⇒ String
An indicator as to whether job logging has been enabled or disabled for the collaboration.
When ‘ENABLED`, Clean Rooms logs details about jobs run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is `DISABLED`.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#member_status ⇒ String
The status of a member in a collaboration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The unique ARN for your membership within the collaboration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique ID for your membership within the collaboration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A human-readable identifier provided by the collaboration owner. Display names are not unique.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#query_log_status ⇒ String
An indicator as to whether query logging has been enabled or disabled for the collaboration.
When ‘ENABLED`, Clean Rooms logs details about queries run within this collaboration and those logs can be viewed in Amazon CloudWatch Logs. The default value is `DISABLED`.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the collaboration metadata was last updated.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1381 class Collaboration < Struct.new( :id, :arn, :name, :description, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :data_encryption_metadata, :query_log_status, :job_log_status, :analytics_engine, :auto_approved_change_types, :allowed_result_regions, :is_metrics_enabled) SENSITIVE = [] include Aws::Structure end |