Class: Aws::CleanRooms::Types::CollaborationAnalysisTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

The analysis template within a collaboration.

Constant Summary collapse

SENSITIVE =
[:analysis_parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_parametersArray<Types::AnalysisParameter>

The analysis parameters that have been specified in the analysis template.

Returns:



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the analysis template.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#collaboration_arnString

The unique ARN for the analysis template’s associated collaboration.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#collaboration_idString

A unique identifier for the collaboration that the analysis templates belong to. Currently accepts collaboration ID.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#create_timeTime

The time that the analysis template within a collaboration was created.

Returns:

  • (Time)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#creator_account_idString

The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#descriptionString

The description of the analysis template.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#error_message_configurationTypes::ErrorMessageConfiguration

The configuration that specifies the level of detail in error messages returned by analyses using this template. When set to ‘DETAILED`, error messages include more information to help troubleshoot issues with PySpark jobs. Detailed error messages may expose underlying data, including sensitive information. Recommended for faster troubleshooting in development and testing environments.



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#formatString

The format of the analysis template in the collaboration.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#idString

The identifier of the analysis template.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#nameString

The name of the analysis template.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#schemaTypes::AnalysisSchema

The entire schema object.



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#sourceTypes::AnalysisSource

The source of the analysis template within a collaboration.



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#source_metadataTypes::AnalysisSourceMetadata

The source metadata for the collaboration analysis template.



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#synthetic_data_parametersTypes::SyntheticDataParameters

The synthetic data generation parameters configured for this collaboration analysis template.



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#update_timeTime

The time that the analysis template in the collaboration was last updated.

Returns:

  • (Time)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end

#validationsArray<Types::AnalysisTemplateValidationStatusDetail>

The validations that were performed.



1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487

class CollaborationAnalysisTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :description,
  :creator_account_id,
  :name,
  :create_time,
  :update_time,
  :schema,
  :format,
  :source,
  :source_metadata,
  :analysis_parameters,
  :validations,
  :error_message_configuration,
  :synthetic_data_parameters)
  SENSITIVE = [:analysis_parameters]
  include Aws::Structure
end