Class: Aws::CleanRooms::Types::CollaborationAnalysisTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationAnalysisTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The analysis template within a collaboration.
Constant Summary collapse
- SENSITIVE =
[:analysis_parameters]
Instance Attribute Summary collapse
-
#analysis_parameters ⇒ Array<Types::AnalysisParameter>
The analysis parameters that have been specified in the analysis template.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
-
#collaboration_arn ⇒ String
The unique ARN for the analysis template’s associated collaboration.
-
#collaboration_id ⇒ String
A unique identifier for the collaboration that the analysis templates belong to.
-
#create_time ⇒ Time
The time that the analysis template within a collaboration was created.
-
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration.
-
#description ⇒ String
The description of the analysis template.
-
#error_message_configuration ⇒ Types::ErrorMessageConfiguration
The configuration that specifies the level of detail in error messages returned by analyses using this template.
-
#format ⇒ String
The format of the analysis template in the collaboration.
-
#id ⇒ String
The identifier of the analysis template.
-
#name ⇒ String
The name of the analysis template.
-
#schema ⇒ Types::AnalysisSchema
The entire schema object.
-
#source ⇒ Types::AnalysisSource
The source of the analysis template within a collaboration.
-
#source_metadata ⇒ Types::AnalysisSourceMetadata
The source metadata for the collaboration analysis template.
-
#synthetic_data_parameters ⇒ Types::SyntheticDataParameters
The synthetic data generation parameters configured for this collaboration analysis template.
-
#update_time ⇒ Time
The time that the analysis template in the collaboration was last updated.
-
#validations ⇒ Array<Types::AnalysisTemplateValidationStatusDetail>
The validations that were performed.
Instance Attribute Details
#analysis_parameters ⇒ Array<Types::AnalysisParameter>
The analysis parameters that have been specified in the analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique ARN for the analysis template’s associated collaboration.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#collaboration_id ⇒ String
A unique identifier for the collaboration that the analysis templates belong to. Currently accepts collaboration ID.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#create_time ⇒ Time
The time that the analysis template within a collaboration was created.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#description ⇒ String
The description of the analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#error_message_configuration ⇒ Types::ErrorMessageConfiguration
The configuration that specifies the level of detail in error messages returned by analyses using this template. When set to ‘DETAILED`, error messages include more information to help troubleshoot issues with PySpark jobs. Detailed error messages may expose underlying data, including sensitive information. Recommended for faster troubleshooting in development and testing environments.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#format ⇒ String
The format of the analysis template in the collaboration.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#id ⇒ String
The identifier of the analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#name ⇒ String
The name of the analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#schema ⇒ Types::AnalysisSchema
The entire schema object.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#source ⇒ Types::AnalysisSource
The source of the analysis template within a collaboration.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#source_metadata ⇒ Types::AnalysisSourceMetadata
The source metadata for the collaboration analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#synthetic_data_parameters ⇒ Types::SyntheticDataParameters
The synthetic data generation parameters configured for this collaboration analysis template.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#update_time ⇒ Time
The time that the analysis template in the collaboration was last updated.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |
#validations ⇒ Array<Types::AnalysisTemplateValidationStatusDetail>
The validations that were performed.
1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1487 class CollaborationAnalysisTemplate < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :description, :creator_account_id, :name, :create_time, :update_time, :schema, :format, :source, :source_metadata, :analysis_parameters, :validations, :error_message_configuration, :synthetic_data_parameters) SENSITIVE = [:analysis_parameters] include Aws::Structure end |