Class: Aws::CleanRooms::Types::CollaborationChangeSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationChangeSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Defines the specific changes being requested for a collaboration, including configuration modifications and approval requirements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_approved_change_types ⇒ Array<String>
Defines requested updates to properties of the collaboration.
Instance Attribute Details
#auto_approved_change_types ⇒ Array<String>
Defines requested updates to properties of the collaboration. Currently, this only supports modifying which change types are auto-approved for the collaboration.
1688 1689 1690 1691 1692 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1688 class CollaborationChangeSpecification < Struct.new( :auto_approved_change_types) SENSITIVE = [] include Aws::Structure end |