Class: Aws::CleanRooms::Types::CollaborationConfiguredAudienceModelAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationConfiguredAudienceModelAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The configured audience model association within a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model association.
-
#collaboration_arn ⇒ String
The unique ARN for the configured audience model’s associated collaboration.
-
#collaboration_id ⇒ String
A unique identifier for the collaboration that the configured audience model associations belong to.
-
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configure audience model.
-
#create_time ⇒ Time
The time at which the configured audience model association was created.
-
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration.
-
#description ⇒ String
The description of the configured audience model association.
-
#id ⇒ String
The identifier of the configured audience model association.
-
#name ⇒ String
The name of the configured audience model association.
-
#update_time ⇒ Time
The most recent time at which the configured audience model association was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model association.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The unique ARN for the configured audience model’s associated collaboration.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
A unique identifier for the collaboration that the configured audience model associations belong to. Accepts collaboration ID.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configure audience model.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the configured audience model association was created.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration. Only supports Amazon Web Services account ID.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configured audience model association.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the configured audience model association.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured audience model association.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the configured audience model association was updated.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1744 class CollaborationConfiguredAudienceModelAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :configured_audience_model_arn, :name, :description, :creator_account_id, :create_time, :update_time) SENSITIVE = [] include Aws::Structure end |