Class: Aws::CleanRooms::Types::CollaborationIdNamespaceAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationIdNamespaceAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Defines details for the collaboration ID namespace association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration ID namespace association.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the collaboration ID namespace association.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains the collaboration ID namespace association.
-
#create_time ⇒ Time
The time at which the collaboration ID namespace association was created.
-
#creator_account_id ⇒ String
The unique identifier of the Amazon Web Services account that created the collaboration ID namespace association.
-
#description ⇒ String
The description of the collaboration ID namespace association.
-
#id ⇒ String
The unique identifier of the collaboration ID namespace association.
-
#id_mapping_config ⇒ Types::IdMappingConfig
The configuration settings for the ID mapping table.
-
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration that's necessary to create the collaboration ID namespace association.
-
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferenceProperties
The input reference properties that are needed to create the collaboration ID namespace association.
-
#name ⇒ String
The name of the collaboration ID namespace association.
-
#update_time ⇒ Time
The most recent time at which the collaboration ID namespace was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the collaboration ID namespace association was created.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The unique identifier of the Amazon Web Services account that created the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#id_mapping_config ⇒ Types::IdMappingConfig
The configuration settings for the ID mapping table.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration that's necessary to create the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferenceProperties
The input reference properties that are needed to create the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the collaboration ID namespace association.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the collaboration ID namespace was updated.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2198 class CollaborationIdNamespaceAssociation < Struct.new( :id, :arn, :collaboration_id, :collaboration_arn, :name, :description, :creator_account_id, :create_time, :update_time, :input_reference_config, :input_reference_properties, :id_mapping_config) SENSITIVE = [] include Aws::Structure end |