Class: Aws::CleanRooms::Types::CollaborationIdNamespaceAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Provides summary information about the collaboration ID namespace association.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the collaboration ID namespace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_arnString

The Amazon Resource Name (ARN) of the collaboration that contains this collaboration ID namespace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_idString

The unique identifier of the collaboration that contains this collaboration ID namespace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the collaboration ID namespace association was created.

Returns:

  • (Time)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#creator_account_idString

The Amazon Web Services account that created this collaboration ID namespace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the collaboration ID namepsace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the collaboration ID namespace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#input_reference_configTypes::IdNamespaceAssociationInputReferenceConfig

The input reference configuration that's used to create the collaboration ID namespace association.



2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#input_reference_propertiesTypes::IdNamespaceAssociationInputReferencePropertiesSummary

The input reference properties that are used to create the collaboration ID namespace association.



2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the collaboration ID namespace association.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The most recent time at which the collaboration ID namespace association was updated.

Returns:

  • (Time)


2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2002

class CollaborationIdNamespaceAssociationSummary < Struct.new(
  :arn,
  :create_time,
  :id,
  :update_time,
  :collaboration_arn,
  :collaboration_id,
  :creator_account_id,
  :input_reference_config,
  :name,
  :description,
  :input_reference_properties)
  SENSITIVE = []
  include Aws::Structure
end