Class: Aws::CleanRooms::Types::CollaborationIdNamespaceAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationIdNamespaceAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Provides summary information about the collaboration ID namespace association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration ID namespace association.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this collaboration ID namespace association.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this collaboration ID namespace association.
-
#create_time ⇒ Time
The time at which the collaboration ID namespace association was created.
-
#creator_account_id ⇒ String
The Amazon Web Services account that created this collaboration ID namespace association.
-
#description ⇒ String
The description of the collaboration ID namepsace association.
-
#id ⇒ String
The unique identifier of the collaboration ID namespace association.
-
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration that’s used to create the collaboration ID namespace association.
-
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferencePropertiesSummary
The input reference properties that are used to create the collaboration ID namespace association.
-
#name ⇒ String
The name of the collaboration ID namespace association.
-
#update_time ⇒ Time
The most recent time at which the collaboration ID namespace association was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the collaboration ID namespace association was created.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The Amazon Web Services account that created this collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the collaboration ID namepsace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration that’s used to create the collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferencePropertiesSummary
The input reference properties that are used to create the collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the collaboration ID namespace association.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the collaboration ID namespace association was updated.
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 1954 class CollaborationIdNamespaceAssociationSummary < Struct.new( :arn, :create_time, :id, :update_time, :collaboration_arn, :collaboration_id, :creator_account_id, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |