Class: Aws::CleanRooms::Types::CollaborationPrivacyBudgetTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

An array that specifies the information for a collaboration's privacy budget template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the collaboration privacy budget template.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#auto_refreshString

How often the privacy budget refreshes.

If you plan to regularly bring new data into the collaboration, use CALENDAR_MONTH to automatically get a new privacy budget for the collaboration every calendar month. Choosing this option allows arbitrary amounts of information to be revealed about rows of the data when repeatedly queried across refreshes. Avoid choosing this if the same rows will be repeatedly queried between privacy budget refreshes.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_arnString

The ARN of the collaboration that includes this collaboration privacy budget template.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_idString

The unique identifier of the collaboration that includes this collaboration privacy budget template.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the collaboration privacy budget template was created.

Returns:

  • (Time)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#creator_account_idString

The unique identifier of the account that created this collaboration privacy budget template.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the collaboration privacy budget template.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::PrivacyBudgetTemplateParametersOutput

Specifies the epsilon and noise parameters for the privacy budget template.



2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_budget_typeString

The type of privacy budget template.

Returns:

  • (String)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The most recent time at which the collaboration privacy budget template was updated.

Returns:

  • (Time)


2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2140

class CollaborationPrivacyBudgetTemplate < Struct.new(
  :id,
  :arn,
  :collaboration_id,
  :collaboration_arn,
  :creator_account_id,
  :create_time,
  :update_time,
  :privacy_budget_type,
  :auto_refresh,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end