Class: Aws::CleanRooms::Types::CollaborationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CollaborationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The metadata of the collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_engine ⇒ String
The analytics engine.
-
#arn ⇒ String
The ARN of the collaboration.
-
#create_time ⇒ Time
The time when the collaboration was created.
-
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration.
-
#creator_display_name ⇒ String
The display name of the collaboration creator.
-
#id ⇒ String
The identifier for the collaboration.
-
#member_status ⇒ String
The status of a member in a collaboration.
-
#membership_arn ⇒ String
The ARN of a member in a collaboration.
-
#membership_id ⇒ String
The identifier of a member in a collaboration.
-
#name ⇒ String
A human-readable identifier provided by the collaboration owner.
-
#update_time ⇒ Time
The time the collaboration metadata was last updated.
Instance Attribute Details
#analytics_engine ⇒ String
The analytics engine.
CLEAN_ROOMS_SQL parameter will no longer
be available.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the collaboration.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the collaboration was created.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#creator_display_name ⇒ String
The display name of the collaboration creator.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier for the collaboration.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#member_status ⇒ String
The status of a member in a collaboration.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The ARN of a member in a collaboration.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The identifier of a member in a collaboration.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A human-readable identifier provided by the collaboration owner. Display names are not unique.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the collaboration metadata was last updated.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2266 class CollaborationSummary < Struct.new( :id, :arn, :name, :creator_account_id, :creator_display_name, :create_time, :update_time, :member_status, :membership_id, :membership_arn, :analytics_engine) SENSITIVE = [] include Aws::Structure end |