Class: Aws::CleanRooms::Types::ColumnLineageEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ColumnLineageEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains column lineage information that traces a disallowed output column back to its source in a base table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column ⇒ String
The name of the column in the intermediate table.
-
#source_account_id ⇒ String
The Amazon Web Services account ID of the owner of the source table.
-
#source_column ⇒ String
The name of the column in the source table.
-
#source_id ⇒ String
The unique identifier of the source table.
-
#source_name ⇒ String
The name of the source table.
-
#source_type ⇒ String
The type of the source table.
Instance Attribute Details
#column ⇒ String
The name of the column in the intermediate table.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2545 class ColumnLineageEntry < Struct.new( :column, :source_column, :source_name, :source_id, :source_type, :source_account_id) SENSITIVE = [] include Aws::Structure end |
#source_account_id ⇒ String
The Amazon Web Services account ID of the owner of the source table.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2545 class ColumnLineageEntry < Struct.new( :column, :source_column, :source_name, :source_id, :source_type, :source_account_id) SENSITIVE = [] include Aws::Structure end |
#source_column ⇒ String
The name of the column in the source table.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2545 class ColumnLineageEntry < Struct.new( :column, :source_column, :source_name, :source_id, :source_type, :source_account_id) SENSITIVE = [] include Aws::Structure end |
#source_id ⇒ String
The unique identifier of the source table.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2545 class ColumnLineageEntry < Struct.new( :column, :source_column, :source_name, :source_id, :source_type, :source_account_id) SENSITIVE = [] include Aws::Structure end |
#source_name ⇒ String
The name of the source table.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2545 class ColumnLineageEntry < Struct.new( :column, :source_column, :source_name, :source_id, :source_type, :source_account_id) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of the source table.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2545 class ColumnLineageEntry < Struct.new( :column, :source_column, :source_name, :source_id, :source_type, :source_account_id) SENSITIVE = [] include Aws::Structure end |