Class: Aws::CleanRooms::Types::ConfiguredAudienceModelAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredAudienceModelAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A summary of the configured audience model association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model association.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the configured audience model association.
-
#collaboration_id ⇒ String
A unique identifier of the collaboration that configured audience model is associated with.
-
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model that was used for this configured audience model association.
-
#create_time ⇒ Time
The time at which the configured audience model association was created.
-
#description ⇒ String
The description of the configured audience model association.
-
#id ⇒ String
A unique identifier of the configured audience model association.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership that contains the configured audience model association.
-
#membership_id ⇒ String
A unique identifier of the membership that contains the configured audience model association.
-
#name ⇒ String
The name of the configured audience model association.
-
#update_time ⇒ Time
The most recent time at which the configured audience model association was updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
A unique identifier of the collaboration that configured audience model is associated with.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model that was used for this configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the configured audience model association was created.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier of the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership that contains the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
A unique identifier of the membership that contains the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured audience model association.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the configured audience model association was updated.
2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2738 class ConfiguredAudienceModelAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :name, :configured_audience_model_arn, :description) SENSITIVE = [] include Aws::Structure end |