Class: Aws::CleanRooms::Types::ConfiguredTableAnalysisRulePolicyV1
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAnalysisRulePolicyV1
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
ConfiguredTableAnalysisRulePolicyV1 is a union - when making an API calls you must set exactly one of the members.
ConfiguredTableAnalysisRulePolicyV1 is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConfiguredTableAnalysisRulePolicyV1 corresponding to the set member.
Controls on the query specifications that can be run on a configured table.
Defined Under Namespace
Classes: Aggregation, Custom, List, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation ⇒ Types::AnalysisRuleAggregation
Analysis rule type that enables only aggregation queries on a configured table.
-
#custom ⇒ Types::AnalysisRuleCustom
A type of analysis rule that enables the table owner to approve custom SQL queries on their configured tables.
-
#list ⇒ Types::AnalysisRuleList
Analysis rule type that enables only list queries on a configured table.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#aggregation ⇒ Types::AnalysisRuleAggregation
Analysis rule type that enables only aggregation queries on a configured table.
2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2721 class ConfiguredTableAnalysisRulePolicyV1 < Struct.new( :list, :aggregation, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class List < ConfiguredTableAnalysisRulePolicyV1; end class Aggregation < ConfiguredTableAnalysisRulePolicyV1; end class Custom < ConfiguredTableAnalysisRulePolicyV1; end class Unknown < ConfiguredTableAnalysisRulePolicyV1; end end |
#custom ⇒ Types::AnalysisRuleCustom
A type of analysis rule that enables the table owner to approve custom SQL queries on their configured tables. It supports differential privacy.
2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2721 class ConfiguredTableAnalysisRulePolicyV1 < Struct.new( :list, :aggregation, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class List < ConfiguredTableAnalysisRulePolicyV1; end class Aggregation < ConfiguredTableAnalysisRulePolicyV1; end class Custom < ConfiguredTableAnalysisRulePolicyV1; end class Unknown < ConfiguredTableAnalysisRulePolicyV1; end end |
#list ⇒ Types::AnalysisRuleList
Analysis rule type that enables only list queries on a configured table.
2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2721 class ConfiguredTableAnalysisRulePolicyV1 < Struct.new( :list, :aggregation, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class List < ConfiguredTableAnalysisRulePolicyV1; end class Aggregation < ConfiguredTableAnalysisRulePolicyV1; end class Custom < ConfiguredTableAnalysisRulePolicyV1; end class Unknown < ConfiguredTableAnalysisRulePolicyV1; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2721 2722 2723 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2721 def unknown @unknown end |