Class: Aws::CleanRooms::Types::ConfiguredTableAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
A configured table association links a configured table to a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule_types ⇒ Array<String>
The analysis rule types for the configured table association.
-
#arn ⇒ String
The unique ARN for the configured table association.
-
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this configured table association.
-
#configured_table_arn ⇒ String
The unique ARN for the configured table that the association refers to.
-
#configured_table_id ⇒ String
The unique ID for the configured table that the association refers to.
-
#create_time ⇒ Time
The time the configured table association was created.
-
#description ⇒ String
A description of the configured table association.
-
#id ⇒ String
The unique ID for the configured table association.
-
#membership_arn ⇒ String
The unique ARN for the membership this configured table association belongs to.
-
#membership_id ⇒ String
The unique ID for the membership this configured table association belongs to.
-
#name ⇒ String
The name of the configured table association, in lowercase.
-
#role_arn ⇒ String
The service will assume this role to access catalog metadata and query the table.
-
#update_time ⇒ Time
The time the configured table association was last updated.
Instance Attribute Details
#analysis_rule_types ⇒ Array<String>
The analysis rule types for the configured table association.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique ARN for the configured table association.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#child_resources ⇒ Array<Types::ChildResource>
The child resources that depend on this configured table association.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#configured_table_arn ⇒ String
The unique ARN for the configured table that the association refers to.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#configured_table_id ⇒ String
The unique ID for the configured table that the association refers to.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the configured table association was created.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the configured table association.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for the configured table association.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The unique ARN for the membership this configured table association belongs to.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique ID for the membership this configured table association belongs to.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured table association, in lowercase. The table is identified by this name when running protected queries against the underlying data.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The service will assume this role to access catalog metadata and query the table.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the configured table association was last updated.
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2998 class ConfiguredTableAssociation < Struct.new( :arn, :id, :configured_table_id, :configured_table_arn, :membership_id, :membership_arn, :role_arn, :name, :description, :analysis_rule_types, :create_time, :update_time, :child_resources) SENSITIVE = [] include Aws::Structure end |