Class: Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRuleAggregation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRuleAggregation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The configured table association analysis rule applied to a configured table with the aggregation analysis rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_additional_analyses ⇒ Array<String>
The list of resources or wildcards (ARNs) that are allowed to perform additional analysis on query output.
-
#allowed_result_receivers ⇒ Array<String>
The list of collaboration members who are allowed to receive results of queries run with this configured table.
Instance Attribute Details
#allowed_additional_analyses ⇒ Array<String>
The list of resources or wildcards (ARNs) that are allowed to perform additional analysis on query output.
The allowedAdditionalAnalyses parameter is currently supported for the list analysis rule (AnalysisRuleList) and the custom analysis rule (AnalysisRuleCustom).
2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2793 class ConfiguredTableAssociationAnalysisRuleAggregation < Struct.new( :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |
#allowed_result_receivers ⇒ Array<String>
The list of collaboration members who are allowed to receive results of queries run with this configured table.
2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 2793 class ConfiguredTableAssociationAnalysisRuleAggregation < Struct.new( :allowed_result_receivers, :allowed_additional_analyses) SENSITIVE = [] include Aws::Structure end |