Class: Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRulePolicyV1

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

ConfiguredTableAssociationAnalysisRulePolicyV1 is a union - when making an API calls you must set exactly one of the members.

Note:

ConfiguredTableAssociationAnalysisRulePolicyV1 is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConfiguredTableAssociationAnalysisRulePolicyV1 corresponding to the set member.

Controls on the query specifications that can be run on an associated configured table.

Defined Under Namespace

Classes: Aggregation, Custom, List, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregationTypes::ConfiguredTableAssociationAnalysisRuleAggregation

Analysis rule type that enables only aggregation queries on a configured table.



3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3286

class ConfiguredTableAssociationAnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Aggregation < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Custom < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Unknown < ConfiguredTableAssociationAnalysisRulePolicyV1; end
end

#customTypes::ConfiguredTableAssociationAnalysisRuleCustom

Analysis rule type that enables the table owner to approve custom SQL queries on their configured tables. It supports differential privacy.



3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3286

class ConfiguredTableAssociationAnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Aggregation < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Custom < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Unknown < ConfiguredTableAssociationAnalysisRulePolicyV1; end
end

#listTypes::ConfiguredTableAssociationAnalysisRuleList

Analysis rule type that enables only list queries on a configured table.



3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3286

class ConfiguredTableAssociationAnalysisRulePolicyV1 < Struct.new(
  :list,
  :aggregation,
  :custom,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class List < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Aggregation < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Custom < ConfiguredTableAssociationAnalysisRulePolicyV1; end
  class Unknown < ConfiguredTableAssociationAnalysisRulePolicyV1; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3286
3287
3288
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3286

def unknown
  @unknown
end