Class: Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRulePolicyV1
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAssociationAnalysisRulePolicyV1
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
ConfiguredTableAssociationAnalysisRulePolicyV1 is a union - when making an API calls you must set exactly one of the members.
ConfiguredTableAssociationAnalysisRulePolicyV1 is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConfiguredTableAssociationAnalysisRulePolicyV1 corresponding to the set member.
Controls on the query specifications that can be run on an associated configured table.
Defined Under Namespace
Classes: Aggregation, Custom, List, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation ⇒ Types::ConfiguredTableAssociationAnalysisRuleAggregation
Analysis rule type that enables only aggregation queries on a configured table.
-
#custom ⇒ Types::ConfiguredTableAssociationAnalysisRuleCustom
Analysis rule type that enables the table owner to approve custom SQL queries on their configured tables.
-
#list ⇒ Types::ConfiguredTableAssociationAnalysisRuleList
Analysis rule type that enables only list queries on a configured table.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#aggregation ⇒ Types::ConfiguredTableAssociationAnalysisRuleAggregation
Analysis rule type that enables only aggregation queries on a configured table.
3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3184 class ConfiguredTableAssociationAnalysisRulePolicyV1 < Struct.new( :list, :aggregation, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class List < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Aggregation < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Custom < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Unknown < ConfiguredTableAssociationAnalysisRulePolicyV1; end end |
#custom ⇒ Types::ConfiguredTableAssociationAnalysisRuleCustom
Analysis rule type that enables the table owner to approve custom SQL queries on their configured tables. It supports differential privacy.
3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3184 class ConfiguredTableAssociationAnalysisRulePolicyV1 < Struct.new( :list, :aggregation, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class List < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Aggregation < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Custom < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Unknown < ConfiguredTableAssociationAnalysisRulePolicyV1; end end |
#list ⇒ Types::ConfiguredTableAssociationAnalysisRuleList
Analysis rule type that enables only list queries on a configured table.
3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3184 class ConfiguredTableAssociationAnalysisRulePolicyV1 < Struct.new( :list, :aggregation, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class List < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Aggregation < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Custom < ConfiguredTableAssociationAnalysisRulePolicyV1; end class Unknown < ConfiguredTableAssociationAnalysisRulePolicyV1; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3184 3185 3186 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3184 def unknown @unknown end |