Class: Aws::CleanRooms::Types::ConfiguredTableAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ConfiguredTableAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The configured table association summary for the objects listed by the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule_types ⇒ Array<String>
The analysis rule types that are associated with the configured table associations in this summary.
-
#arn ⇒ String
The unique ARN for the configured table association.
-
#configured_table_id ⇒ String
The unique configured table ID that this configured table association refers to.
-
#create_time ⇒ Time
The time the configured table association was created.
-
#id ⇒ String
The unique ID for the configured table association.
-
#membership_arn ⇒ String
The unique ARN for the membership that the configured table association belongs to.
-
#membership_id ⇒ String
The unique ID for the membership that the configured table association belongs to.
-
#name ⇒ String
The name of the configured table association.
-
#update_time ⇒ Time
The time the configured table association was last updated.
Instance Attribute Details
#analysis_rule_types ⇒ Array<String>
The analysis rule types that are associated with the configured table associations in this summary.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique ARN for the configured table association.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#configured_table_id ⇒ String
The unique configured table ID that this configured table association refers to.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the configured table association was created.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for the configured table association.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The unique ARN for the membership that the configured table association belongs to.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique ID for the membership that the configured table association belongs to.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured table association. The table is identified by this name when running Protected Queries against the underlying data.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the configured table association was last updated.
3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 3064 class ConfiguredTableAssociationSummary < Struct.new( :configured_table_id, :membership_id, :membership_arn, :name, :create_time, :update_time, :id, :arn, :analysis_rule_types) SENSITIVE = [] include Aws::Structure end |