Class: Aws::CleanRooms::Types::CreateIntermediateTableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::CreateIntermediateTableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the intermediate table.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the customer-managed KMS key used to encrypt the intermediate table data.
-
#membership_identifier ⇒ String
The unique identifier of the membership where the intermediate table is created.
-
#name ⇒ String
The display name for the intermediate table.
-
#population_analysis_configuration ⇒ Types::PopulationAnalysisConfiguration
The configuration that defines the analysis used to populate the intermediate table.
-
#retention_in_days ⇒ Integer
The number of days to retain populated data versions.
-
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it.
Instance Attribute Details
#description ⇒ String
A description of the intermediate table.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the customer-managed KMS key used to encrypt the intermediate table data.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The unique identifier of the membership where the intermediate table is created.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The display name for the intermediate table.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |
#population_analysis_configuration ⇒ Types::PopulationAnalysisConfiguration
The configuration that defines the analysis used to populate the intermediate table.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days to retain populated data versions.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4257 class CreateIntermediateTableInput < Struct.new( :membership_identifier, :name, :description, :population_analysis_configuration, :kms_key_arn, :retention_in_days, :tags) SENSITIVE = [] include Aws::Structure end |