Class: Aws::CleanRooms::Types::DifferentialPrivacyPreviewParametersInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::DifferentialPrivacyPreviewParametersInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The epsilon and noise parameters that you want to preview.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#epsilon ⇒ Integer
The epsilon value that you want to preview.
-
#users_noise_per_query ⇒ Integer
Noise added per query is measured in terms of the number of users whose contributions you want to obscure.
Instance Attribute Details
#epsilon ⇒ Integer
The epsilon value that you want to preview.
4862 4863 4864 4865 4866 4867 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4862 class DifferentialPrivacyPreviewParametersInput < Struct.new( :epsilon, :users_noise_per_query) SENSITIVE = [] include Aws::Structure end |
#users_noise_per_query ⇒ Integer
Noise added per query is measured in terms of the number of users whose contributions you want to obscure. This value governs the rate at which the privacy budget is depleted.
4862 4863 4864 4865 4866 4867 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 4862 class DifferentialPrivacyPreviewParametersInput < Struct.new( :epsilon, :users_noise_per_query) SENSITIVE = [] include Aws::Structure end |