Class: Aws::CleanRooms::Types::GetAnalysisLogExportInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::GetAnalysisLogExportInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_log_export_identifier ⇒ String
The unique identifier of the analysis log export to retrieve.
-
#membership_identifier ⇒ String
A unique identifier for the membership that the analysis log export belongs to.
Instance Attribute Details
#analysis_log_export_identifier ⇒ String
The unique identifier of the analysis log export to retrieve.
5109 5110 5111 5112 5113 5114 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5109 class GetAnalysisLogExportInput < Struct.new( :membership_identifier, :analysis_log_export_identifier) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
A unique identifier for the membership that the analysis log export belongs to. Currently accepts the membership ID.
5109 5110 5111 5112 5113 5114 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 5109 class GetAnalysisLogExportInput < Struct.new( :membership_identifier, :analysis_log_export_identifier) SENSITIVE = [] include Aws::Structure end |