Class: Aws::CleanRooms::Types::IdNamespaceAssociationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IdNamespaceAssociationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Detailed information about the ID namespace association.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of this ID namespace association.
-
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this ID namespace association.
-
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this ID namespace association.
-
#create_time ⇒ Time
The time at which this ID namespace association was created.
-
#description ⇒ String
The description of the ID namespace association.
-
#id ⇒ String
The unique identifier of this ID namespace association.
-
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration details for this ID namespace association.
-
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferencePropertiesSummary
The input reference properties for this ID namespace association.
-
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership resource for this ID namespace association.
-
#membership_id ⇒ String
The unique identifier of the membership resource for this ID namespace association.
-
#name ⇒ String
The name of the ID namespace association.
-
#update_time ⇒ Time
The most recent time at which this ID namespace association has been updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#collaboration_arn ⇒ String
The Amazon Resource Name (ARN) of the collaboration that contains this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#collaboration_id ⇒ String
The unique identifier of the collaboration that contains this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which this ID namespace association was created.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#input_reference_config ⇒ Types::IdNamespaceAssociationInputReferenceConfig
The input reference configuration details for this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#input_reference_properties ⇒ Types::IdNamespaceAssociationInputReferencePropertiesSummary
The input reference properties for this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The Amazon Resource Name (ARN) of the membership resource for this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership resource for this ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the ID namespace association.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which this ID namespace association has been updated.
6287 6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 6298 6299 6300 6301 6302 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6287 class IdNamespaceAssociationSummary < Struct.new( :membership_id, :membership_arn, :collaboration_arn, :collaboration_id, :create_time, :update_time, :id, :arn, :input_reference_config, :name, :description, :input_reference_properties) SENSITIVE = [] include Aws::Structure end |