Class: Aws::CleanRooms::Types::InheritedAdditionalAnalysesSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains information about a parent table that contributes an additional analyses constraint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier of the parent table.

Returns:

  • (String)


6127
6128
6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6127

class InheritedAdditionalAnalysesSource < Struct.new(
  :name,
  :id,
  :type,
  :value,
  :source_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the parent table.

Returns:

  • (String)


6127
6128
6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6127

class InheritedAdditionalAnalysesSource < Struct.new(
  :name,
  :id,
  :type,
  :value,
  :source_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_account_idString

The Amazon Web Services account ID of the member who owns the parent table.

Returns:

  • (String)


6127
6128
6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6127

class InheritedAdditionalAnalysesSource < Struct.new(
  :name,
  :id,
  :type,
  :value,
  :source_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the parent table.

Returns:

  • (String)


6127
6128
6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6127

class InheritedAdditionalAnalysesSource < Struct.new(
  :name,
  :id,
  :type,
  :value,
  :source_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The additional analyses setting defined on the parent table.

Returns:

  • (String)


6127
6128
6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6127

class InheritedAdditionalAnalysesSource < Struct.new(
  :name,
  :id,
  :type,
  :value,
  :source_account_id)
  SENSITIVE = []
  include Aws::Structure
end