Class: Aws::CleanRooms::Types::IntermediateTableAnalysisRuleCustom
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IntermediateTableAnalysisRuleCustom
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains the custom analysis rule configuration for an intermediate table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_analyses ⇒ String
The setting that controls whether additional analyses are allowed on the intermediate table.
-
#allowed_additional_analyses ⇒ Array<String>
The list of allowed additional analyses for the intermediate table.
-
#allowed_analyses ⇒ Array<String>
The list of allowed analyses that can be performed on the intermediate table.
-
#allowed_analysis_providers ⇒ Array<String>
The list of Amazon Web Services account IDs for the allowed analysis providers.
-
#allowed_result_receivers ⇒ Array<String>
The list of Amazon Web Services account IDs that are allowed to receive results from queries run on the intermediate table.
-
#differential_privacy ⇒ Types::DifferentialPrivacyConfiguration
Specifies the unique identifier for your users.
-
#disallowed_output_columns ⇒ Array<String>
The list of columns that are not allowed in the query output.
Instance Attribute Details
#additional_analyses ⇒ String
The setting that controls whether additional analyses are allowed on the intermediate table.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |
#allowed_additional_analyses ⇒ Array<String>
The list of allowed additional analyses for the intermediate table.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |
#allowed_analyses ⇒ Array<String>
The list of allowed analyses that can be performed on the intermediate table.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |
#allowed_analysis_providers ⇒ Array<String>
The list of Amazon Web Services account IDs for the allowed analysis providers.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |
#allowed_result_receivers ⇒ Array<String>
The list of Amazon Web Services account IDs that are allowed to receive results from queries run on the intermediate table.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |
#differential_privacy ⇒ Types::DifferentialPrivacyConfiguration
Specifies the unique identifier for your users.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |
#disallowed_output_columns ⇒ Array<String>
The list of columns that are not allowed in the query output.
6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6744 class IntermediateTableAnalysisRuleCustom < Struct.new( :allowed_analyses, :additional_analyses, :allowed_additional_analyses, :allowed_analysis_providers, :allowed_result_receivers, :differential_privacy, :disallowed_output_columns) SENSITIVE = [] include Aws::Structure end |