Class: Aws::CleanRooms::Types::IntermediateTableVersionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::IntermediateTableVersionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains summary information about a version of an intermediate table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The identifier of the protected query that created this version.
-
#analysis_type ⇒ String
The type of analysis that created this version.
-
#create_time ⇒ Time
The time the version was created.
-
#expiration_time ⇒ Time
The time when this version expires based on the retention period.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt this version's data.
-
#status ⇒ String
The status of the version.
-
#table_id ⇒ String
The unique identifier of the intermediate table that this version belongs to.
-
#version_id ⇒ String
The unique identifier of the version.
Instance Attribute Details
#analysis_id ⇒ String
The identifier of the protected query that created this version.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#analysis_type ⇒ String
The type of analysis that created this version.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time the version was created.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ Time
The time when this version expires based on the retention period.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt this version's data.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the version.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#table_id ⇒ String
The unique identifier of the intermediate table that this version belongs to.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The unique identifier of the version.
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7082 class IntermediateTableVersionSummary < Struct.new( :version_id, :table_id, :create_time, :analysis_id, :status, :analysis_type, :kms_key_arn, :expiration_time) SENSITIVE = [] include Aws::Structure end |