Class: Aws::CleanRooms::Types::MLSyntheticDataParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MLSyntheticDataParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Parameters that control the generation of synthetic data for machine learning, including privacy settings and column classification details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_classification ⇒ Types::ColumnClassificationDetails
Classification details for data columns that specify how each column should be treated during synthetic data generation.
-
#epsilon ⇒ Float
The epsilon value for differential privacy when generating synthetic data.
-
#max_membership_inference_attack_score ⇒ Float
The maximum acceptable score for membership inference attack vulnerability.
Instance Attribute Details
#column_classification ⇒ Types::ColumnClassificationDetails
Classification details for data columns that specify how each column should be treated during synthetic data generation.
6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6734 class MLSyntheticDataParameters < Struct.new( :epsilon, :max_membership_inference_attack_score, :column_classification) SENSITIVE = [] include Aws::Structure end |
#epsilon ⇒ Float
The epsilon value for differential privacy when generating synthetic data. Lower values provide stronger privacy guarantees but may reduce data utility.
6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6734 class MLSyntheticDataParameters < Struct.new( :epsilon, :max_membership_inference_attack_score, :column_classification) SENSITIVE = [] include Aws::Structure end |
#max_membership_inference_attack_score ⇒ Float
The maximum acceptable score for membership inference attack vulnerability. Synthetic data generation fails if the score for the resulting data exceeds this threshold.
6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6734 class MLSyntheticDataParameters < Struct.new( :epsilon, :max_membership_inference_attack_score, :column_classification) SENSITIVE = [] include Aws::Structure end |