Class: Aws::CleanRooms::Types::MemberChangeSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Specifies changes to collaboration membership, including adding new members with their abilities and display names.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID of the member to add to the collaboration.

Returns:

  • (String)


6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6775

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

Specifies the display name that will be shown for this member in the collaboration. While this field is required when inviting new members, it becomes optional when modifying abilities of existing collaboration members.

Returns:

  • (String)


6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6775

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#member_abilitiesArray<String>

The abilities granted to the collaboration member. These determine what actions the member can perform within the collaboration.

<note markdown=“1”> The following values are currently not supported: ‘CAN_QUERY` and `CAN_RUN_JOB`.

Set the value of `memberAbilities` to `[]` to allow a member to

contribute data.

Set the value of `memberAbilities` to `[CAN_RECEIVE_RESULTS]` to

allow a member to contribute data and receive results.

</note>

Returns:

  • (Array<String>)


6775
6776
6777
6778
6779
6780
6781
# File 'lib/aws-sdk-cleanrooms/types.rb', line 6775

class MemberChangeSpecification < Struct.new(
  :account_id,
  :member_abilities,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end