Class: Aws::CleanRooms::Types::MemberSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MemberSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The member object listed by the request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#abilities ⇒ Array<String>
The abilities granted to the collaboration member.
-
#account_id ⇒ String
The identifier used to reference members of the collaboration.
-
#create_time ⇒ Time
The time when the member was created.
-
#display_name ⇒ String
The member's display name.
-
#membership_arn ⇒ String
The unique ARN for the member's associated membership, if present.
-
#membership_id ⇒ String
The unique ID for the member's associated membership, if present.
-
#ml_abilities ⇒ Types::MLMemberAbilities
Provides a summary of the ML abilities for the collaboration member.
-
#payment_configuration ⇒ Types::PaymentConfiguration
The collaboration member's payment responsibilities set by the collaboration creator.
-
#status ⇒ String
The status of the member.
-
#update_time ⇒ Time
The time the member metadata was last updated.
Instance Attribute Details
#abilities ⇒ Array<String>
The abilities granted to the collaboration member.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
The identifier used to reference members of the collaboration. Currently only supports Amazon Web Services account ID.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the member was created.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The member's display name.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#membership_arn ⇒ String
The unique ARN for the member's associated membership, if present.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique ID for the member's associated membership, if present.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#ml_abilities ⇒ Types::MLMemberAbilities
Provides a summary of the ML abilities for the collaboration member.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#payment_configuration ⇒ Types::PaymentConfiguration
The collaboration member's payment responsibilities set by the collaboration creator.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the member.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The time the member metadata was last updated.
8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8130 class MemberSummary < Struct.new( :account_id, :status, :display_name, :abilities, :ml_abilities, :create_time, :update_time, :membership_id, :membership_arn, :payment_configuration) SENSITIVE = [] include Aws::Structure end |