Class: Aws::CleanRooms::Types::MembershipJobComputePaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipJobComputePaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the payment responsibilities accepted by the collaboration member for query and job compute costs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for job compute costs (
TRUE) or has not accepted to pay for query and job compute costs (FALSE).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for
job compute costs (TRUE) or has not accepted to pay for query and
job compute costs (FALSE).
There can be one or more members who are designated as payer candidates for queries and jobs.
An error message is returned for the following reasons:
-
If you set the value to
FALSEbut you are responsible to pay for query and job compute costs. -
If you set the value to
TRUEbut you are not responsible to pay for query and job compute costs.
8283 8284 8285 8286 8287 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8283 class MembershipJobComputePaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |