Class: Aws::CleanRooms::Types::MembershipModelTrainingPaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipModelTrainingPaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the collaboration member’s model training payment responsibilities set by the collaboration creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for model training costs (‘TRUE`) or has not accepted to pay for model training costs (`FALSE`).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration member has accepted to pay for model training costs (‘TRUE`) or has not accepted to pay for model training costs (`FALSE`).
If the collaboration creator has not specified anyone to pay for model training costs, then the member who can query is the default payer.
An error message is returned for the following reasons:
-
If you set the value to ‘FALSE` but you are responsible to pay for model training costs.
-
If you set the value to ‘TRUE` but you are not responsible to pay for model training costs.
7107 7108 7109 7110 7111 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7107 class MembershipModelTrainingPaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |