Class: Aws::CleanRooms::Types::MembershipProtectedJobResultConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipProtectedJobResultConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains configurations for protected job results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#output_configuration ⇒ Types::MembershipProtectedJobOutputConfiguration
The output configuration for a protected job result.
-
#role_arn ⇒ String
The unique ARN for an IAM role that is used by Clean Rooms to write protected job results to the result location, given by the member who can receive results.
Instance Attribute Details
#output_configuration ⇒ Types::MembershipProtectedJobOutputConfiguration
The output configuration for a protected job result.
7189 7190 7191 7192 7193 7194 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7189 class MembershipProtectedJobResultConfiguration < Struct.new( :output_configuration, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The unique ARN for an IAM role that is used by Clean Rooms to write protected job results to the result location, given by the member who can receive results.
7189 7190 7191 7192 7193 7194 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7189 class MembershipProtectedJobResultConfiguration < Struct.new( :output_configuration, :role_arn) SENSITIVE = [] include Aws::Structure end |