Class: Aws::CleanRooms::Types::MembershipProtectedQueryResultConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::MembershipProtectedQueryResultConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains configurations for protected query results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#output_configuration ⇒ Types::MembershipProtectedQueryOutputConfiguration
Configuration for protected query results.
-
#role_arn ⇒ String
The unique ARN for an IAM role that is used by Clean Rooms to write protected query results to the result location, given by the member who can receive results.
Instance Attribute Details
#output_configuration ⇒ Types::MembershipProtectedQueryOutputConfiguration
Configuration for protected query results.
7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7233 class MembershipProtectedQueryResultConfiguration < Struct.new( :output_configuration, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The unique ARN for an IAM role that is used by Clean Rooms to write protected query results to the result location, given by the member who can receive results.
7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7233 class MembershipProtectedQueryResultConfiguration < Struct.new( :output_configuration, :role_arn) SENSITIVE = [] include Aws::Structure end |