Class: Aws::CleanRooms::Types::ModelInferencePaymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ModelInferencePaymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
An object representing the collaboration member's model inference payment responsibilities set by the collaboration creator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_responsible ⇒ Boolean
Indicates whether the collaboration creator has configured the collaboration member to pay for model inference costs (
TRUE) or has not configured the collaboration member to pay for model inference costs (FALSE).
Instance Attribute Details
#is_responsible ⇒ Boolean
Indicates whether the collaboration creator has configured the
collaboration member to pay for model inference costs (TRUE) or
has not configured the collaboration member to pay for model
inference costs (FALSE).
One or more members can be configured as payer candidates for model inference costs.
If the collaboration creator hasn't specified anyone as the member paying for model inference costs, then the member who can query is the default payer.
8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8917 class ModelInferencePaymentConfig < Struct.new( :is_responsible) SENSITIVE = [] include Aws::Structure end |