Class: Aws::CleanRooms::Types::OutputColumnThreshold
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::OutputColumnThreshold
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Specifies the minimum number of distinct identities for an individual
output column. This value overrides the table-wide
minimumIdentityCount that you set in AggregationThreshold.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#minimum_identity_count ⇒ Integer
The minimum number of distinct identities that each query output group must represent for this column.
-
#output_column_name ⇒ String
The name of the output column that the override applies to.
Instance Attribute Details
#minimum_identity_count ⇒ Integer
The minimum number of distinct identities that each query output group must represent for this column. Specify 0 to exempt the column from the threshold, or a value of 2 or greater to enforce a threshold.
9094 9095 9096 9097 9098 9099 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9094 class OutputColumnThreshold < Struct.new( :output_column_name, :minimum_identity_count) SENSITIVE = [] include Aws::Structure end |
#output_column_name ⇒ String
The name of the output column that the override applies to. You can specify each column only once.
9094 9095 9096 9097 9098 9099 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9094 class OutputColumnThreshold < Struct.new( :output_column_name, :minimum_identity_count) SENSITIVE = [] include Aws::Structure end |