Class: Aws::CleanRooms::Types::PopulationAnalysisSqlParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PopulationAnalysisSqlParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Contains the SQL parameters used to populate an intermediate table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_template_arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template to use for populating the intermediate table.
-
#query_string ⇒ String
The SQL query string used to populate the intermediate table.
Instance Attribute Details
#analysis_template_arn ⇒ String
The Amazon Resource Name (ARN) of the analysis template to use for populating the intermediate table.
9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9128 class PopulationAnalysisSqlParameters < Struct.new( :query_string, :analysis_template_arn) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The SQL query string used to populate the intermediate table.
9128 9129 9130 9131 9132 9133 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9128 class PopulationAnalysisSqlParameters < Struct.new( :query_string, :analysis_template_arn) SENSITIVE = [] include Aws::Structure end |