Class: Aws::CleanRooms::Types::PreviewPrivacyImpactOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PreviewPrivacyImpactOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#privacy_impact ⇒ Types::PrivacyImpact
An estimate of the number of aggregation functions that the member who can query can run given the epsilon and noise parameters.
Instance Attribute Details
#privacy_impact ⇒ Types::PrivacyImpact
An estimate of the number of aggregation functions that the member who can query can run given the epsilon and noise parameters. This does not change the privacy budget.
7510 7511 7512 7513 7514 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7510 class PreviewPrivacyImpactOutput < Struct.new( :privacy_impact) SENSITIVE = [] include Aws::Structure end |