Class: Aws::CleanRooms::Types::PrivacyBudget
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PrivacyBudget
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
PrivacyBudget is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivacyBudget corresponding to the set member.
The epsilon parameter value and number of each aggregation function that you can perform.
Defined Under Namespace
Classes: AccessBudget, DifferentialPrivacy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_budget ⇒ Types::AccessBudget
Access budget information associated with this privacy budget.
-
#differential_privacy ⇒ Types::DifferentialPrivacyPrivacyBudget
An object that specifies the epsilon parameter and the utility in terms of total aggregations, as well as the remaining aggregations available.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_budget ⇒ Types::AccessBudget
Access budget information associated with this privacy budget.
9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9360 class PrivacyBudget < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudget; end class AccessBudget < PrivacyBudget; end class Unknown < PrivacyBudget; end end |
#differential_privacy ⇒ Types::DifferentialPrivacyPrivacyBudget
An object that specifies the epsilon parameter and the utility in terms of total aggregations, as well as the remaining aggregations available.
9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9360 class PrivacyBudget < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudget; end class AccessBudget < PrivacyBudget; end class Unknown < PrivacyBudget; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9360 9361 9362 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9360 def unknown @unknown end |