Class: Aws::CleanRooms::Types::PrivacyBudget
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PrivacyBudget
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
PrivacyBudget is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivacyBudget corresponding to the set member.
The epsilon parameter value and number of each aggregation function that you can perform.
Defined Under Namespace
Classes: AccessBudget, DifferentialPrivacy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_budget ⇒ Types::AccessBudget
Access budget information associated with this privacy budget.
-
#differential_privacy ⇒ Types::DifferentialPrivacyPrivacyBudget
An object that specifies the epsilon parameter and the utility in terms of total aggregations, as well as the remaining aggregations available.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_budget ⇒ Types::AccessBudget
Access budget information associated with this privacy budget.
8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8922 class PrivacyBudget < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudget; end class AccessBudget < PrivacyBudget; end class Unknown < PrivacyBudget; end end |
#differential_privacy ⇒ Types::DifferentialPrivacyPrivacyBudget
An object that specifies the epsilon parameter and the utility in terms of total aggregations, as well as the remaining aggregations available.
8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8922 class PrivacyBudget < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudget; end class AccessBudget < PrivacyBudget; end class Unknown < PrivacyBudget; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8922 8923 8924 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8922 def unknown @unknown end |