Class: Aws::CleanRooms::Types::PrivacyBudget

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

PrivacyBudget is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivacyBudget corresponding to the set member.

The epsilon parameter value and number of each aggregation function that you can perform.

Direct Known Subclasses

AccessBudget, DifferentialPrivacy, Unknown

Defined Under Namespace

Classes: AccessBudget, DifferentialPrivacy, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_budgetTypes::AccessBudget

Access budget information associated with this privacy budget.

Returns:



7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7559

class PrivacyBudget < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudget; end
  class AccessBudget < PrivacyBudget; end
  class Unknown < PrivacyBudget; end
end

#differential_privacyTypes::DifferentialPrivacyPrivacyBudget

An object that specifies the epsilon parameter and the utility in terms of total aggregations, as well as the remaining aggregations available.



7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7559

class PrivacyBudget < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudget; end
  class AccessBudget < PrivacyBudget; end
  class Unknown < PrivacyBudget; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7559
7560
7561
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7559

def unknown
  @unknown
end