Class: Aws::CleanRooms::Types::PrivacyBudgetTemplateParametersOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PrivacyBudgetTemplateParametersOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
PrivacyBudgetTemplateParametersOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivacyBudgetTemplateParametersOutput corresponding to the set member.
The epsilon and noise parameters that were used in the privacy budget template.
Direct Known Subclasses
Defined Under Namespace
Classes: AccessBudget, DifferentialPrivacy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_budget ⇒ Types::AccessBudgetsPrivacyTemplateParametersOutput
Access budget configuration returned from the privacy budget template, containing the configured access budget settings.
-
#differential_privacy ⇒ Types::DifferentialPrivacyTemplateParametersOutput
The epsilon and noise parameters.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_budget ⇒ Types::AccessBudgetsPrivacyTemplateParametersOutput
Access budget configuration returned from the privacy budget template, containing the configured access budget settings.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7773 class PrivacyBudgetTemplateParametersOutput < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudgetTemplateParametersOutput; end class AccessBudget < PrivacyBudgetTemplateParametersOutput; end class Unknown < PrivacyBudgetTemplateParametersOutput; end end |
#differential_privacy ⇒ Types::DifferentialPrivacyTemplateParametersOutput
The epsilon and noise parameters.
7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7773 class PrivacyBudgetTemplateParametersOutput < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudgetTemplateParametersOutput; end class AccessBudget < PrivacyBudgetTemplateParametersOutput; end class Unknown < PrivacyBudgetTemplateParametersOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7773 7774 7775 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 7773 def unknown @unknown end |