Class: Aws::CleanRooms::Types::PrivacyBudgetTemplateUpdateParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

PrivacyBudgetTemplateUpdateParameters is a union - when making an API calls you must set exactly one of the members.

The epsilon and noise parameters that you want to update in the privacy budget template.

Defined Under Namespace

Classes: AccessBudget, DifferentialPrivacy, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_budgetTypes::AccessBudgetsPrivacyTemplateUpdateParameters

The new access budget configuration that completely replaces the existing access budget settings in the privacy budget template.



9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9500

class PrivacyBudgetTemplateUpdateParameters < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudgetTemplateUpdateParameters; end
  class AccessBudget < PrivacyBudgetTemplateUpdateParameters; end
  class Unknown < PrivacyBudgetTemplateUpdateParameters; end
end

#differential_privacyTypes::DifferentialPrivacyTemplateUpdateParameters

An object that specifies the new values for the epsilon and noise parameters.



9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9500

class PrivacyBudgetTemplateUpdateParameters < Struct.new(
  :differential_privacy,
  :access_budget,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DifferentialPrivacy < PrivacyBudgetTemplateUpdateParameters; end
  class AccessBudget < PrivacyBudgetTemplateUpdateParameters; end
  class Unknown < PrivacyBudgetTemplateUpdateParameters; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9500
9501
9502
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9500

def unknown
  @unknown
end