Class: Aws::CleanRooms::Types::PrivacyBudgetTemplateUpdateParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PrivacyBudgetTemplateUpdateParameters
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
PrivacyBudgetTemplateUpdateParameters is a union - when making an API calls you must set exactly one of the members.
The epsilon and noise parameters that you want to update in the privacy budget template.
Defined Under Namespace
Classes: AccessBudget, DifferentialPrivacy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_budget ⇒ Types::AccessBudgetsPrivacyTemplateUpdateParameters
The new access budget configuration that completely replaces the existing access budget settings in the privacy budget template.
-
#differential_privacy ⇒ Types::DifferentialPrivacyTemplateUpdateParameters
An object that specifies the new values for the epsilon and noise parameters.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_budget ⇒ Types::AccessBudgetsPrivacyTemplateUpdateParameters
The new access budget configuration that completely replaces the existing access budget settings in the privacy budget template.
9500 9501 9502 9503 9504 9505 9506 9507 9508 9509 9510 9511 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9500 class PrivacyBudgetTemplateUpdateParameters < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudgetTemplateUpdateParameters; end class AccessBudget < PrivacyBudgetTemplateUpdateParameters; end class Unknown < PrivacyBudgetTemplateUpdateParameters; end end |
#differential_privacy ⇒ Types::DifferentialPrivacyTemplateUpdateParameters
An object that specifies the new values for the epsilon and noise parameters.
9500 9501 9502 9503 9504 9505 9506 9507 9508 9509 9510 9511 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9500 class PrivacyBudgetTemplateUpdateParameters < Struct.new( :differential_privacy, :access_budget, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyBudgetTemplateUpdateParameters; end class AccessBudget < PrivacyBudgetTemplateUpdateParameters; end class Unknown < PrivacyBudgetTemplateUpdateParameters; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9500 9501 9502 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9500 def unknown @unknown end |