Class: Aws::CleanRooms::Types::PrivacyImpact
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::PrivacyImpact
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Note:
PrivacyImpact is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivacyImpact corresponding to the set member.
Provides an estimate of the number of aggregation functions that the member who can query can run given the epsilon and noise parameters.
Defined Under Namespace
Classes: DifferentialPrivacy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#differential_privacy ⇒ Types::DifferentialPrivacyPrivacyImpact
An object that lists the number and type of aggregation functions you can perform.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#differential_privacy ⇒ Types::DifferentialPrivacyPrivacyImpact
An object that lists the number and type of aggregation functions you can perform.
9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9525 class PrivacyImpact < Struct.new( :differential_privacy, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DifferentialPrivacy < PrivacyImpact; end class Unknown < PrivacyImpact; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9525 9526 9527 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9525 def unknown @unknown end |