Class: Aws::CleanRooms::Types::ProtectedJobWorkerComputeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ProtectedJobWorkerComputeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The configuration of the compute resources for a PySpark job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#number ⇒ Integer
The number of workers for a PySpark job.
-
#properties ⇒ Types::WorkerComputeConfigurationProperties
The configuration properties for the worker compute environment.
-
#type ⇒ String
The worker compute configuration type.
Instance Attribute Details
#number ⇒ Integer
The number of workers for a PySpark job.
8361 8362 8363 8364 8365 8366 8367 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8361 class ProtectedJobWorkerComputeConfiguration < Struct.new( :type, :number, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Types::WorkerComputeConfigurationProperties
The configuration properties for the worker compute environment. These properties allow you to customize the compute settings for your Clean Rooms workloads.
8361 8362 8363 8364 8365 8366 8367 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8361 class ProtectedJobWorkerComputeConfiguration < Struct.new( :type, :number, :properties) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The worker compute configuration type.
8361 8362 8363 8364 8365 8366 8367 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8361 class ProtectedJobWorkerComputeConfiguration < Struct.new( :type, :number, :properties) SENSITIVE = [] include Aws::Structure end |