Class: Aws::CleanRooms::Types::ProtectedQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ProtectedQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The parameters for an Clean Rooms protected query.
Constant Summary collapse
- SENSITIVE =
[:sql_parameters]
Instance Attribute Summary collapse
-
#compute_configuration ⇒ Types::ComputeConfiguration
The compute configuration for the protected query.
-
#create_time ⇒ Time
The time at which the protected query was created.
-
#differential_privacy ⇒ Types::DifferentialPrivacyParameters
The sensitivity parameters of the differential privacy results of the protected query.
-
#error ⇒ Types::ProtectedQueryError
An error thrown by the protected query.
-
#id ⇒ String
The identifier for a protected query instance.
-
#membership_arn ⇒ String
The ARN of the membership.
-
#membership_id ⇒ String
The identifier for the membership.
-
#query_compute_payer_account_id ⇒ String
The account ID of the member that pays for the query compute costs.
-
#result ⇒ Types::ProtectedQueryResult
The result of the protected query.
-
#result_configuration ⇒ Types::ProtectedQueryResultConfiguration
Contains any details needed to write the query results.
-
#sql_parameters ⇒ Types::ProtectedQuerySQLParameters
The protected query SQL parameters.
-
#statistics ⇒ Types::ProtectedQueryStatistics
Statistics about protected query execution.
-
#status ⇒ String
The status of the query.
Instance Attribute Details
#compute_configuration ⇒ Types::ComputeConfiguration
The compute configuration for the protected query.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#create_time ⇒ Time
The time at which the protected query was created.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#differential_privacy ⇒ Types::DifferentialPrivacyParameters
The sensitivity parameters of the differential privacy results of the protected query.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#error ⇒ Types::ProtectedQueryError
An error thrown by the protected query.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#id ⇒ String
The identifier for a protected query instance.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#membership_arn ⇒ String
The ARN of the membership.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#membership_id ⇒ String
The identifier for the membership.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#query_compute_payer_account_id ⇒ String
The account ID of the member that pays for the query compute costs.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#result ⇒ Types::ProtectedQueryResult
The result of the protected query.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#result_configuration ⇒ Types::ProtectedQueryResultConfiguration
Contains any details needed to write the query results.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#sql_parameters ⇒ Types::ProtectedQuerySQLParameters
The protected query SQL parameters.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#statistics ⇒ Types::ProtectedQueryStatistics
Statistics about protected query execution.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#status ⇒ String
The status of the query.
10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 10097 10098 10099 10100 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10084 class ProtectedQuery < Struct.new( :id, :membership_id, :membership_arn, :create_time, :sql_parameters, :status, :result_configuration, :statistics, :result, :error, :differential_privacy, :compute_configuration, :query_compute_payer_account_id) SENSITIVE = [:sql_parameters] include Aws::Structure end |