Class: Aws::CleanRooms::Types::ProtectedQueryDistributeOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Contains the output information for a protected query with a distribute output configuration.

This output type allows query results to be distributed to multiple receivers, including S3 and collaboration members. It is only available for queries using the Spark analytics engine.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#member_listArray<Types::ProtectedQuerySingleMemberOutput>

Contains the output results for each member location specified in the distribute output configuration. Each entry provides details about the result distribution to a specific collaboration member.



10122
10123
10124
10125
10126
10127
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10122

class ProtectedQueryDistributeOutput < Struct.new(
  :s3,
  :member_list)
  SENSITIVE = []
  include Aws::Structure
end

#s3Types::ProtectedQueryS3Output

Contains output information for protected queries with an S3 output type.



10122
10123
10124
10125
10126
10127
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10122

class ProtectedQueryDistributeOutput < Struct.new(
  :s3,
  :member_list)
  SENSITIVE = []
  include Aws::Structure
end