Class: Aws::CleanRooms::Types::ProtectedQueryOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ProtectedQueryOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
ProtectedQueryOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProtectedQueryOutput corresponding to the set member.
Contains details about the protected query output.
Direct Known Subclasses
Defined Under Namespace
Classes: Distribute, MemberList, S3, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribute ⇒ Types::ProtectedQueryDistributeOutput
Contains output information for protected queries that use a
distributeoutput type. -
#member_list ⇒ Array<Types::ProtectedQuerySingleMemberOutput>
The list of member Amazon Web Services account(s) that received the results of the query.
-
#s3 ⇒ Types::ProtectedQueryS3Output
If present, the output for a protected query with an
S3output type. -
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#distribute ⇒ Types::ProtectedQueryDistributeOutput
Contains output information for protected queries that use a distribute output type. This output type lets you send query results to multiple locations - either to S3 or to collaboration members.
<note markdown=“1”> You can only use the distribute output type with the Spark analytics engine.
</note>
8574 8575 8576 8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8574 class ProtectedQueryOutput < Struct.new( :s3, :member_list, :distribute, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < ProtectedQueryOutput; end class MemberList < ProtectedQueryOutput; end class Distribute < ProtectedQueryOutput; end class Unknown < ProtectedQueryOutput; end end |
#member_list ⇒ Array<Types::ProtectedQuerySingleMemberOutput>
The list of member Amazon Web Services account(s) that received the results of the query.
8574 8575 8576 8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8574 class ProtectedQueryOutput < Struct.new( :s3, :member_list, :distribute, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < ProtectedQueryOutput; end class MemberList < ProtectedQueryOutput; end class Distribute < ProtectedQueryOutput; end class Unknown < ProtectedQueryOutput; end end |
#s3 ⇒ Types::ProtectedQueryS3Output
If present, the output for a protected query with an S3 output type.
8574 8575 8576 8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8574 class ProtectedQueryOutput < Struct.new( :s3, :member_list, :distribute, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < ProtectedQueryOutput; end class MemberList < ProtectedQueryOutput; end class Distribute < ProtectedQueryOutput; end class Unknown < ProtectedQueryOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8574 8575 8576 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8574 def unknown @unknown end |