Class: Aws::CleanRooms::Types::ReceiverConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::ReceiverConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
The receiver configuration for a protected query.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_type ⇒ String
The type of analysis for the protected query.
-
#configuration_details ⇒ Types::ConfigurationDetails
The configuration details of the receiver configuration.
Instance Attribute Details
#analysis_type ⇒ String
The type of analysis for the protected query. The results of the query can be analyzed directly (DIRECT_ANALYSIS) or used as input into additional analyses (ADDITIONAL_ANALYSIS), such as a query that is a seed for a lookalike ML model.
8880 8881 8882 8883 8884 8885 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8880 class ReceiverConfiguration < Struct.new( :analysis_type, :configuration_details) SENSITIVE = [] include Aws::Structure end |
#configuration_details ⇒ Types::ConfigurationDetails
The configuration details of the receiver configuration.
8880 8881 8882 8883 8884 8885 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 8880 class ReceiverConfiguration < Struct.new( :analysis_type, :configuration_details) SENSITIVE = [] include Aws::Structure end |