Class: Aws::CleanRooms::Types::StartAnalysisLogExportInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The unique identifier of the protected query that you want to export the analysis logs for.

Returns:

  • (String)


11043
11044
11045
11046
11047
11048
11049
11050
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043

class StartAnalysisLogExportInput < Struct.new(
  :membership_identifier,
  :analysis_id,
  :analysis_type,
  :result_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#analysis_typeString

The type of analysis that the logs are exported for. Currently, only PROTECTED_QUERY is supported.

Returns:

  • (String)


11043
11044
11045
11046
11047
11048
11049
11050
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043

class StartAnalysisLogExportInput < Struct.new(
  :membership_identifier,
  :analysis_id,
  :analysis_type,
  :result_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

A unique identifier for the membership to export the analysis logs for. Currently accepts a membership ID.

Returns:

  • (String)


11043
11044
11045
11046
11047
11048
11049
11050
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043

class StartAnalysisLogExportInput < Struct.new(
  :membership_identifier,
  :analysis_id,
  :analysis_type,
  :result_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#result_configurationTypes::AnalysisLogExportResultConfiguration

The details needed to write the exported analysis logs.

You don't need to create an IAM role for log export. Clean Rooms writes the exported logs using your own identity, so Clean Rooms writes the exported logs only where your existing permissions allow.



11043
11044
11045
11046
11047
11048
11049
11050
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043

class StartAnalysisLogExportInput < Struct.new(
  :membership_identifier,
  :analysis_id,
  :analysis_type,
  :result_configuration)
  SENSITIVE = []
  include Aws::Structure
end