Class: Aws::CleanRooms::Types::StartAnalysisLogExportInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::StartAnalysisLogExportInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The unique identifier of the protected query that you want to export the analysis logs for.
-
#analysis_type ⇒ String
The type of analysis that the logs are exported for.
-
#membership_identifier ⇒ String
A unique identifier for the membership to export the analysis logs for.
-
#result_configuration ⇒ Types::AnalysisLogExportResultConfiguration
The details needed to write the exported analysis logs.
Instance Attribute Details
#analysis_id ⇒ String
The unique identifier of the protected query that you want to export the analysis logs for.
11043 11044 11045 11046 11047 11048 11049 11050 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043 class StartAnalysisLogExportInput < Struct.new( :membership_identifier, :analysis_id, :analysis_type, :result_configuration) SENSITIVE = [] include Aws::Structure end |
#analysis_type ⇒ String
The type of analysis that the logs are exported for. Currently, only
PROTECTED_QUERY is supported.
11043 11044 11045 11046 11047 11048 11049 11050 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043 class StartAnalysisLogExportInput < Struct.new( :membership_identifier, :analysis_id, :analysis_type, :result_configuration) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
A unique identifier for the membership to export the analysis logs for. Currently accepts a membership ID.
11043 11044 11045 11046 11047 11048 11049 11050 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043 class StartAnalysisLogExportInput < Struct.new( :membership_identifier, :analysis_id, :analysis_type, :result_configuration) SENSITIVE = [] include Aws::Structure end |
#result_configuration ⇒ Types::AnalysisLogExportResultConfiguration
The details needed to write the exported analysis logs.
You don't need to create an IAM role for log export. Clean Rooms writes the exported logs using your own identity, so Clean Rooms writes the exported logs only where your existing permissions allow.
11043 11044 11045 11046 11047 11048 11049 11050 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11043 class StartAnalysisLogExportInput < Struct.new( :membership_identifier, :analysis_id, :analysis_type, :result_configuration) SENSITIVE = [] include Aws::Structure end |