Class: Aws::CleanRooms::Types::SyntheticDataParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::SyntheticDataParameters
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
SyntheticDataParameters is a union - when making an API calls you must set exactly one of the members.
SyntheticDataParameters is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SyntheticDataParameters corresponding to the set member.
The parameters that control how synthetic data is generated, including privacy settings, column classifications, and other configuration options that affect the data synthesis process.
Defined Under Namespace
Classes: MlSyntheticDataParameters, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ml_synthetic_data_parameters ⇒ Types::MLSyntheticDataParameters
The machine learning-specific parameters for synthetic data generation.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#ml_synthetic_data_parameters ⇒ Types::MLSyntheticDataParameters
The machine learning-specific parameters for synthetic data generation.
10894 10895 10896 10897 10898 10899 10900 10901 10902 10903 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10894 class SyntheticDataParameters < Struct.new( :ml_synthetic_data_parameters, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class MlSyntheticDataParameters < SyntheticDataParameters; end class Unknown < SyntheticDataParameters; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10894 10895 10896 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10894 def unknown @unknown end |