Class: Aws::CleanRooms::Types::UpdateCollaborationChangeRequestInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action to perform on the change request. Valid values include APPROVE (approve the change), DENY (reject the change), CANCEL (cancel the request), and COMMIT (commit after the request is approved).

For change requests without automatic approval, a member in the collaboration can manually APPROVE or DENY a change request. The collaboration owner can manually CANCEL or COMMIT a change request.

Returns:

  • (String)


11057
11058
11059
11060
11061
11062
11063
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11057

class UpdateCollaborationChangeRequestInput < Struct.new(
  :collaboration_identifier,
  :change_request_identifier,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#change_request_identifierString

The unique identifier of the specific change request to be updated within the collaboration.

Returns:

  • (String)


11057
11058
11059
11060
11061
11062
11063
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11057

class UpdateCollaborationChangeRequestInput < Struct.new(
  :collaboration_identifier,
  :change_request_identifier,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#collaboration_identifierString

The unique identifier of the collaboration that contains the change request to be updated.

Returns:

  • (String)


11057
11058
11059
11060
11061
11062
11063
# File 'lib/aws-sdk-cleanrooms/types.rb', line 11057

class UpdateCollaborationChangeRequestInput < Struct.new(
  :collaboration_identifier,
  :change_request_identifier,
  :action)
  SENSITIVE = []
  include Aws::Structure
end