Class: Aws::CleanRooms::Types::UpdateCollaborationChangeRequestInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRooms::Types::UpdateCollaborationChangeRequestInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanrooms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform on the change request.
-
#change_request_identifier ⇒ String
The unique identifier of the specific change request to be updated within the collaboration.
-
#collaboration_identifier ⇒ String
The unique identifier of the collaboration that contains the change request to be updated.
Instance Attribute Details
#action ⇒ String
The action to perform on the change request. Valid values include APPROVE (approve the change), DENY (reject the change), CANCEL (cancel the request), and COMMIT (commit after the request is approved).
For change requests without automatic approval, a member in the collaboration can manually APPROVE or DENY a change request. The collaboration owner can manually CANCEL or COMMIT a change request.
9682 9683 9684 9685 9686 9687 9688 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9682 class UpdateCollaborationChangeRequestInput < Struct.new( :collaboration_identifier, :change_request_identifier, :action) SENSITIVE = [] include Aws::Structure end |
#change_request_identifier ⇒ String
The unique identifier of the specific change request to be updated within the collaboration.
9682 9683 9684 9685 9686 9687 9688 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9682 class UpdateCollaborationChangeRequestInput < Struct.new( :collaboration_identifier, :change_request_identifier, :action) SENSITIVE = [] include Aws::Structure end |
#collaboration_identifier ⇒ String
The unique identifier of the collaboration that contains the change request to be updated.
9682 9683 9684 9685 9686 9687 9688 |
# File 'lib/aws-sdk-cleanrooms/types.rb', line 9682 class UpdateCollaborationChangeRequestInput < Struct.new( :collaboration_identifier, :change_request_identifier, :action) SENSITIVE = [] include Aws::Structure end |