Class: Aws::CleanRooms::Types::WorkerComputeConfigurationProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanrooms/types.rb

Overview

Note:

WorkerComputeConfigurationProperties is a union - when making an API calls you must set exactly one of the members.

Note:

WorkerComputeConfigurationProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WorkerComputeConfigurationProperties corresponding to the set member.

The configuration properties that define the compute environment settings for workers in Clean Rooms. These properties enable customization of the underlying compute environment to optimize performance for your specific workloads.

Direct Known Subclasses

Spark, Unknown

Defined Under Namespace

Classes: Spark, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sparkHash<String,String>

The Spark configuration properties for SQL and PySpark workloads. This map contains key-value pairs that configure Apache Spark settings to optimize performance for your data processing jobs. You can specify up to 50 Spark properties, with each key being 1-200 characters and each value being 0-500 characters. These properties allow you to adjust compute capacity for large datasets and complex workloads.

Returns:

  • (Hash<String,String>)


10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10359

class WorkerComputeConfigurationProperties < Struct.new(
  :spark,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Spark < WorkerComputeConfigurationProperties; end
  class Unknown < WorkerComputeConfigurationProperties; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10359
10360
10361
# File 'lib/aws-sdk-cleanrooms/types.rb', line 10359

def unknown
  @unknown
end